@@ -22,6 +22,7 @@
 #include <QtWidgets>
 #include <gdal.h>
 #include <proj_api.h>
+#include <routino.h>
 
 CAbout::CAbout(QWidget *parent)
     : QDialog(parent)
@@ -32,6 +33,14 @@ CAbout::CAbout(QWidget *parent)
     labelQtVersion->setText(qVersion());
     labelGDALVersion->setText(GDALVersionInfo("--version"));
     labelProj4Version->setText(QString::number(PJ_VERSION));
+    if(Routino_CheckAPIVersion() != ROUTINO_ERROR_NONE)
+    {
+        labelRoutinoVersion->setText(tr("%1 (API V%2, expected V%3)").arg(Routino_Version).arg(ROUTINO_API_VERSION).arg(Routino_APIVersion));
+    }
+    else
+    {
+        labelRoutinoVersion->setText(tr("%1 (API V%2)").arg(Routino_Version).arg(Routino_APIVersion));
+    }
 }
 
 CAbout::~CAbout()
