@@ -18,14 +18,17 @@
 
 #include "CAbout.h"
 #include "CMainWindow.h"
-#include "GeoMath.h"
 #include "canvas/CCanvas.h"
 #include "config.h"
 #include "dem/CDemDraw.h"
 #include "dem/CDemList.h"
 #include "gis/CGisWidget.h"
+#include "gis/IGisLine.h"
 #include "gis/WptIcons.h"
 #include "gis/db/CSetupWorkspace.h"
+#include "gis/prj/IGisProject.h"
+#include "gis/trk/CKnownExtension.h"
+#include "helpers/CProgressDialog.h"
 #include "helpers/CSettings.h"
 #include "map/CMapDraw.h"
 #include "map/CMapItem.h"
@@ -33,6 +36,7 @@
 #include "tool/CImportDatabase.h"
 #include "tool/CMapVrtBuilder.h"
 #include "tool/CRoutinoDatabaseBuilder.h"
+#include "units/CCoordFormatSetup.h"
 #include "units/CTimeZoneSetup.h"
 #include "units/CUnitsSetup.h"
 #include "units/IUnit.h"
@@ -64,6 +68,7 @@ CMainWindow::CMainWindow()
     initWptIcons();
 
     IUnit::self().setUnitType((IUnit::type_e)cfg.value("MainWindow/units",IUnit::eTypeMetric).toInt(), this);
+    CKnownExtension::init(IUnit::self());
 
     gisWidget = new CGisWidget(menuProject, this);
     dockGis->setWidget(gisWidget);
@@ -85,39 +90,39 @@ CMainWindow::CMainWindow()
     // end ---- restore window geometry -----
 
 
-    connect(actionAbout, SIGNAL(triggered()), this, SLOT(slotAbout()));
-    connect(actionHelp, SIGNAL(triggered()), this, SLOT(slotHelp()));
-    connect(actionAddMapView, SIGNAL(triggered()), this, SLOT(slotAddCanvas()));
-    connect(actionCloneMapView, SIGNAL(triggered()), this, SLOT(slotCloneCanvas()));
-    connect(actionShowScale, SIGNAL(changed()), this, SLOT(slotUpdateCurrentWidget()));
-    connect(actionShowGrid, SIGNAL(changed()), this, SLOT(update()));
-    connect(actionPOIText, SIGNAL(changed()), this, SLOT(slotUpdateCurrentWidget()));
-    connect(actionMapToolTip, SIGNAL(changed()), this, SLOT(slotUpdateCurrentWidget()));
-    connect(actionNightDay, SIGNAL(changed()), this, SLOT(slotUpdateCurrentWidget()));
-    connect(actionProfileIsWindow, SIGNAL(toggled(bool)), this, SLOT(slotSetProfileMode(bool)));
-    connect(actionSetupMapFont, SIGNAL(triggered()), this, SLOT(slotSetupMapFont()));
-    connect(actionSetupGrid, SIGNAL(triggered()), this, SLOT(slotSetupGrid()));
-    connect(actionSetupMapPaths, SIGNAL(triggered()), this, SLOT(slotSetupMapPath()));
-    connect(actionSetupDEMPaths, SIGNAL(triggered()), this, SLOT(slotSetupDemPath()));
-    connect(actionSetupMapView, SIGNAL(triggered()), this, SLOT(slotSetupMapView()));
-    connect(actionSetupTimeZone, SIGNAL(triggered()), this, SLOT(slotSetupTimeZone()));
-    connect(actionSetupUnits, SIGNAL(triggered()), this, SLOT(slotSetupUnits()));
-    connect(actionSetupWorkspace, SIGNAL(triggered()), this, SLOT(slotSetupWorkspace()));
-    connect(actionImportDatabase, SIGNAL(triggered()), this, SLOT(slotImportDatabase()));
-    connect(actionSaveGISData, SIGNAL(triggered()), gisWidget, SLOT(slotSaveAll()));
-    connect(actionLoadGISData, SIGNAL(triggered()), this, SLOT(slotLoadGISData()));
-    connect(actionVrtBuilder, SIGNAL(triggered()), this, SLOT(slotBuildVrt()));
-    connect(actionStoreView, SIGNAL(triggered()), this, SLOT(slotStoreView()));
-    connect(actionLoadView, SIGNAL(triggered()), this, SLOT(slotLoadView()));
-    connect(actionClose, SIGNAL(triggered()), this, SLOT(close()));
-    connect(actionCreateRoutinoDatabase, SIGNAL(triggered()), this, SLOT(slotCreateRoutinoDatabase()));
-    connect(tabWidget, SIGNAL(tabCloseRequested(int)), this, SLOT(slotTabCloseRequest(int)));
+    connect(actionAbout,                 SIGNAL(triggered()),            this,      SLOT(slotAbout()));
+    connect(actionHelp,                  SIGNAL(triggered()),            this,      SLOT(slotHelp()));
+    connect(actionAddMapView,            SIGNAL(triggered()),            this,      SLOT(slotAddCanvas()));
+    connect(actionCloneMapView,          SIGNAL(triggered()),            this,      SLOT(slotCloneCanvas()));
+    connect(actionShowScale,             SIGNAL(changed()),              this,      SLOT(slotUpdateCurrentWidget()));
+    connect(actionShowGrid,              SIGNAL(changed()),              this,      SLOT(update()));
+    connect(actionPOIText,               SIGNAL(changed()),              this,      SLOT(slotUpdateCurrentWidget()));
+    connect(actionMapToolTip,            SIGNAL(changed()),              this,      SLOT(slotUpdateCurrentWidget()));
+    connect(actionNightDay,              SIGNAL(changed()),              this,      SLOT(slotUpdateCurrentWidget()));
+    connect(actionProfileIsWindow,       SIGNAL(toggled(bool)),          this,      SLOT(slotSetProfileMode(bool)));
+    connect(actionSetupMapFont,          SIGNAL(triggered()),            this,      SLOT(slotSetupMapFont()));
+    connect(actionSetupGrid,             SIGNAL(triggered()),            this,      SLOT(slotSetupGrid()));
+    connect(actionSetupMapPaths,         SIGNAL(triggered()),            this,      SLOT(slotSetupMapPath()));
+    connect(actionSetupDEMPaths,         SIGNAL(triggered()),            this,      SLOT(slotSetupDemPath()));
+    connect(actionSetupMapView,          SIGNAL(triggered()),            this,      SLOT(slotSetupMapView()));
+    connect(actionSetupTimeZone,         SIGNAL(triggered()),            this,      SLOT(slotSetupTimeZone()));
+    connect(actionSetupUnits,            SIGNAL(triggered()),            this,      SLOT(slotSetupUnits()));
+    connect(actionSetupWorkspace,        SIGNAL(triggered()),            this,      SLOT(slotSetupWorkspace()));
+    connect(actionSetupCoordFormat,      SIGNAL(triggered(bool)),        this,      SLOT(slotSetupCoordFormat()));
+    connect(actionImportDatabase,        SIGNAL(triggered()),            this,      SLOT(slotImportDatabase()));
+    connect(actionSaveGISData,           SIGNAL(triggered()),            gisWidget, SLOT(slotSaveAll()));
+    connect(actionLoadGISData,           SIGNAL(triggered()),            this,      SLOT(slotLoadGISData()));
+    connect(actionVrtBuilder,            SIGNAL(triggered()),            this,      SLOT(slotBuildVrt()));
+    connect(actionStoreView,             SIGNAL(triggered()),            this,      SLOT(slotStoreView()));
+    connect(actionLoadView,              SIGNAL(triggered()),            this,      SLOT(slotLoadView()));
+    connect(actionClose,                 SIGNAL(triggered()),            this,      SLOT(close()));
+    connect(actionCreateRoutinoDatabase, SIGNAL(triggered()),            this,      SLOT(slotCreateRoutinoDatabase()));
+    connect(actionPrintMap,              SIGNAL(triggered()),            this,      SLOT(slotPrintMap()));
+    connect(tabWidget,                   SIGNAL(tabCloseRequested(int)), this,      SLOT(slotTabCloseRequest(int)));
 
-
-
-    connect(tabWidget, SIGNAL(currentChanged(int)), this, SLOT(slotCurrentTabCanvas(int)));
-    connect(tabMaps, SIGNAL(currentChanged(int)), this, SLOT(slotCurrentTabMaps(int)));
-    connect(tabDem, SIGNAL(currentChanged(int)), this, SLOT(slotCurrentTabDem(int)));
+    connect(tabWidget,                   SIGNAL(currentChanged(int)),    this,      SLOT(slotCurrentTabCanvas(int)));
+    connect(tabMaps,                     SIGNAL(currentChanged(int)),    this,      SLOT(slotCurrentTabMaps(int)));
+    connect(tabDem,                      SIGNAL(currentChanged(int)),    this,      SLOT(slotCurrentTabDem(int)));
 
     cfg.beginGroup("Canvas");
     CMapDraw::loadMapPath(cfg);
@@ -164,6 +169,10 @@ CMainWindow::CMainWindow()
 
     IUnit::setTimeZoneSetup(tzmode, tz, useShortFormat);
 
+    IUnit::coord_format_e coordFormat;
+    coordFormat = (IUnit::coord_format_e)cfg.value("Units/coordFormat", IUnit::eCoordFormat1).toInt();
+    IUnit::setCoordFormat(coordFormat);
+
 
     QStatusBar * status = statusBar();
     lblPosWGS84 = new QLabel(status);
@@ -194,7 +203,7 @@ CMainWindow::~CMainWindow()
 
 
     /*
-       The "Canvas" section will holf all settings global to all views
+       The "Canvas" section will hold all settings global to all views
        and "Views" section containing a subsection for each view.
      */
     cfg.beginGroup("Canvas");
@@ -247,7 +256,7 @@ CMainWindow::~CMainWindow()
     /*
         Delete all canvas objects now to make sure they are destroyed before all
         other objects. This allows children of the canvas to access central objects
-        like CGisWidget safely uppon their destruction. (e.g. CMouseRangeTrk to reset
+        like CGisWidget safely upon their destruction. (e.g. CMouseRangeTrk to reset
         it's track's draw mode by key)
      */
     qDeleteAll(allViews);
@@ -260,6 +269,27 @@ CMainWindow::~CMainWindow()
     cfg.setValue("Units/timezone", tz);
     cfg.setValue("Units/timezone/mode", tzmode);
     cfg.setValue("Units/time/useShortFormat", useShortFormat);
+
+    IUnit::coord_format_e coordFormat;
+    IUnit::getCoordFormat(coordFormat);
+    cfg.setValue("Units/coordFormat", coordFormat);
+}
+
+QWidget * CMainWindow::getBestWidgetForParent()
+{
+    QWidget * w = CProgressDialog::self();
+    if(w)
+    {
+        return w;
+    }
+
+    w = self().getVisibleCanvas();
+    if(w)
+    {
+        return w;
+    }
+
+    return &self();
 }
 
 bool CMainWindow::isScaleVisible()
@@ -447,6 +477,7 @@ void CMainWindow::slotCloneCanvas()
     }
 
     target->loadConfig(view);
+    target->slotTriggerCompleteUpdate(CCanvas::redraw_e::eRedrawGis);
 
     SETTINGS;
     cfg.beginGroup("Canvas");
@@ -550,7 +581,7 @@ void CMainWindow::slotCurrentTabDem(int i)
 void CMainWindow::slotMousePosition(const QPointF& pos, qreal ele)
 {
     QString str;
-    GPS_Math_Deg_To_Str(pos.x(), pos.y(), str);
+    IUnit::degToStr(pos.x(), pos.y(), str);
     lblPosWGS84->setText(str);
 
     if(ele != NOFLOAT)
@@ -572,8 +603,8 @@ void CMainWindow::slotMousePosition(const QPointF& pos, qreal ele)
         {
             QString str;
             lblPosGrid->show();
-            canvas->convertGridPos2Str(pos, str);
-            lblPosGrid->setText(str);
+            canvas->convertGridPos2Str(pos, str, false);
+            lblPosGrid->setText(tr("[Grid: %1]").arg(str));
         }
     }
     else
@@ -655,6 +686,11 @@ void CMainWindow::slotSetupUnits()
 {
     CUnitsSetup dlg(this);
     dlg.exec();
+
+    if(QDialog::Accepted == dlg.result())
+    {
+        CKnownExtension::init(IUnit::self());
+    }
 }
 
 void CMainWindow::slotSetupWorkspace()
@@ -663,6 +699,12 @@ void CMainWindow::slotSetupWorkspace()
     dlg.exec();
 }
 
+void CMainWindow::slotSetupCoordFormat()
+{
+    CCoordFormatSetup dlg(this);
+    dlg.exec();
+}
+
 void CMainWindow::slotImportDatabase()
 {
     CImportDatabase * widget = new CImportDatabase(this);
@@ -684,11 +726,10 @@ void CMainWindow::slotCreateRoutinoDatabase()
 void CMainWindow::slotLoadGISData()
 {
     SETTINGS;
-    QString path = cfg.value("Paths/lastGisPath", QDir::homePath()).toString();
-    QString filter = cfg.value("Paths/lastGisFilter", "GPS Exchange Format (*.gpx)").toString();
+    QString path   = cfg.value("Paths/lastGisPath",   QDir::homePath()).toString();
+    QString filter = cfg.value("Paths/lastGisFilter", IGisProject::filedialogAllSupported).toString();
 
-
-    QStringList filenames = QFileDialog::getOpenFileNames(this, tr("Load GIS Data..."), path, "GPS Exchange Format (*.gpx);; QMapShack Binary (*.qms)", &filter);
+    QStringList filenames = QFileDialog::getOpenFileNames(this, tr("Load GIS Data..."), path, IGisProject::filedialogLoadFilters, &filter);
 
     if(filenames.isEmpty())
     {
@@ -698,7 +739,7 @@ void CMainWindow::slotLoadGISData()
     loadGISData(filenames);
 
     path = QFileInfo(filenames.first()).absolutePath();
-    cfg.setValue("Paths/lastGisPath", path);
+    cfg.setValue("Paths/lastGisPath",   path);
     cfg.setValue("Paths/lastGisFilter", filter);
 }
 
@@ -793,6 +834,17 @@ void CMainWindow::slotSetProfileMode(bool on)
     }
 }
 
+void CMainWindow::slotPrintMap()
+{
+    CCanvas * canvas = getVisibleCanvas();
+    if(canvas == 0)
+    {
+        return;
+    }
+
+    canvas->setMousePrint();
+}
+
 #ifdef WIN32
 
 static void sendDeviceEvent(DWORD unitmask, bool add)
