@@ -19,7 +19,6 @@
 #ifndef CMAINWINDOW_H
 #define CMAINWINDOW_H
 
-#include "gis/IGisLine.h"
 #include "ui_IMainWindow.h"
 #include <QMainWindow>
 
@@ -28,6 +27,8 @@ class CDemList;
 class QLabel;
 class CGisWidget;
 class CCanvas;
+struct SGisLine;
+
 
 class CMainWindow : public QMainWindow, private Ui::IMainWindow
 {
@@ -37,6 +38,9 @@ public:
     {
         return *pSelf;
     }
+
+    static QWidget * getBestWidgetForParent();
+
     virtual ~CMainWindow();
 
     void addMapList(CMapList *list, const QString& name);
@@ -58,14 +62,14 @@ public:
     void zoomCanvasTo(const QRectF rect);
     /**
        @brief Read the elevation from DEM data attached to the currently visible canvas for a given location
-       @param pos   a poistion in units of [rad]
+       @param pos   a position in units of [rad]
        @return If no elevation value can be found for the position NOFLOAT is returned.
      */
     qreal getEelevationAt(const QPointF &pos);
     void  getEelevationAt(const QPolygonF& pos, QPolygonF &ele);
     void  getEelevationAt(SGisLine &line);
     /**
-       @brief Get pointer to the currently visibale canvas object.
+       @brief Get pointer to the currently visible canvas object.
        @return If the currently visible tab does not contain a CCanvas object 0 is returned.
      */
     CCanvas * getVisibleCanvas();
@@ -97,6 +101,7 @@ private slots:
     void slotSetupTimeZone();
     void slotSetupUnits();
     void slotSetupWorkspace();
+    void slotSetupCoordFormat();
     void slotImportDatabase();
     void slotLoadGISData();
     void slotBuildVrt();
@@ -104,6 +109,7 @@ private slots:
     void slotLoadView();
     void slotSetProfileMode(bool on);
     void slotCreateRoutinoDatabase();
+    void slotPrintMap();
 
 private:
     friend int main(int argc, char ** argv);
