@@ -19,6 +19,7 @@
 
 #include "GeoMath.h"
 #include "canvas/IDrawContext.h"
+#include "units/IUnit.h"
 #include <proj_api.h>
 #include <stdlib.h>
 
@@ -28,9 +29,18 @@
 #define PI M_PI
 #define TWOPI (2*PI)
 
-void GPS_Math_DegMinSec_To_Deg(bool sign, const int32_t d, const int32_t m, const int32_t s, qreal &deg)
+pointDP::pointDP() : used(true), idx(NOIDX)
 {
-    deg = qAbs(d) + qreal(m) / 60.0 + qreal(s) / 3600;
+}
+
+segment_t::segment_t() : idx11(NOIDX), idx12(NOIDX), idx21(NOIDX)
+{
+}
+
+
+void GPS_Math_DegMinSec_To_Deg(bool sign, const qint32 d, const qint32 m, const qreal s, qreal &deg)
+{
+    deg = qAbs(d) + qreal(m) / 60.0 + s / 3600;
     if(sign)
     {
         deg = -deg;
@@ -64,110 +74,6 @@ void GPS_Math_DegMin_To_Deg(bool sign, const qint32 d, const qreal m, qreal& deg
     return;
 }
 
-void GPS_Math_Deg_To_Str(const qreal& x, const qreal& y, QString& str)
-{
-    qint32 degN,degE;
-    qreal minN,minE;
-
-    bool signLat = GPS_Math_Deg_To_DegMin(y, &degN, &minN);
-
-    bool signLon = GPS_Math_Deg_To_DegMin(x, &degE, &minE);
-
-    QString lat,lng;
-    lat = signLat ? "S" : "N";
-    lng = signLon ? "W" : "E";
-    str.sprintf("%s%02d° %06.3f %s%03d° %06.3f",lat.toUtf8().data(),qAbs(degN),minN,lng.toUtf8().data(),qAbs(degE),minE);
-}
-
-
-static QRegExp reCoord1("^\\s*([N|S]){1}\\W*([0-9]+)\\W*([0-9]+\\.[0-9]+)\\s+([E|W|O]){1}\\W*([0-9]+)\\W*([0-9]+\\.[0-9]+)\\s*$");
-
-static QRegExp reCoord2("^\\s*([N|S]){1}\\s*([0-9]+\\.[0-9]+)\\W*\\s+([E|W|O]){1}\\s*([0-9]+\\.[0-9]+)\\W*\\s*$");
-
-static QRegExp reCoord3("^\\s*([-0-9]+\\.[0-9]+)\\s+([-0-9]+\\.[0-9]+)\\s*$");
-
-static QRegExp reCoord4("^\\s*([N|S]){1}\\s*([0-9]+)\\W+([0-9]+)\\W+([0-9]+)\\W*([E|W|O]){1}\\W*([0-9]+)\\W+([0-9]+)\\W+([0-9]+)\\W*\\s*$");
-
-static QRegExp reCoord5("^\\s*([-0-9]+\\.[0-9]+)([N|S])\\s+([-0-9]+\\.[0-9]+)([W|E])\\s*$");
-
-
-bool GPS_Math_Str_To_Deg(const QString& str, qreal& lon, qreal& lat)
-{
-    if(reCoord2.exactMatch(str))
-    {
-        bool signLat    = reCoord2.cap(1) == "S";
-        float absLat    = reCoord2.cap(2).toDouble();
-        lat = signLat ? -absLat : absLat;
-
-        bool signLon    = reCoord2.cap(3) == "W";
-        float absLon    = reCoord2.cap(4).toDouble();
-        lon = signLon ? -absLon : absLon;
-    }
-    else if(reCoord1.exactMatch(str))
-    {
-        bool signLat    = reCoord1.cap(1) == "S";
-        int degLat      = reCoord1.cap(2).toInt();
-        float minLat    = reCoord1.cap(3).toDouble();
-
-        GPS_Math_DegMin_To_Deg(signLat, degLat, minLat, lat);
-
-        bool signLon    = reCoord1.cap(4) == "W";
-        int degLon      = reCoord1.cap(5).toInt();
-        float minLon    = reCoord1.cap(6).toDouble();
-
-        GPS_Math_DegMin_To_Deg(signLon, degLon, minLon, lon);
-    }
-    else if(reCoord3.exactMatch(str))
-    {
-        lat             = reCoord3.cap(1).toDouble();
-        lon             = reCoord3.cap(2).toDouble();
-    }
-    else if(reCoord4.exactMatch(str))
-    {
-        bool signLat    = reCoord4.cap(1) == "S";
-        int degLat    = reCoord4.cap(2).toInt();
-        int minLat    = reCoord4.cap(3).toInt();
-        int secLat    = reCoord4.cap(4).toInt();
-
-        GPS_Math_DegMinSec_To_Deg(signLat, degLat, minLat, secLat, lat);
-
-        bool signLon    = reCoord4.cap(5) == "W";
-        int degLon    = reCoord4.cap(6).toInt();
-        int minLon    = reCoord4.cap(7).toInt();
-        int secLon    = reCoord4.cap(8).toInt();
-
-        GPS_Math_DegMinSec_To_Deg(signLon, degLon, minLon, secLon, lon);
-    }
-    else if(reCoord5.exactMatch(str))
-    {
-        bool signLon    = reCoord4.cap(4) == "W";
-        bool signLat    = reCoord4.cap(2) == "S";
-        lat             = reCoord5.cap(1).toDouble();
-        lon             = reCoord5.cap(3).toDouble();
-
-        if(signLon)
-        {
-            lon = -lon;
-        }
-        if(signLat)
-        {
-            lat = -lat;
-        }
-    }
-    else
-    {
-        QMessageBox::warning(0,QObject::tr("Error"),QObject::tr("Bad position format. Must be: \"[N|S] ddd mm.sss [W|E] ddd mm.sss\" or \"[N|S] ddd.ddd [W|E] ddd.ddd\""),QMessageBox::Ok,QMessageBox::NoButton);
-        return false;
-    }
-
-    if(fabs(lon) > 180.0 || fabs(lat) > 90.0)
-    {
-        QMessageBox::warning(0,QObject::tr("Error"),QObject::tr("Position values out of bounds. "),QMessageBox::Ok,QMessageBox::NoButton);
-        return false;
-    }
-
-    return true;
-}
 
 // from http://www.movable-type.co.uk/scripts/LatLongVincenty.html
 qreal GPS_Math_Distance(const qreal u1, const qreal v1, const qreal u2, const qreal v2, qreal& a1, qreal& a2)
@@ -343,6 +249,62 @@ qreal GPS_Math_distPointLine3D(point3D& x1, point3D& x2, point3D& x0)
     return qSqrt(a1x2/a3);
 }
 
+static inline qreal sqr(qreal a)
+{
+    return a*a;
+}
+static inline qreal sqrlen(const QPointF &a)
+{
+    return sqr(a.x()) + sqr(a.y());
+}
+
+
+qreal GPS_Math_DistPointPolyline(const QPolygonF &points, const QPointF &q)
+{
+    const qint32 count = points.size();
+
+    if(count == 0)
+    {
+        return NOFLOAT;
+    }
+
+    QPointF b   = points[0];
+    QPointF dbq = b - q;
+    qreal dist  = sqrlen(dbq);
+
+    for (qint32 i = 1; i<count; ++i)
+    {
+        const QPointF a = b;
+        const QPointF daq = dbq;
+        b = points[i];
+        dbq = b - q;
+
+        const QPointF dab = a - b;
+
+        const qreal inv_sqrlen = 1./sqrlen(dab);
+        const qreal t = (dab.x()*daq.x() + dab.y()*daq.y())*inv_sqrlen;
+        if (t < 0.)
+        {
+            continue;
+        }
+        qreal current_dist;
+        if (t<=1.)
+        {
+            current_dist = sqr(dab.x()*dbq.y() - dab.y()*dbq.x())*inv_sqrlen;
+        }
+        else//t>1.
+        {
+            current_dist = sqrlen(dbq);
+        }
+        if (current_dist<dist)
+        {
+            dist = current_dist;
+        }
+    }
+    return dist;
+}
+
+
 
 struct segment
 {
@@ -374,13 +336,14 @@ void GPS_Math_DouglasPeucker(QVector<pointDP> &line, qreal d)
         pointDP& x1 = line[seg.idx1];
         pointDP& x2 = line[seg.idx2];
 
+        qreal dmax = d;
         for(qint32 i = seg.idx1 + 1; i < seg.idx2; i++)
         {
             qreal distance = GPS_Math_distPointLine3D(x1, x2, line[i]);
-            if(distance > d)
+            if(distance > dmax)
             {
-                idx = i;
-                break;
+                idx  = i;
+                dmax = distance;
             }
         }
 
@@ -418,7 +381,7 @@ QPointF GPS_Math_Wpt_Projection(const QPointF& pt1, qreal distance, qreal bearin
 
 bool GPS_Math_LineCrossesRect(const QPointF &p1, const QPointF &p2, const QRectF &rect)
 {
-    // the trival case
+    // the trivial case
     if(rect.contains(p1) || rect.contains(p2))
     {
         return true;
@@ -578,47 +541,26 @@ void segment_t::apply(const QPolygonF& coords, const QPolygonF& pixel, QPolygonF
 
     if(idx11 != NOIDX && idx21 != NOIDX)
     {
-        if(idx11 == idx21)
+        if(idx12 == idx21)
         {
-//            segPixel.push_back(px1);
-//            segPixel.push_back(px2);
-
-//            segCoord.push_back(pt1);
-//            segCoord.push_back(pt2);
-        }
-        else if(idx12 == idx21)
-        {
-//            segPixel.push_back(px1);
             segPixel.push_back(pixel[idx12]);
-//            segPixel.push_back(px2);
-
-//            segCoord.push_back(pt1);
             segCoord.push_back(coords[idx12]);
-//            segCoord.push_back(pt2);
         }
         else if(idx11 < idx21)
         {
-//            segPixel.push_back(px1);
-//            segCoord.push_back(pt1);
             for(int i = idx12; i <= idx21; i++)
             {
                 segPixel.push_back(pixel[i]);
                 segCoord.push_back(coords[i]);
             }
-//            segPixel.push_back(px2);
-//            segCoord.push_back(pt2);
         }
         else if(idx11 > idx21)
         {
-//            segPixel.push_back(px1);
-//            segCoord.push_back(pt1);
             for(int i = idx11; i > idx21; i--)
             {
                 segPixel.push_back(pixel[i]);
                 segCoord.push_back(coords[i]);
             }
-//            segPixel.push_back(px2);
-//            segCoord.push_back(pt2);
         }
     }
 }
