@@ -23,10 +23,12 @@
 #include "dem/CDemDraw.h"
 #include "gis/CGisDraw.h"
 #include "gis/CGisWidget.h"
+#include "gis/IGisLine.h"
 #include "gis/ovl/CGisItemOvlArea.h"
 #include "gis/trk/CGisItemTrk.h"
 #include "grid/CGrid.h"
 #include "grid/CGridSetup.h"
+#include "helpers/CDraw.h"
 #include "helpers/CSettings.h"
 #include "map/CMapDraw.h"
 #include "mouse/CMouseEditArea.h"
@@ -34,25 +36,18 @@
 #include "mouse/CMouseEditTrk.h"
 #include "mouse/CMouseMoveWpt.h"
 #include "mouse/CMouseNormal.h"
+#include "mouse/CMousePrint.h"
 #include "mouse/CMouseRangeTrk.h"
 #include "mouse/CMouseWptBubble.h"
 #include "plot/CPlotProfile.h"
 #include "units/IUnit.h"
-
+#include "widgets/CColorLegend.h"
 
 #include <QtWidgets>
 
-QPen CCanvas::penBorderBlue(QColor(10,10,150,220),2);
-QPen CCanvas::penBorderGray(Qt::lightGray,2);
-QPen CCanvas::penBorderBlack(QColor(0,0,0,200),2);
-QBrush CCanvas::brushBackWhite(QColor(255,255,255,255));
-QBrush CCanvas::brushBackYellow(QColor(0xff, 0xff, 0xcc, 0xE0));
-
 
 CCanvas::CCanvas(QWidget *parent, const QString &name)
     : QWidget(parent)
-    , posFocus(12.00 * DEG_TO_RAD, 49.00 * DEG_TO_RAD)
-    , plotTrackProfile(0)
 {
     setFocusPolicy(Qt::WheelFocus);
 
@@ -128,13 +123,31 @@ CCanvas::~CCanvas()
 {
     /*
         Some mouse objects call methods from their canvas on destruction.
-        So they are better deleted now explicitely befor any other object
+        So they are better deleted now explicitly before any other object
         in CCanvas is destroyed.
      */
     delete mouse;
     saveSizeTrackProfile();
 }
 
+void CCanvas::setOverrideCursor(const QCursor& cursor, const QString& src)
+{
+//    qDebug() << "setOverrideCursor" << src;
+    QApplication::setOverrideCursor(cursor);
+}
+
+void CCanvas::restoreOverrideCursor(const QString& src)
+{
+//    qDebug() << "restoreOverrideCursor" << src;
+    QApplication::restoreOverrideCursor();
+}
+
+void CCanvas::changeOverrideCursor(const QCursor& cursor, const QString &src)
+{
+//    qDebug() << "changeOverrideCursor" << src;
+    QApplication::changeOverrideCursor(cursor);
+}
+
 void CCanvas::saveConfig(QSettings& cfg)
 {
     map->saveConfig(cfg);
@@ -165,8 +178,11 @@ void CCanvas::resetMouse()
     mouse = new CMouseNormal(gis, this);
     if(underMouse())
     {
-        QApplication::restoreOverrideCursor();
-        QApplication::setOverrideCursor(*mouse);
+        while(QApplication::overrideCursor())
+        {
+            CCanvas::restoreOverrideCursor("resetMouse");
+        }
+        CCanvas::setOverrideCursor(*mouse, "resetMouse");
     }
 }
 
@@ -176,8 +192,8 @@ void CCanvas::setMouseMoveWpt(CGisItemWpt& wpt)
     mouse = new CMouseMoveWpt(wpt, gis, this);
     if(underMouse())
     {
-        QApplication::restoreOverrideCursor();
-        QApplication::setOverrideCursor(*mouse);
+        CCanvas::restoreOverrideCursor("setMouseMoveWpt");
+        CCanvas::setOverrideCursor(*mouse, "setMouseMoveWpt");
     }
 }
 
@@ -187,8 +203,8 @@ void CCanvas::setMouseEditTrk(const QPointF &pt)
     mouse = new CMouseEditTrk(pt, gis, this);
     if(underMouse())
     {
-        QApplication::restoreOverrideCursor();
-        QApplication::setOverrideCursor(*mouse);
+        CCanvas::restoreOverrideCursor("setMouseEditTrk");
+        CCanvas::setOverrideCursor(*mouse, "setMouseEditTrk");
     }
 }
 
@@ -198,8 +214,8 @@ void CCanvas::setMouseEditRte(const QPointF &pt)
     mouse = new CMouseEditRte(pt, gis, this);
     if(underMouse())
     {
-        QApplication::restoreOverrideCursor();
-        QApplication::setOverrideCursor(*mouse);
+        CCanvas::restoreOverrideCursor("setMouseEditRte");
+        CCanvas::setOverrideCursor(*mouse, "setMouseEditRte");
     }
 }
 
@@ -209,8 +225,8 @@ void CCanvas::setMouseEditTrk(CGisItemTrk& trk)
     mouse = new CMouseEditTrk(trk, gis, this);
     if(underMouse())
     {
-        QApplication::restoreOverrideCursor();
-        QApplication::setOverrideCursor(*mouse);
+        CCanvas::restoreOverrideCursor("setMouseEditTrk");
+        CCanvas::setOverrideCursor(*mouse, "setMouseEditTrk");
     }
 }
 
@@ -220,8 +236,8 @@ void CCanvas::setMouseRangeTrk(CGisItemTrk& trk)
     mouse = new CMouseRangeTrk(trk, gis, this);
     if(underMouse())
     {
-        QApplication::restoreOverrideCursor();
-        QApplication::setOverrideCursor(*mouse);
+        CCanvas::restoreOverrideCursor("setMouseRangeTrk");
+        CCanvas::setOverrideCursor(*mouse, "setMouseRangeTrk");
     }
 }
 
@@ -231,8 +247,8 @@ void CCanvas::setMouseEditArea(const QPointF& pt)
     mouse = new CMouseEditArea(pt, gis, this);
     if(underMouse())
     {
-        QApplication::restoreOverrideCursor();
-        QApplication::setOverrideCursor(*mouse);
+        CCanvas::restoreOverrideCursor("setMouseEditArea");
+        CCanvas::setOverrideCursor(*mouse, "setMouseEditArea");
     }
 }
 
@@ -242,8 +258,8 @@ void CCanvas::setMouseEditArea(CGisItemOvlArea& area)
     mouse = new CMouseEditArea(area, gis, this);
     if(underMouse())
     {
-        QApplication::restoreOverrideCursor();
-        QApplication::setOverrideCursor(*mouse);
+        CCanvas::restoreOverrideCursor("setMouseEditArea");
+        CCanvas::setOverrideCursor(*mouse, "setMouseEditArea");
     }
 }
 
@@ -253,8 +269,8 @@ void CCanvas::setMouseEditRte(CGisItemRte& rte)
     mouse = new CMouseEditRte(rte, gis, this);
     if(underMouse())
     {
-        QApplication::restoreOverrideCursor();
-        QApplication::setOverrideCursor(*mouse);
+        CCanvas::restoreOverrideCursor("setMouseEditRte");
+        CCanvas::setOverrideCursor(*mouse, "setMouseEditRte");
     }
 }
 
@@ -264,8 +280,19 @@ void CCanvas::setMouseWptBubble(const IGisItem::key_t& key)
     mouse = new CMouseWptBubble(key, gis, this);
     if(underMouse())
     {
-        QApplication::restoreOverrideCursor();
-        QApplication::setOverrideCursor(*mouse);
+        CCanvas::restoreOverrideCursor("setMouseWptBubble");
+        CCanvas::setOverrideCursor(*mouse, "setMouseWptBubble");
+    }
+}
+
+void CCanvas::setMousePrint()
+{
+    mouse->deleteLater();
+    mouse = new CMousePrint(gis, this);
+    if(underMouse())
+    {
+        CCanvas::restoreOverrideCursor("setMousePrint");
+        CCanvas::setOverrideCursor(*mouse, "setMousePrint");
     }
 }
 
@@ -305,20 +332,7 @@ void CCanvas::resizeEvent(QResizeEvent * e)
 {
     needsRedraw = eRedrawAll;
 
-    QSize s = e->size();
-    if(map)
-    {
-        map->resize(s);
-    }
-    if(dem)
-    {
-        dem->resize(s);
-    }
-    if(gis)
-    {
-        gis->resize(s);
-    }
-
+    setDrawContextSize(e->size());
     QWidget::resizeEvent(e);
 
     // move map loading indicator to new center of canvas
@@ -346,7 +360,7 @@ void CCanvas::paintEvent(QPaintEvent * e)
     p.begin(this);
     USE_ANTI_ALIASING(p,true);
 
-    // fill the backbround with default pattern
+    // fill the background with default pattern
     p.fillRect(rect(), "#FFFFBF");
 
     // ----- start to draw thread based content -----
@@ -380,6 +394,7 @@ void CCanvas::mousePressEvent(QMouseEvent * e)
 {
     mouse->mousePressEvent(e);
     QWidget::mousePressEvent(e);
+    e->accept();
 }
 
 void CCanvas::mouseMoveEvent(QMouseEvent * e)
@@ -392,12 +407,14 @@ void CCanvas::mouseMoveEvent(QMouseEvent * e)
 
     mouse->mouseMoveEvent(e);
     QWidget::mouseMoveEvent(e);
+    e->accept();
 }
 
 void CCanvas::mouseReleaseEvent(QMouseEvent *e)
 {
     mouse->mouseReleaseEvent(e);
     QWidget::mouseReleaseEvent(e);
+    e->accept();
 }
 
 void CCanvas::mouseDoubleClickEvent(QMouseEvent * e)
@@ -428,7 +445,7 @@ void CCanvas::wheelEvent(QWheelEvent * e)
 void CCanvas::enterEvent(QEvent * e)
 {
     Q_UNUSED(e);
-    QApplication::setOverrideCursor(*mouse);
+    CCanvas::setOverrideCursor(*mouse, "enterEvent");
 
     mouse->setMouseTracking(true);
 }
@@ -437,12 +454,11 @@ void CCanvas::enterEvent(QEvent * e)
 void CCanvas::leaveEvent(QEvent * e)
 {
     Q_UNUSED(e);
-    // bad hack to stop bad number of overide cursors.
-    QApplication::restoreOverrideCursor();
-    QApplication::restoreOverrideCursor();
-    QApplication::restoreOverrideCursor();
-    QApplication::restoreOverrideCursor();
-
+    // bad hack to stop bad number of override cursors.
+    while(QApplication::overrideCursor())
+    {
+        CCanvas::restoreOverrideCursor("leaveEvent");
+    }
 
     mouse->setMouseTracking(false);
 }
@@ -450,38 +466,56 @@ void CCanvas::leaveEvent(QEvent * e)
 void CCanvas::keyPressEvent(QKeyEvent * e)
 {
     qDebug() << hex << e->key();
-    bool doUpdate = false;
+    bool doUpdate = true;
 
-    if(e->key() == Qt::Key_Plus)
+    switch(e->key())
     {
+    case Qt::Key_Plus:
         setZoom(true, needsRedraw);
-        doUpdate = true;
-    }
-    else if(e->key() == Qt::Key_Minus)
-    {
+        break;
+
+    case Qt::Key_Minus:
         setZoom(false, needsRedraw);
-        doUpdate = true;
-    }
-    else if(e->key() == Qt::Key_Up)
+        break;
+
+    /* move the map with keys up, down, left and right */
+    case Qt::Key_Up:
+        moveMap(QPointF(         0,  height()/4));
+        break;
+
+    case Qt::Key_Down:
+        moveMap(QPointF(         0, -height()/4));
+        break;
+
+    case Qt::Key_Left:
+        moveMap(QPointF( width()/4,           0));
+        break;
+
+    case Qt::Key_Right:
+        moveMap(QPointF(-width()/4,           0));
+        break;
+
+    case Qt::Key_Escape:
     {
-        moveMap(QPointF(0, height()/4));
-    }
-    else if(e->key() == Qt::Key_Down)
-    {
-        moveMap(QPointF(0, -height()/4));
-    }
-    else if(e->key() == Qt::Key_Left)
-    {
-        moveMap(QPointF(width()/4, 0));
-    }
-    else if(e->key() == Qt::Key_Right)
-    {
-        moveMap(QPointF(-width()/4, 0));
+        IMouseEditLine *lineMouse = dynamic_cast<IMouseEditLine*>(mouse);
+        if(lineMouse != 0)
+        {
+            lineMouse->abortStep();
+        }
+        else
+        {
+            doUpdate = false;
+        }
+        break;
     }
 
+    default:
+        doUpdate = false;
+    }
 
     if(doUpdate)
     {
+        mouse->keyPressEvent(e);
         e->accept();
         update();
     }
@@ -491,59 +525,6 @@ void CCanvas::keyPressEvent(QKeyEvent * e)
     }
 }
 
-
-void CCanvas::drawText(const QString& str, QPainter& p, const QPoint& center, const QColor& color)
-{
-    CCanvas::drawText(str,p,center, color, CMainWindow::self().getMapFont());
-}
-
-
-void CCanvas::drawText(const QString& str, QPainter& p, const QPoint& center, const QColor& color, const QFont& font)
-{
-    QFontMetrics fm(font);
-    QRect r = fm.boundingRect(str);
-
-    r.moveCenter(center);
-
-    p.setPen(Qt::white);
-    p.setFont(font);
-
-    p.drawText(r.topLeft() - QPoint(-1,-1), str);
-    p.drawText(r.topLeft() - QPoint( 0,-1), str);
-    p.drawText(r.topLeft() - QPoint(+1,-1), str);
-
-    p.drawText(r.topLeft() - QPoint(-1, 0), str);
-    p.drawText(r.topLeft() - QPoint(+1, 0), str);
-
-    p.drawText(r.topLeft() - QPoint(-1,+1), str);
-    p.drawText(r.topLeft() - QPoint( 0,+1), str);
-    p.drawText(r.topLeft() - QPoint(+1,+1), str);
-
-    p.setPen(color);
-    p.drawText(r.topLeft(),str);
-}
-
-
-void CCanvas::drawText(const QString& str, QPainter& p, const QRect& r, const QColor& color)
-{
-    p.setPen(Qt::white);
-    p.setFont(CMainWindow::self().getMapFont());
-
-    p.drawText(r.adjusted(-1,-1,-1,-1),Qt::AlignCenter,str);
-    p.drawText(r.adjusted( 0,-1, 0,-1),Qt::AlignCenter,str);
-    p.drawText(r.adjusted(+1,-1,+1,-1),Qt::AlignCenter,str);
-
-    p.drawText(r.adjusted(-1, 0,-1, 0),Qt::AlignCenter,str);
-    p.drawText(r.adjusted(+1, 0,+1, 0),Qt::AlignCenter,str);
-
-    p.drawText(r.adjusted(-1,+1,-1,+1),Qt::AlignCenter,str);
-    p.drawText(r.adjusted( 0,+1, 0,+1),Qt::AlignCenter,str);
-    p.drawText(r.adjusted(+1,+1,+1,+1),Qt::AlignCenter,str);
-
-    p.setPen(color);
-    p.drawText(r,Qt::AlignCenter,str);
-}
-
 void CCanvas::drawStatusMessages(QPainter& p)
 {
     if(labelStatusMessages->isVisible())
@@ -551,8 +532,8 @@ void CCanvas::drawStatusMessages(QPainter& p)
         QRect r = labelStatusMessages->rect();
         r.adjust(-5, -5, 5, 5);
         r.moveTopLeft(QPoint(15,45));
-        p.setPen(CCanvas::penBorderGray);
-        p.setBrush(CCanvas::brushBackWhite);
+        p.setPen(CDraw::penBorderGray);
+        p.setBrush(CDraw::brushBackWhite);
         p.drawRoundedRect(r, 5, 5);
     }
 }
@@ -564,7 +545,6 @@ void CCanvas::drawScale(QPainter& p)
         return;
     }
 
-
     // step I: get the approximate distance for 200px in the bottom right corner
     QPointF brc(rect().bottomRight() - QPoint(50,30));
     QPointF pt1 = brc;
@@ -619,7 +599,7 @@ void CCanvas::drawScale(QPainter& p)
 
     QString val, unit;
     IUnit::self().meter2distance(d,val,unit);
-    drawText(QString("%1 %2").arg(val).arg(unit), p, pt3, Qt::black);
+    CDraw::text(QString("%1 %2").arg(val).arg(unit), p, pt3, Qt::black);
 }
 
 void CCanvas::slotTriggerCompleteUpdate(CCanvas::redraw_e flags)
@@ -651,6 +631,7 @@ void CCanvas::slotCheckTrackOnFocus()
         saveSizeTrackProfile();
         // get access to current track object
         delete plotTrackProfile;
+        delete colorLegend;
         keyTrackOnFocus.clear();
 
         // get access to next track object
@@ -668,6 +649,9 @@ void CCanvas::slotCheckTrackOnFocus()
             plotTrackProfile->show();
         }
 
+        colorLegend = new CColorLegend(this, trk2);
+        colorLegend->setGeometry(20, 20, 40, 300);
+
         // finally store the new key as track on focus
         keyTrackOnFocus = key;
     }
@@ -679,6 +663,8 @@ void CCanvas::moveMap(const QPointF& delta)
     posFocus -= delta;
     map->convertPx2Rad(posFocus);
 
+    emit sigMove();
+
     slotTriggerCompleteUpdate(eRedrawAll);
 }
 
@@ -698,9 +684,19 @@ void CCanvas::setupGrid()
     update();
 }
 
-void CCanvas::convertGridPos2Str(const QPointF& pos, QString& str)
+void CCanvas::convertGridPos2Str(const QPointF& pos, QString& str, bool simple)
 {
-    grid->convertPos2Str(pos, str);
+    grid->convertPos2Str(pos, str, simple);
+}
+
+void CCanvas::convertRad2Px(QPointF& pos)
+{
+    map->convertRad2Px(pos);
+}
+
+void CCanvas::convertPx2Rad(QPointF& pos)
+{
+    map->convertPx2Rad(pos);
 }
 
 void CCanvas::displayInfo(const QPoint& px)
@@ -765,6 +761,8 @@ void CCanvas::setZoom(bool in, redraw_e& needsRedraw)
     map->zoom(in, needsRedraw);
     dem->zoom(map->zoom());
     gis->zoom(map->zoom());
+
+    emit sigZoom();
 }
 
 bool CCanvas::findPolylineCloseBy(const QPointF& pt1, const QPointF& pt2, qint32 threshold, QPolygonF& polyline)
@@ -864,3 +862,56 @@ void CCanvas::showProfile(bool yes)
         }
     }
 }
+
+void CCanvas::setDrawContextSize(const QSize& s)
+{
+    if(map)
+    {
+        map->resize(s);
+    }
+    if(dem)
+    {
+        dem->resize(s);
+    }
+    if(gis)
+    {
+        gis->resize(s);
+    }
+}
+
+void CCanvas::print(QPainter& p, const QRectF& area, const QPointF& focus)
+{
+    const QSize oldSize = size();
+    const QSize newSize(area.size().toSize());
+
+    setDrawContextSize(newSize);
+
+    // ----- start to draw thread based content -----
+    // move coordinate system to center of the screen
+    p.translate(newSize.width() >> 1, newSize.height() >> 1);
+
+    redraw_e redraw = eRedrawAll;
+
+    map->draw(p, redraw, focus);
+    dem->draw(p, redraw, focus);
+    gis->draw(p, redraw, focus);
+
+    map->wait();
+    dem->wait();
+    gis->wait();
+
+    map->draw(p, redraw, focus);
+    dem->draw(p, redraw, focus);
+    gis->draw(p, redraw, focus);
+
+    // restore coordinate system to default
+    p.resetTransform();
+    // ----- start to draw fast content -----
+
+    QRect r(QPoint(0,0), area.size().toSize());
+
+    grid->draw(p, r);
+    gis->draw(p, r);
+
+    setDrawContextSize(oldSize);
+}
