@@ -40,10 +40,6 @@ public:
 
     struct buffer_t
     {
-        buffer_t() : zoomFactor(1.0,1.0), scale(1.0,1.0)
-        {
-        }
-
         /// @note: all coordinate values are long/lat WGS84 [rad]
 
         /// the canvas buffer
@@ -51,11 +47,11 @@ public:
         /// the used projection
         projPJ pjsrc;
         /// the zoomfactor used to draw the canvas
-        QPointF zoomFactor;
+        QPointF zoomFactor {1.0,1.0};
         /// the number of zoom levels
         int zoomLevels;
         /// the scale of the global viewport
-        QPointF scale;
+        QPointF scale {1.0,1.0};
         /// top left corner
         QPointF ref1;
         /// top right corner
@@ -76,7 +72,7 @@ public:
     /**
        @brief Zoom in and out of the map by the scale factors defined in CMapDB::scales.
        @param in            set true to zoom in, and false to zoom out
-       @param needsRedraw   if the zoom action makes a redraw nesseccary needsRedraw is set true
+       @param needsRedraw   if the zoom action makes a redraw necessary needsRedraw is set true
      */
     void zoom(bool in, CCanvas::redraw_e &needsRedraw);
     void zoom(int idx);
@@ -88,13 +84,13 @@ public:
 
     /**
        @brief Convert a geo coordinate of format lon/lat WGS84 into the currently used coordinate/projection/datum system.
-       @note  The unit is dependent on the currently used projection and must not nesseccarily be meter
+       @note  The unit is dependent on the currently used projection and must not necessarily be meter
        @param p             the point to convert
      */
     void convertRad2M(QPointF &p);
     /**
        @brief Convert a geo coordinate of the currently used projection/datum to lon/lat WGS84
-       @note  The unit is dependent on the currently used projection and must not nesseccarily be meter
+       @note  The unit is dependent on the currently used projection and must not necessarily be meter
        @param p             the point to convert
      */
     void convertM2Rad(QPointF &p);
@@ -118,7 +114,7 @@ public:
 
     /**
         @brief Draw the active map buffer to the painter
-        @param p            the painte used to draw the map
+        @param p            the painter used to draw the map
         @param needsRedraw  set true to trigger a redraw in the background thread
         @param f            the point of focus in [°] that is drawn in the middle of the viewport.
      */
@@ -135,7 +131,7 @@ public:
        @brief Set the projection of the draw context
 
        This will just create a new source projection object (pjsrc). Most likely you want to
-       overide this method to:
+       override this method to:
 
        1) save what ever has to be saved
        2) call this method
@@ -186,15 +182,15 @@ protected:
     /// map canvas twin buffer
     buffer_t buffer[2];
     /// the main threads currently used map canvas buffer
-    bool bufIndex;
+    bool bufIndex = false;
     /// buffer width [px]
-    int bufWidth;
+    int bufWidth = 100;
     /// buffer height [px]
-    int bufHeight;
+    int bufHeight = 100;
     /// the viewports width [px]
-    int viewWidth;
+    int viewWidth = 100;
     /// the viewports height [px]
-    int viewHeight;
+    int viewHeight = 100;
     /// the center of the viewport
     QPointF center;
 
@@ -206,12 +202,12 @@ protected:
     qreal scales[CANVAS_MAX_ZOOM_LEVELS];
     CCanvas::scales_type_e scalesType;
     /// the number of zoom levels
-    int zoomLevels;
+    int zoomLevels = 0;
 
     /// the basic scale of the map canvas
-    QPointF scale;
+    QPointF scale {1.0,-1.0};
     /// index into scales table
-    int zoomIndex;
+    int zoomIndex = 0;
     /// the actual used scaleFactor
     QPointF zoomFactor;
 
