@@ -19,6 +19,7 @@
 #ifndef IDRAWOBJECT_H
 #define IDRAWOBJECT_H
 
+#include "units/IUnit.h"
 #include <QObject>
 
 class QSettings;
@@ -81,7 +82,7 @@ public:
        connect to the QListWidget's signals to be noticed by a change.
 
        Different to other properties, that will get queried when ever the property
-       widget think it needs an update, getLayers() will only be called once uppon
+       widget think it needs an update, getLayers() will only be called once upon
        property widget creation.
 
        The default implementation will simply clear the list.
@@ -128,11 +129,11 @@ protected:
 
 private:
     /// the opacity level of a map
-    qreal opacity;
+    qreal opacity = 100;
     /// the minimum scale a map is visible
-    qreal minScale;
+    qreal minScale = NOFLOAT;
     /// the maximum scale a map is visible
-    qreal maxScale;
+    qreal maxScale = NOFLOAT;
 };
 
 #endif //IDRAWOBJECT_H
