@@ -23,6 +23,7 @@
 #include "dem/CDemList.h"
 #include "dem/CDemPathSetup.h"
 #include "dem/IDem.h"
+#include "gis/IGisLine.h"
 #include "helpers/CSettings.h"
 #include "units/IUnit.h"
 
@@ -57,7 +58,7 @@ void CDemDraw::setProjection(const QString& proj)
     // --- save the active maps
     QStringList keys;
     saveActiveMapsList(keys);
-    // --- neow set the new projection
+    // --- now set the new projection
     IDrawContext::setProjection(proj);
     // --- now build the map list from scratch. This will deactivate -> activate all maps
     //     By that everything is restored with the new projection
@@ -209,7 +210,7 @@ void CDemDraw::restoreActiveMapsList(const QStringList& keys)
             if(item && item->key == key)
             {
                 /**
-                    @Note   the item will load it's configuration uppon successful activation
+                    @Note   the item will load it's configuration upon successful activation
                             by calling loadConfigForDemItem().
                  */
                 item->activate();
@@ -279,9 +280,11 @@ qreal CDemDraw::getElevationAt(const QPointF& pos)
 
 void CDemDraw::getElevationAt(const QPolygonF& pos, QPolygonF& ele)
 {
+    qreal basefactor = IUnit::self().basefactor;
+
     for(int i = 0; i < pos.size(); i++)
     {
-        ele[i].ry() = getElevationAt(pos[i]);
+        ele[i].ry() = getElevationAt(pos[i]) * basefactor;
     }
 }
 
