@@ -18,9 +18,9 @@
 
 #include "CMainWindow.h"
 #include "GeoMath.h"
-#include "canvas/CCanvas.h"
 #include "dem/CDemDraw.h"
 #include "dem/CDemVRT.h"
+#include "helpers/CDraw.h"
 #include "units/IUnit.h"
 
 #include <QtWidgets>
@@ -34,7 +34,6 @@
 CDemVRT::CDemVRT(const QString &filename, CDemDraw *parent)
     : IDem(parent)
     , filename(filename)
-    , hasOverviews(false)
 {
     qDebug() << "------------------------------";
     qDebug() << "VRT: try to open" << filename;
@@ -42,14 +41,15 @@ CDemVRT::CDemVRT(const QString &filename, CDemDraw *parent)
     dataset = (GDALDataset*)GDALOpen(filename.toUtf8(),GA_ReadOnly);
     if(dataset == 0)
     {
-        QMessageBox::warning(&CMainWindow::self(), tr("Error..."), tr("Failed to load file: %1").arg(filename));
+        QMessageBox::warning(CMainWindow::getBestWidgetForParent(), tr("Error..."), tr("Failed to load file: %1").arg(filename));
         return;
     }
 
     if(dataset->GetRasterCount() != 1)
     {
-        delete dataset; dataset = 0;
-        QMessageBox::warning(&CMainWindow::self(), tr("Error..."), tr("DEM must have one band with 16bit or 32bit data."));
+        delete dataset;
+        dataset = 0;
+        QMessageBox::warning(CMainWindow::getBestWidgetForParent(), tr("Error..."), tr("DEM must have one band with 16bit or 32bit data."));
         return;
     }
 
@@ -57,8 +57,9 @@ CDemVRT::CDemVRT(const QString &filename, CDemDraw *parent)
     pBand = dataset->GetRasterBand(1);
     if(pBand == 0)
     {
-        delete dataset; dataset = 0;
-        QMessageBox::warning(&CMainWindow::self(), tr("Error..."), tr("DEM must have one band with 16bit or 32bit data."));
+        delete dataset;
+        dataset = 0;
+        QMessageBox::warning(CMainWindow::getBestWidgetForParent(), tr("Error..."), tr("DEM must have one band with 16bit or 32bit data."));
         return;
     }
 
@@ -85,7 +86,8 @@ CDemVRT::CDemVRT(const QString &filename, CDemDraw *parent)
     free(ptr);
     if(pjsrc == 0)
     {
-        delete dataset; dataset = 0;
+        delete dataset;
+        dataset = 0;
         QMessageBox::warning(0, tr("Error..."), tr("No georeference information found."));
         return;
     }
