@@ -19,16 +19,22 @@
 #ifndef IDEM_H
 #define IDEM_H
 
-#include "canvas/IDrawContext.h"
 #include "canvas/IDrawObject.h"
 #include <QObject>
 #include <QPointer>
 #include <proj_api.h>
 
+#define CUSTOM_SLOPE_COLORTABLE ( -1 )
+
 class CDemDraw;
 class IDemProp;
 class QSettings;
 
+struct SlopePresets
+{
+    const char  *name;
+    const qreal steps[5];
+};
 
 class IDem : public IDrawObject
 {
@@ -72,18 +78,23 @@ public:
         return bSlopeColor;
     }
 
-    int getGradeSlopeColor()
-    {
-        return gradeSlopeColor;
-    }
-
-
     const QVector<QRgb> getSlopeColorTable()
     {
         return slopetable;
     }
 
-    static const qreal tblGrade[5][6];
+    static const struct SlopePresets slopePresets[7];
+    static const size_t slopePresetCount = sizeof(IDem::slopePresets) / sizeof(IDem::slopePresets[0]);
+
+    const qreal* getCurrentSlopeStepTable();
+
+    int getSlopeStepTableIndex()
+    {
+        return gradeSlopeColor;
+    }
+
+    void setSlopeStepTable(int idx);
+    void setSlopeStepTableCustomValue(int idx, int val);
 
 public slots:
     void slotSetHillshading(bool yes)
@@ -98,8 +109,6 @@ public slots:
         bSlopeColor = yes;
     }
 
-    void slotSetGradeSlopeColor(int g);
-
 protected:
 
     void hillshading(QVector<qint16>& data, qreal w, qreal h, QImage &img);
@@ -107,7 +116,7 @@ protected:
     void slopecolor(QVector<qint16>& data, qreal w, qreal h, QImage &img);
 
     /**
-       @brief Reproject (translate, rotate, scale) tile befor drwaing it.
+       @brief Reproject (translate, rotate, scale) tile before drawing it.
        @param img   the tile as QImage
        @param l     a 4 point polygon to fit the tile in
        @param p     the QPainter used to paint the tile
@@ -119,31 +128,30 @@ protected:
     /// source projection of the current map file
     /**
         Has to be set by subclass. Destruction has to be
-        handeled by subclass.
+        handled by subclass.
      */
-    projPJ pjsrc;
+    projPJ pjsrc = 0;
     /// target projection
     /**
         Is set by IMap() to WGS84. Will be freed by ~IMap()
      */
-    projPJ pjtar;
+    projPJ pjtar = 0;
 
     /// width in number of px
-    quint32 xsize_px;
+    quint32 xsize_px = 0;
     /// height in number of px
-    quint32 ysize_px;
+    quint32 ysize_px = 0;
 
     /// scale [px/m]
-    qreal xscale;
+    qreal xscale = 1.0;
     /// scale [px/m]
-    qreal yscale;
-
+    qreal yscale = 1.0;
 
 
     /**
        @brief True if map was loaded successfully
      */
-    bool isActivated;
+    bool isActivated = false;
 
     /// the setup dialog. Use getSetup() for access
     QPointer<IDemProp> setup;
@@ -152,18 +160,17 @@ protected:
 
     QVector<QRgb> slopetable;
 
-    int hasNoData;
+    int hasNoData = 0;
 
-    double noData;
+    double noData = 0;
 
 private:
-    bool bHillshading;
+    bool bHillshading = false;
+    qreal factorHillshading = 1.0;
 
-    qreal factorHillshading;
-
-    bool bSlopeColor;
-
-    int gradeSlopeColor;
+    bool bSlopeColor = false;
+    int gradeSlopeColor = 0;
+    qreal slopeCustomStepTable[5];
 };
 
 #endif //IDEM_H
