@@ -18,13 +18,15 @@
 
 #include "CMainWindow.h"
 #include "canvas/CCanvas.h"
-#include "config.h"
 #ifdef Q_OS_LINUX
 #include "device/CDeviceWatcherLinux.h"
 #endif
 #ifdef Q_OS_WIN
 #include "device/CDeviceWatcherWindows.h"
 #endif
+#ifdef Q_OS_MAC
+#include "device/CDeviceWatcherMac.h"
+#endif
 #include "device/IDevice.h"
 #include "gis/CGisListWks.h"
 #include "gis/CGisWidget.h"
@@ -44,6 +46,8 @@
 #include "gis/search/CSearchGoogle.h"
 #include "gis/trk/CGisItemTrk.h"
 #include "gis/wpt/CGisItemWpt.h"
+#include "helpers/CAppSetup.h"
+#include "helpers/CProgressDialog.h"
 #include "helpers/CSelectCopyAction.h"
 #include "helpers/CSelectProjectDialog.h"
 #include "helpers/CSettings.h"
@@ -52,7 +56,8 @@
 #include <QtSql>
 #include <QtWidgets>
 
-#define DB_VERSION 1
+#undef  DB_VERSION
+#define DB_VERSION 2
 
 class CGisListWksEditLock
 {
@@ -61,7 +66,7 @@ public:
     {
         if(waitCursor)
         {
-            QApplication::setOverrideCursor(Qt::WaitCursor);
+            CCanvas::setOverrideCursor(Qt::WaitCursor, "CGisListWksEditLock");
         }
         mutex.lock();
     }
@@ -69,7 +74,7 @@ public:
     {
         if(waitCursor)
         {
-            QApplication::restoreOverrideCursor();
+            CCanvas::restoreOverrideCursor("~CGisListWksEditLock");
         }
         mutex.unlock();
     }
@@ -81,21 +86,23 @@ private:
 
 CGisListWks::CGisListWks(QWidget *parent)
     : QTreeWidget(parent)
-    , menuNone(0)
-    , saveOnExit(true)
-    , saveEvery(5)
-    , deviceWatcher(0)
 {
     db = QSqlDatabase::addDatabase("QSQLITE","Workspace1");
-    db.setDatabaseName(QDir::home().filePath(CONFIGDIR).append("/workspace.db"));
+    QString config = CAppSetup::getPlattformInstance()->configDir().filePath("workspace.db");
+    db.setDatabaseName(config);
     db.open();
     configDB();
 
     menuProjectWks  = new QMenu(this);
     actionEditPrj   = menuProjectWks->addAction(QIcon("://icons/32x32/EditDetails.png"),tr("Edit.."), this, SLOT(slotEditPrj()));
-    actionSaveAs    = menuProjectWks->addAction(QIcon("://icons/32x32/SaveGISAs.png"),tr("Save As..."), this, SLOT(slotSaveAsProject()));
+    actionShowOnMap = menuProjectWks->addAction(QIcon("://icons/32x32/ShowAll.png"),tr("Show on Map"), this, SLOT(slotShowOnMap()));
+    actionHideFrMap = menuProjectWks->addAction(QIcon("://icons/32x32/ShowNone.png"),tr("Hide from Map"), this, SLOT(slotHideFrMap()));
+    menuProjectWks->addSeparator();
     actionSave      = menuProjectWks->addAction(QIcon("://icons/32x32/SaveGIS.png"),tr("Save"), this, SLOT(slotSaveProject()));
+    actionSaveAs    = menuProjectWks->addAction(QIcon("://icons/32x32/SaveGISAs.png"),tr("Save As..."), this, SLOT(slotSaveAsProject()));
+    menuProjectWks->addSeparator();
     actionSyncWksDev= menuProjectWks->addAction(QIcon("://icons/32x32/Device.png"),tr("Send to Devices"), this, SLOT(slotSyncWksDev()));
+    menuProjectWks->addSeparator();
     actionCloseProj = menuProjectWks->addAction(QIcon("://icons/32x32/Close.png"),tr("Close"), this, SLOT(slotCloseProject()));
 
     menuProjectDev  = new QMenu(this);
@@ -141,6 +148,8 @@ CGisListWks::CGisListWks(QWidget *parent)
     menuItemRte->addAction(actionEditDetails);
     menuItemRte->addAction(actionCopyItem);
     menuItemRte->addSeparator();
+    actionFocusRte  = menuItemRte->addAction(QIcon("://icons/32x32/RteInstr.png"), tr("Route Instructions"));
+    actionFocusRte->setCheckable(true);
     actionCalcRte   = menuItemRte->addAction(QIcon("://icons/32x32/Apply.png"), tr("Calculate Route"), this, SLOT(slotCalcRte()));
     actionResetRte  = menuItemRte->addAction(QIcon("://icons/32x32/Reset.png"), tr("Reset Route"), this, SLOT(slotResetRte()));
     actionEditRte   = menuItemRte->addAction(QIcon("://icons/32x32/LineMove.png"), tr("Edit Route"), this, SLOT(slotEditRte()));
@@ -165,6 +174,7 @@ CGisListWks::CGisListWks(QWidget *parent)
 
 
     connect(actionFocusTrk, SIGNAL(triggered(bool)), this, SLOT(slotFocusTrk(bool)));
+    connect(actionFocusRte, SIGNAL(triggered(bool)), this, SLOT(slotFocusRte(bool)));
     connect(qApp, SIGNAL(aboutToQuit ()), this, SLOT(slotSaveWorkspace()));
 
     SETTINGS;
@@ -180,6 +190,12 @@ CGisListWks::CGisListWks(QWidget *parent)
     deviceWatcher = new CDeviceWatcherLinux(this);
     connect(deviceWatcher, SIGNAL(sigChanged()), SIGNAL(sigChanged()));
 #endif
+#ifdef Q_OS_MAC
+    CDeviceWatcherMac* pWatcher = new CDeviceWatcherMac(this);
+    deviceWatcher = pWatcher;
+    connect(deviceWatcher, SIGNAL(sigChanged()), SIGNAL(sigChanged()));
+    connect(qApp, SIGNAL(aboutToQuit()), deviceWatcher, SLOT(slotEndListing()));
+#endif
 #ifdef Q_OS_WIN
     deviceWatcher = new CDeviceWatcherWindows(this);
     connect(deviceWatcher, SIGNAL(sigChanged()), SIGNAL(sigChanged()));
@@ -246,7 +262,7 @@ void CGisListWks::initDB()
     {
         query.prepare( "INSERT INTO versioninfo (version) VALUES(:version)");
         query.bindValue(":version", DB_VERSION);
-        QUERY_EXEC(; );
+        QUERY_EXEC();
     }
 
     if(!query.exec( "CREATE TABLE workspace ("
@@ -255,6 +271,7 @@ void CGisListWks::initDB()
                     "name           TEXT NOT NULL,"
                     "key            TEXT NOT NULL,"
                     "changed        BOOLEAN DEFAULT FALSE,"
+                    "visible        BOOLEAN DEFAULT TRUE,"
                     "data           BLOB NOT NULL"
 
                     ")"))
@@ -266,17 +283,34 @@ void CGisListWks::initDB()
 
 void CGisListWks::migrateDB(int version)
 {
-    QSqlQuery query(db);
+    qDebug() << "workspace.db has version " << version << ", migration to version " << DB_VERSION << " required";
 
-    for(version++; version <= DB_VERSION; version++)
+    // try to migrate between the database versions step by step (as soon as applicable)
+    if(version < 2)
     {
-//        switch(version)
-//        {
-//        }
+        migrateDB1to2();
     }
+//  if(version < 3) { migrateDB2to3(); }
+
+    // save the new version to the database
+    QSqlQuery query(db);
     query.prepare( "UPDATE versioninfo set version=:version");
-    query.bindValue(":version", version - 1);
-    QUERY_EXEC(; );
+    query.bindValue(":version", DB_VERSION);
+    QUERY_EXEC();
+}
+
+void CGisListWks::migrateDB1to2()
+{
+    qDebug() << "migrating workspace.db from version 1 to version 2";
+    // add a new column `visible` to the database
+    // the default value is `true`, as - by default in older versions of QMS - all saved projects
+    // have been loaded and shown on the map directly after starting
+    QSqlQuery query(db);
+    if(!query.exec( "ALTER TABLE workspace ADD COLUMN visible BOOLEAN DEFAULT TRUE;" ))
+    {
+        qDebug() << query.lastQuery();
+        qDebug() << query.lastError();
+    }
 }
 
 void CGisListWks::setExternalMenu(QMenu * project)
@@ -294,7 +328,7 @@ void CGisListWks::dragMoveEvent (QDragMoveEvent  * e )
     QTreeWidgetItem * item1 = currentItem();
     QTreeWidgetItem * item2 = itemAt(e->pos());
 
-    // changeing the item order is only valid for single selected items
+    // changing the item order is only valid for single selected items
     if(selectedItems().count() == 1)
     {
         /*
@@ -379,7 +413,7 @@ void CGisListWks::dragMoveEvent (QDragMoveEvent  * e )
             Never move/copy projects on devices. Data has to be removed or changed
             to store a project and it's items on a device. Moving it back to the
             workspace would conflict with the original project. To much hassle to
-            reslove this properly.
+            resolve this properly.
          */
         IGisProject * proj1 = dynamic_cast<IGisProject*>(item1);
         if(proj1 && proj1->isOnDevice())
@@ -576,16 +610,11 @@ void CGisListWks::dropEvent ( QDropEvent  * e )
 
         int cnt = 1;
         int N   = items.size();
-        QProgressDialog progress("Drop items...", "Abort drop", 0, 100, this);
-        progress.setWindowModality(Qt::WindowModal);
+        PROGRESS_SETUP(tr("Drop items..."), 0, N, this);
 
         foreach(QTreeWidgetItem * item, items)
         {
-            progress.setValue(qRound(100.0 * cnt++ / N));
-            if (progress.wasCanceled())
-            {
-                break;
-            }
+            PROGRESS(cnt++, break);
 
             IGisItem * gisItem = dynamic_cast<IGisItem*>(item);
             if(gisItem)
@@ -692,6 +721,8 @@ CDBProject * CGisListWks::getProjectById(quint64 id, const QString& db)
 
 void CGisListWks::slotSaveWorkspace()
 {
+    CGisListWksEditLock lock(true,IGisItem::mutexItems);
+
     if(!saveOnExit)
     {
         return;
@@ -706,11 +737,11 @@ void CGisListWks::slotSaveWorkspace()
     qDebug() << "slotSaveWorkspace()";
 
     const int total = topLevelItemCount();
-    PROGRESS_SETUP(tr("Saving workspace. Please wait."), this);
+    PROGRESS_SETUP(tr("Saving workspace. Please wait."), 0, total, this);
 
     for(int i = 0; i < total; i++)
     {
-        PROGRESS(i, total, return );
+        PROGRESS(i, return );
 
         IGisProject * project = dynamic_cast<IGisProject*>(topLevelItem(i));
         if(project == 0)
@@ -725,11 +756,14 @@ void CGisListWks::slotSaveWorkspace()
 
         project->IGisProject::operator>>(stream);
 
-        query.prepare("INSERT INTO workspace (type, key, name, changed, data) VALUES (:type, :key, :name, :changed, :data)");
+        query.prepare("INSERT INTO workspace (type, key, name, changed, visible, data) VALUES (:type, :key, :name, :changed, :visible, :data)");
         query.bindValue(":type", project->getType());
         query.bindValue(":key", project->getKey());
         query.bindValue(":name", project->getName());
         query.bindValue(":changed", project->isChanged());
+
+        bool visible = (project->checkState(CGisListDB::eColumnCheckbox) == Qt::Checked);
+        query.bindValue(":visible", visible);
         query.bindValue(":data", data);
         QUERY_EXEC(continue);
     }
@@ -742,25 +776,26 @@ void CGisListWks::slotSaveWorkspace()
 
 void CGisListWks::slotLoadWorkspace()
 {
+    CGisListWksEditLock lock(true,IGisItem::mutexItems);
+
     QSqlQuery query(db);
 
-    query.prepare("SELECT type, key, name, changed, data FROM workspace");
+    query.prepare("SELECT type, key, name, changed, visible, data FROM workspace");
     QUERY_EXEC(return );
 
     const int total = query.size();
-    PROGRESS_SETUP(tr("Loading workspace. Please wait."), this);
+    PROGRESS_SETUP(tr("Loading workspace. Please wait."), 0, total, this);
     quint32 progCnt = 0;
 
-    QApplication::setOverrideCursor(Qt::WaitCursor);
-
     while(query.next())
     {
-        PROGRESS(progCnt++, total, return );
+        PROGRESS(progCnt++, return );
 
-        int type        = query.value(0).toInt();
-        QString name    = query.value(2).toString();
-        bool changed    = query.value(3).toBool();
-        QByteArray data = query.value(4).toByteArray();
+        int type               = query.value(0).toInt();
+        QString name           = query.value(2).toString();
+        bool changed           = query.value(3).toBool();
+        Qt::CheckState visible = query.value(4).toBool() ? Qt::Checked : Qt::Unchecked;
+        QByteArray data        = query.value(5).toByteArray();
 
         QDataStream stream(&data, QIODevice::ReadOnly);
         stream.setVersion(QDataStream::Qt_5_2);
@@ -772,6 +807,7 @@ void CGisListWks::slotLoadWorkspace()
         case IGisProject::eTypeQms:
         {
             project = new CQmsProject(name, this);
+            project->setCheckState(CGisListDB::eColumnCheckbox, visible); // (1a)
             *project << stream;
             break;
         }
@@ -779,6 +815,7 @@ void CGisListWks::slotLoadWorkspace()
         case IGisProject::eTypeGpx:
         {
             project = new CGpxProject(name, this);
+            project->setCheckState(CGisListDB::eColumnCheckbox, visible); // (1b)
             *project << stream;
             break;
         }
@@ -787,6 +824,7 @@ void CGisListWks::slotLoadWorkspace()
         {
             CDBProject * dbProject;
             project = dbProject = new CDBProject(this);
+            project->setCheckState(CGisListDB::eColumnCheckbox, visible); // (1c)
 
             project->IGisProject::operator<<(stream);
             dbProject->restoreDBLink();
@@ -809,6 +847,11 @@ void CGisListWks::slotLoadWorkspace()
             continue;
         }
 
+        // Hiding the individual projects from the map (1a, 1b, 1c) could be done here within a single statement,
+        // but this results in a visible `the checkbox is being unchecked`, especially in case the project
+        // is large and takes some time to load.
+        // When done directly after construction there is no `blinking` of the check mark
+
         project->setToolTip(eColumnName,project->getInfo());
         if(changed)
         {
@@ -817,7 +860,6 @@ void CGisListWks::slotLoadWorkspace()
     }
 
     emit sigChanged();
-    QApplication::restoreOverrideCursor();
 }
 
 void CGisListWks::slotContextMenu(const QPoint& point)
@@ -829,6 +871,36 @@ void CGisListWks::slotContextMenu(const QPoint& point)
         return;
     }
 
+    // check whether all projects are checked or unchecked...
+    bool allChecked   = true;
+    bool allUnchecked = true;
+
+    foreach(QTreeWidgetItem *item, selectedItems())
+    {
+        IGisProject *project = dynamic_cast<IGisProject*>(item);
+        if(project != 0)
+        {
+            // as soon as we find an unchecked element, not all elements are checked (and vice versa)
+            if(project->checkState(CGisListDB::eColumnCheckbox) == Qt::Unchecked)
+            {
+                allChecked = false;
+            }
+            else
+            {
+                allUnchecked = false;
+            }
+        }
+
+        if(!allChecked && !allUnchecked)
+        {
+            break;
+        }
+    }
+
+    // ...and disable entries without any effect
+    actionShowOnMap->setEnabled(!allChecked);
+    actionHideFrMap->setEnabled(!allUnchecked);
+
     if(selectedItems().count() > 1)
     {
         IGisProject * project = dynamic_cast<IGisProject*>(currentItem());
@@ -926,6 +998,7 @@ void CGisListWks::slotContextMenu(const QPoint& point)
                 break;
 
             case IGisItem::eTypeRte:
+                actionFocusRte->setChecked(gisItem->hasUserFocus());
                 menuItemRte->exec(p);
                 break;
 
@@ -934,11 +1007,37 @@ void CGisListWks::slotContextMenu(const QPoint& point)
                 menuItemOvl->exec(p);
                 break;
             }
+
             return;
         }
     }
 }
 
+void CGisListWks::setVisibilityOnMap(bool visible)
+{
+    CGisListWksEditLock lock(true, IGisItem::mutexItems);
+    QList<QTreeWidgetItem*> items = selectedItems();
+    foreach(QTreeWidgetItem *item, items)
+    {
+        IGisProject * project = dynamic_cast<IGisProject*>(item);
+        if(project != 0)
+        {
+            project->setCheckState(CGisListDB::eColumnCheckbox, visible ? Qt::Checked : Qt::Unchecked);
+        }
+    }
+    emit sigChanged();
+}
+
+void CGisListWks::slotShowOnMap()
+{
+    setVisibilityOnMap(true);
+}
+
+void CGisListWks::slotHideFrMap()
+{
+    setVisibilityOnMap(false);
+}
+
 void CGisListWks::slotCloseProject()
 {
     CGisListWksEditLock lock(true, IGisItem::mutexItems);
@@ -995,9 +1094,9 @@ void CGisListWks::slotDeleteProject()
         IGisProject * project = dynamic_cast<IGisProject*>(item);
         if(project != 0)
         {
-            QApplication::setOverrideCursor(Qt::ArrowCursor);
-            int res = QMessageBox::question(&CMainWindow::self(), QObject::tr("Delete project..."), QObject::tr("Do you really want to delete %1?").arg(project->getFilename()), QMessageBox::Ok|QMessageBox::No,QMessageBox::Ok);
-            QApplication::restoreOverrideCursor();
+            CCanvas::setOverrideCursor(Qt::ArrowCursor, "slotDeleteProject");
+            int res = QMessageBox::question(CMainWindow::getBestWidgetForParent(), QObject::tr("Delete project..."), QObject::tr("Do you really want to delete %1?").arg(project->getFilename()), QMessageBox::Ok|QMessageBox::No,QMessageBox::Ok);
+            CCanvas::restoreOverrideCursor("slotDeleteProject");
             if(res != QMessageBox::Ok)
             {
                 continue;
@@ -1140,6 +1239,12 @@ void CGisListWks::slotDeleteItem()
     {
         project->blockUpdateItems(false);
     }
+
+    CCanvas * canvas = CMainWindow::self().getVisibleCanvas();
+    if(canvas)
+    {
+        canvas->slotTriggerCompleteUpdate(CCanvas::eRedrawGis);
+    }
 }
 
 void CGisListWks::slotCopyItem()
@@ -1155,9 +1260,13 @@ void CGisListWks::slotCopyItem()
     int lastResult = CSelectCopyAction::eResultNone;
 
     project->blockUpdateItems(true);
+
     QList<QTreeWidgetItem*> items = selectedItems();
+    int cnt = 1;
+    PROGRESS_SETUP(tr("Copy items..."), 0, items.count(), this);
     foreach(QTreeWidgetItem * item, items)
     {
+        PROGRESS(cnt++, break);
         IGisItem * gisItem = dynamic_cast<IGisItem*>(item);
         if(gisItem == 0)
         {
@@ -1167,6 +1276,12 @@ void CGisListWks::slotCopyItem()
         project->insertCopyOfItem(gisItem, NOIDX, lastResult);
     }
     project->blockUpdateItems(false);
+
+    CCanvas * canvas = CMainWindow::self().getVisibleCanvas();
+    if(canvas)
+    {
+        canvas->slotTriggerCompleteUpdate(CCanvas::eRedrawGis);
+    }
 }
 
 void CGisListWks::slotProjWpt()
@@ -1261,6 +1376,16 @@ void CGisListWks::slotRangeTrk()
     }
 }
 
+void CGisListWks::slotFocusRte(bool on)
+{
+    CGisListWksEditLock lock(true, IGisItem::mutexItems);
+    CGisItemRte * gisItem = dynamic_cast<CGisItemRte*>(currentItem());
+    if(gisItem != 0)
+    {
+        CGisWidget::self().focusRteByKey(on, gisItem->getKey());
+    }
+}
+
 void CGisListWks::slotCalcRte()
 {
     CGisListWksEditLock lock(false, IGisItem::mutexItems);
@@ -1357,18 +1482,30 @@ void CGisListWks::slotSearchGoogle(bool on)
     {
         searchGoogle = new CSearchGoogle(this);
     }
+
+    CCanvas * canvas = CMainWindow::self().getVisibleCanvas();
+    if(canvas)
+    {
+        canvas->slotTriggerCompleteUpdate(CCanvas::eRedrawGis);
+    }
 }
 
 void CGisListWks::slotSyncWksDev()
 {
     CGisListWksEditLock lock(true, IGisItem::mutexItems);
 
+    if(IDevice::count() == 0)
+    {
+        return;
+    }
+
     IGisProject * project = dynamic_cast<IGisProject*>(currentItem());
     if(project == 0)
     {
         return;
     }
 
+    const int N = topLevelItemCount();
     QSet<QString> keys;
     if(IDevice::count() > 1)
     {
@@ -1379,13 +1516,26 @@ void CGisListWks::slotSyncWksDev()
         }
         dlg.getSlectedDevices(keys);
     }
+    else
+    {
+        for(int n = 0; n < N; n++)
+        {
+            IDevice * device = dynamic_cast<IDevice*>(topLevelItem(n));
+            if(device == 0)
+            {
+                continue;
+            }
+
+            keys << device->getKey();
+            break;
+        }
+    }
 
     CCanvas * canvas = CMainWindow::self().getVisibleCanvas();
-    const int N = topLevelItemCount();
     for(int n = 0; n < N; n++)
     {
         IDevice * device = dynamic_cast<IDevice*>(topLevelItem(n));
-        if(device == 0 || (!keys.isEmpty() && !keys.contains(device->getKey())))
+        if(device == 0 || keys.isEmpty() || !keys.contains(device->getKey()))
         {
             continue;
         }
