@@ -66,8 +66,8 @@ CGisWidget::~CGisWidget()
     cfg.setValue("Workspace/treeDB/state", treeDB->header()->saveState());
 
     /*
-        Explicitely delete workspace here, as database projects use
-        CGisWidget uppon destruction to signal the database their destruction.
+        Explicitly delete workspace here, as database projects use
+        CGisWidget upon destruction to signal the database their destruction.
 
      */
     delete treeWks;
@@ -87,7 +87,7 @@ void CGisWidget::postEventForDb(QEvent * event)
 void CGisWidget::loadGisProject(const QString& filename)
 {
     // add project to workspace
-    QApplication::setOverrideCursor(Qt::WaitCursor);
+    CCanvas::setOverrideCursor(Qt::WaitCursor, "loadGisProject");
     treeWks->blockSignals(true);
 
     QMutexLocker lock(&IGisItem::mutexItems);
@@ -118,7 +118,7 @@ void CGisWidget::loadGisProject(const QString& filename)
     }
 
     treeWks->blockSignals(false);
-    QApplication::restoreOverrideCursor();
+    CCanvas::restoreOverrideCursor("loadGisProject");
 
     emit sigChanged();
 }
@@ -137,7 +137,7 @@ void CGisWidget::slotHelpText()
 
 void CGisWidget::slotSaveAll()
 {
-    QApplication::setOverrideCursor(Qt::WaitCursor);
+    CCanvas::setOverrideCursor(Qt::WaitCursor, "slotSaveAll");
     QMutexLocker lock(&IGisItem::mutexItems);
     for(int i = 0; i < treeWks->topLevelItemCount(); i++)
     {
@@ -149,7 +149,7 @@ void CGisWidget::slotSaveAll()
         item->save();
     }
 
-    QApplication::restoreOverrideCursor();
+    CCanvas::restoreOverrideCursor("slotSaveAll");
 }
 
 IGisProject * CGisWidget::selectProject()
@@ -435,6 +435,18 @@ void CGisWidget::focusTrkByKey(bool yes, const IGisItem::key_t& key)
         trk->gainUserFocus(yes);
     }
 
+    emit sigChanged();
+}
+
+void CGisWidget::focusRteByKey(bool yes, const IGisItem::key_t &key)
+{
+    QMutexLocker lock(&IGisItem::mutexItems);
+
+    CGisItemRte * rte = dynamic_cast<CGisItemRte*>(getItemByKey(key));
+    if(rte != 0)
+    {
+        rte->gainUserFocus(yes);
+    }
 
     emit sigChanged();
 }
@@ -556,9 +568,7 @@ void CGisWidget::calcRteByKey(const IGisItem::key_t& key)
     CGisItemRte * rte = dynamic_cast<CGisItemRte*>(getItemByKey(key));
     if(rte != 0)
     {
-        QApplication::setOverrideCursor(Qt::WaitCursor);
         rte->calc();
-        QApplication::restoreOverrideCursor();
     }
 }
 
@@ -569,9 +579,7 @@ void CGisWidget::resetRteByKey(const IGisItem::key_t& key)
     CGisItemRte * rte = dynamic_cast<CGisItemRte*>(getItemByKey(key));
     if(rte != 0)
     {
-        QApplication::setOverrideCursor(Qt::WaitCursor);
         rte->reset();
-        QApplication::restoreOverrideCursor();
     }
 }
 
