@@ -19,6 +19,7 @@
 #include "CMainWindow.h"
 #include "GeoMath.h"
 #include "canvas/CCanvas.h"
+#include "device/IDevice.h"
 #include "gis/CGisDraw.h"
 #include "gis/CGisListWks.h"
 #include "gis/IGisItem.h"
@@ -27,6 +28,7 @@
 #include "gis/rte/CGisItemRte.h"
 #include "gis/trk/CGisItemTrk.h"
 #include "gis/wpt/CGisItemWpt.h"
+#include "helpers/CDraw.h"
 #include "units/IUnit.h"
 
 #include <QtSql>
@@ -35,33 +37,33 @@
 
 QMutex IGisItem::mutexItems(QMutex::Recursive);
 
-QString IGisItem::noKey;
+const QString IGisItem::noKey;
+
+const QString IGisItem::noName = QObject::tr("[no name]");
 
 const IGisItem::color_t IGisItem::colorMap[] =
 {
-    {"Black",       QColor(Qt::black)}
-    ,{"DarkRed",     QColor(Qt::darkRed)}
-    ,{"DarkGreen",   QColor(Qt::darkGreen)}
-    ,{"DarkYellow",  QColor(Qt::darkYellow)}
-    ,{"DarkBlue",    QColor(Qt::darkBlue)}
-    ,{"DarkMagenta", QColor(Qt::darkMagenta)}
-    ,{"DarkCyan",    QColor(Qt::darkCyan)}
-    ,{"LightGray",   QColor(Qt::gray)}
-    ,{"DarkGray",    QColor(Qt::darkGray)}
-    ,{"Red",         QColor(Qt::red)}
-    ,{"Green",       QColor(Qt::green)}
-    ,{"Yellow",      QColor(Qt::yellow)}
-    ,{"Blue",        QColor(Qt::blue)}
-    ,{"Magenta",     QColor(Qt::magenta)}
-    ,{"Cyan",        QColor(Qt::cyan)}
-    ,{"White",       QColor(Qt::white)}
-    ,{"Transparent", QColor(Qt::transparent)}
-    ,{0, QColor()}
+    {"Black",        QColor(Qt::black),       QString("://icons/8x8/bullet_black.png")}
+    ,{"DarkRed",     QColor(Qt::darkRed),     QString("://icons/8x8/bullet_dark_red.png")}
+    ,{"DarkGreen",   QColor(Qt::darkGreen),   QString("://icons/8x8/bullet_dark_green.png")}
+    ,{"DarkYellow",  QColor(Qt::darkYellow),  QString("://icons/8x8/bullet_dark_yellow.png")}
+    ,{"DarkBlue",    QColor(Qt::darkBlue),    QString("://icons/8x8/bullet_dark_blue.png")}
+    ,{"DarkMagenta", QColor(Qt::darkMagenta), QString("://icons/8x8/bullet_dark_magenta.png")}
+    ,{"DarkCyan",    QColor(Qt::darkCyan),    QString("://icons/8x8/bullet_dark_cyan.png")}
+    ,{"LightGray",   QColor(Qt::lightGray),   QString("://icons/8x8/bullet_gray.png")}
+    ,{"DarkGray",    QColor(Qt::darkGray),    QString("://icons/8x8/bullet_dark_gray.png")}
+    ,{"Red",         QColor(Qt::red),         QString("://icons/8x8/bullet_red.png")}
+    ,{"Green",       QColor(Qt::green),       QString("://icons/8x8/bullet_green.png")}
+    ,{"Yellow",      QColor(Qt::yellow),      QString("://icons/8x8/bullet_yellow.png")}
+    ,{"Blue",        QColor(Qt::blue),        QString("://icons/8x8/bullet_blue.png")}
+    ,{"Magenta",     QColor(Qt::magenta),     QString("://icons/8x8/bullet_magenta.png")}
+    ,{"Cyan",        QColor(Qt::cyan),        QString("://icons/8x8/bullet_cyan.png")}
+    ,{"White",       QColor(Qt::white),       QString("://icons/8x8/bullet_white.png")}
+    ,{"Transparent", QColor(Qt::transparent), QString("")}
 };
 
 IGisItem::IGisItem(IGisProject *parent, type_e typ, int idx)
     : QTreeWidgetItem(parent, typ)
-    , flags(0)
 {
     int n = -1;
     setFlags(QTreeWidgetItem::flags() & ~Qt::ItemIsDropEnabled);
@@ -186,7 +188,7 @@ void IGisItem::genKey()
 void IGisItem::loadFromDb(quint64 id, QSqlDatabase& db)
 {
     QSqlQuery query(db);
-    query.prepare("SELECT data FROM items WHERE id=:id");
+    query.prepare("SELECT data, key FROM items WHERE id=:id");
     query.bindValue(":id", id);
     QUERY_EXEC(return );
     if(query.next())
@@ -197,6 +199,24 @@ void IGisItem::loadFromDb(quint64 id, QSqlDatabase& db)
         in.setVersion(QDataStream::Qt_5_2);
         in >> history;
         loadHistory(history.histIdxCurrent);
+
+        if(key.item.isEmpty())
+        {
+            QString keyFromDB = query.value(1).toString();
+            /*[Issue #72] Database/Workspace inconsisteny in QMS 1.4.0
+
+               The root cause is a missing key in the serialized data. This is fixed by calling getKey() in setupHistory().
+
+               As the database has a valid key the complete history data has to be fixed with that key.
+             */
+            const int N = history.events.size();
+            for(int i = 0; i < N; i++)
+            {
+                loadHistory(i);
+                key.item = keyFromDB;
+                updateHistory();
+            }
+        }
     }
 }
 
@@ -208,6 +228,12 @@ QString IGisItem::getNameEx() const
     {
         str += " @ " + project->getName();
     }
+    IDevice * device = dynamic_cast<IDevice*>(parent()->parent());
+    if(device)
+    {
+        str += " @ " + device->getName();
+    }
+
     return str;
 }
 
@@ -283,6 +309,11 @@ void IGisItem::changed(const QString &what, const QString &icon)
 
 void IGisItem::updateHistory()
 {
+    if(history.histIdxCurrent == NOIDX)
+    {
+        return;
+    }
+
     history_event_t& event = history.events[history.histIdxCurrent];
     event.data.clear();
 
@@ -301,6 +332,7 @@ void IGisItem::updateHistory()
 
 void IGisItem::setupHistory()
 {
+    getKey();
     history.histIdxInitial = NOIDX;
     history.histIdxCurrent = NOIDX;
 
@@ -417,10 +449,10 @@ bool IGisItem::setReadOnlyMode(bool readOnly)
     {
         if(isReadOnly() && !readOnly)
         {
-            QApplication::setOverrideCursor(Qt::ArrowCursor);
-            QString str = QObject::tr("This element is probably read-only because it was not created within QMapShack. Usually you should not want to change imported data. But if you think that is ok press'Ok'.");
-            int res = QMessageBox::warning(&CMainWindow::self(), QObject::tr("Read Only Mode..."), str, QMessageBox::Ok|QMessageBox::Abort, QMessageBox::Ok);
-            QApplication::restoreOverrideCursor();
+            CCanvas::setOverrideCursor(Qt::ArrowCursor, "setReadOnlyMode");
+            QString str = QObject::tr("<h3>%1</h3> This element is probably read-only because it was not created within QMapShack. Usually you should not want to change imported data. But if you think that is ok press 'Ok'.").arg(getName());
+            int res = QMessageBox::warning(CMainWindow::getBestWidgetForParent(), QObject::tr("Read Only Mode..."), str, QMessageBox::Ok|QMessageBox::Abort, QMessageBox::Ok);
+            CCanvas::restoreOverrideCursor("setReadOnlyMode");
             if(res != QMessageBox::Ok)
             {
                 return false;
@@ -428,7 +460,7 @@ bool IGisItem::setReadOnlyMode(bool readOnly)
         }
     }
 
-    // finally change falg
+    // finally change flag
     if(readOnly)
     {
         flags &= ~eFlagWriteAllowed;
@@ -452,32 +484,36 @@ const IGisItem::key_t &IGisItem::getKey()
     return key;
 }
 
+const QString& IGisItem::getHash()
+{
+    if(history.histIdxCurrent == NOIDX)
+    {
+        return noKey;
+    }
+    return history.events[history.histIdxCurrent].hash;
+}
+
 QColor IGisItem::str2color(const QString& name)
 {
-    QColor ref(name);
-    const color_t * p = colorMap;
-    while(p->name)
+    for(size_t i = 0; i < sizeof(colorMap) / sizeof(color_t); i++)
     {
-        if((p->name == name) || (ref == p->color))
+        if(QString(colorMap[i].name).toUpper() == name.toUpper())
         {
-            return p->color;
+            return colorMap[i].color;
         }
-        p++;
     }
 
-    return QColor();
+    return QColor(name);
 }
 
 QString IGisItem::color2str(const QColor& color)
 {
-    const color_t * p = colorMap;
-    while(p->name)
+    for(size_t i = 0; i < sizeof(colorMap) / sizeof(color_t); i++)
     {
-        if(p->color == color)
+        if(colorMap[i].color == color)
         {
-            return p->name;
+            return colorMap[i].name;
         }
-        p++;
     }
 
     return "";
@@ -530,72 +566,6 @@ void IGisItem::splitLineToViewport(const QPolygonF& line, const QRectF& extViewp
     }
 }
 
-void IGisItem::drawArrows(const QPolygonF& line, const QRectF& extViewport, QPainter& p)
-{
-    QPointF arrow[4] =
-    {
-        QPointF( 20.0, 7.0),     //front
-        QPointF( 0.0, 0.0),      //upper tail
-        QPointF( 5.0, 7.0),      //mid tail
-        QPointF( 0.0, 15.0)      //lower tail
-    };
-
-    QPointF pt, pt1, ptt;
-
-    // draw direction arrows
-    bool start = true;
-    qreal heading;
-
-    //generate arrow pic on-the-fly
-    QImage arrow_pic(21,16, QImage::Format_ARGB32);
-    arrow_pic.fill( qRgba(0,0,0,0));
-    QPainter t_paint(&arrow_pic);
-    USE_ANTI_ALIASING(t_paint, true);
-    t_paint.setPen(QPen(Qt::white, 2));
-    t_paint.setBrush(p.brush());
-    t_paint.drawPolygon(arrow, 4);
-    t_paint.end();
-
-    foreach(pt,line)
-    {
-        if(start)                // no arrow on  the first loop
-        {
-            start = false;
-        }
-        else
-        {
-            if(!extViewport.contains(pt))
-            {
-                pt1 = pt;
-                continue;
-            }
-            if((qAbs(pt.x() - pt1.x()) + qAbs(pt.y() - pt1.y())) < 7)
-            {
-                pt1 = pt;
-                continue;
-            }
-            // keep distance
-            if((qAbs(pt.x() - ptt.x()) + qAbs(pt.y() - ptt.y())) > 100)
-            {
-                if(0 != pt.x() - pt1.x() && (pt.y() - pt1.y()))
-                {
-                    heading = ( qAtan2((qreal)(pt.y() - pt1.y()), (qreal)(pt.x() - pt1.x())) * 180.) / M_PI;
-
-                    p.save();
-                    // draw arrow between bullets
-                    p.translate((pt.x() + pt1.x())/2,(pt.y() + pt1.y())/2);
-                    p.rotate(heading);
-                    p.drawImage(-11, -7, arrow_pic);
-                    p.restore();
-                    //remember last point
-                    ptt = pt;
-                }
-            }
-        }
-        pt1 = pt;
-    }
-}
-
 QString IGisItem::removeHtml(const QString &str)
 {
     QTextDocument html;
@@ -751,3 +721,7 @@ bool IGisItem::isVisible(const QPointF& point, const QPolygonF& viewport, CGisDr
     return tmp2.boundingRect().contains(pt);
 }
 
+bool IGisItem::isChanged() const
+{
+    return text(CGisListWks::eColumnDecoration) == "*";
+}
