@@ -54,6 +54,10 @@ public:
 
     struct history_t
     {
+        history_t() : histIdxInitial(NOIDX), histIdxCurrent(NOIDX)
+        {
+        }
+
         qint32 histIdxInitial;
         qint32 histIdxCurrent;
         QList<history_event_t> events;
@@ -170,6 +174,17 @@ public:
      */
     const key_t& getKey();
 
+    /**
+       @brief Get a hash over the items data.
+
+       Every entry in the history has a hash over the item's serialized data. If the
+       data changes a new history entry is created and a new hash calculated. Thus the
+       has can be used to detect if an item has been changed between the last time the
+       hash was read.
+
+       @return The hash as a string reference.
+     */
+    const QString& getHash();
 
     /**
        @brief Get the icon attached to object
@@ -209,7 +224,7 @@ public:
     /**
         @brief Edit content of item.
 
-        This is quite dependent on the item. The default implemntation does nothing. It has to be
+        This is quite dependent on the item. The default implementation does nothing. It has to be
         overwritten and the item has to generate what ever is needed to edit/view it's details.
 
      */
@@ -296,6 +311,12 @@ public:
      */
     bool isOnDevice() const;
 
+    /**
+       @brief Check if there are any pending unsaved changes
+       @return True if the are changes to be safed
+     */
+    bool isChanged() const;
+
     /**
        @brief Set the read only mode.
 
@@ -345,7 +366,7 @@ public:
        @param stream the binary data stream
        @return The stream object.
      */
-    virtual QDataStream& operator>>(QDataStream& stream) = 0;
+    virtual QDataStream& operator>>(QDataStream& stream) const = 0;
 
     /**
        @brief Get read access to history of changes
@@ -358,7 +379,7 @@ public:
     }
 
     /**
-       @brief Load a given state of chnage from the history
+       @brief Load a given state of change from the history
        @param idx
      */
     void loadHistory(int idx);
@@ -413,18 +434,27 @@ public:
     static QString toLink(bool isReadOnly, const QString& href, const QString& str, const QString& key);
 
     /// a no key value that can be used to nullify references.
-    static QString noKey;
+    const static QString noKey;
+
+    const static QString noName;
+
+    struct color_t
+    {
+        const char   *name;
+        const QColor color;
+        const QString bullet;
+    };
+
+    static const color_t colorMap[];
 
 protected:
-    struct color_t;
-
     /// set icon of QTreeWidgetItem
     virtual void setSymbol() = 0;
     /// read waypoint data from an XML snippet
     void readWpt(const QDomNode& xml, wpt_t &wpt);
     /// write waypoint data to an XML snippet
     void writeWpt(QDomElement &xml, const wpt_t &wpt);
-    /// gnerate a unique key from item's data
+    /// generate a unique key from item's data
     virtual void genKey();
     /// setup the history structure right after the creation of the item
     void setupHistory();
@@ -432,12 +462,10 @@ protected:
     void updateHistory();
     /// convert a color string from GPX to a QT color
     QColor str2color(const QString& name);
-    /// convertr a QT color to a string to be used in a GPX file
+    /// convert a QT color to a string to be used in a GPX file
     QString color2str(const QColor &color);
     /// to optimize drawing of large polylines split the line into sections that are visible
     void splitLineToViewport(const QPolygonF& line, const QRectF& extViewport, QList<QPolygonF>& lines);
-    /// ditribute arrows over a polyline
-    void drawArrows(const QPolygonF &line, const QRectF &extViewport, QPainter& p);
     /// call when ever you make a change to the item's data
     virtual void changed(const QString& what, const QString& icon);
 
@@ -446,27 +474,13 @@ protected:
     bool isVisible(const QRectF& rect, const QPolygonF& viewport, CGisDraw * gis);
     bool isVisible(const QPointF& point, const QPolygonF& viewport, CGisDraw * gis);
 
-
-
-    quint32 flags;
+    quint32 flags = 0;
     key_t key;
-    QString hash;
     QPixmap icon;
     QRectF boundingRect;
 
     history_t history;
 
-
-    static const color_t colorMap[];
-
-
-    struct color_t
-    {
-        const char * name;
-        QColor color;
-    };
-
-
     enum flags_e
     {
         eFlagCreatedInQms   = 0x00000001
@@ -475,8 +489,6 @@ protected:
         ,eFlagWptBubble     = 0x00000100
     };
 
-
-
     static inline bool isBlocked(const QRectF& rect, const QList<QRectF> &blockedAreas)
     {
         foreach(const QRectF &r, blockedAreas)
