@@ -18,7 +18,7 @@
 
 
 #include "WptIcons.h"
-#include "config.h"
+#include "helpers/CAppSetup.h"
 
 #include <QtGui>
 
@@ -28,11 +28,11 @@ static QMap<QString, icon_t> wptIcons;
 
 void initWptIcons()
 {
-    wptIcons["Default"]            = icon_t(wptDefault, 16, 16);
-//    wptIcons["City (Capitol)"]      = ":/icons/wpt/capitol_city15x15.png";
-//    wptIcons["City (Large)"]        = ":/icons/wpt/large_city15x15.png";
-//    wptIcons["City (Medium)"]       = ":/icons/wpt/medium_city15x15.png";
-//    wptIcons["City (Small)"]        = ":/icons/wpt/small_city15x15.png";
+    wptIcons["Default"]             = icon_t(wptDefault, 16, 16);
+    wptIcons["City (Capitol)"]      = icon_t("://icons/waypoints/32x32/CityCapitol.png", 16, 16);
+    wptIcons["City (Large)"]        = icon_t("://icons/waypoints/32x32/CityLarge.png", 16, 16);
+    wptIcons["City (Medium)"]       = icon_t("://icons/waypoints/32x32/CityMedium.png", 16, 16);
+    wptIcons["City (Small)"]        = icon_t("://icons/waypoints/32x32/CitySmall.png", 16, 16);
 //    wptIcons["Small City"]          = ":/icons/wpt/small_city15x15.png";
 //    wptIcons["Geocache"]            = ":/icons/wpt/geocache15x15.png";
 //    wptIcons["Geocache Found"]      = ":/icons/wpt/geocache_fnd15x15.png";
@@ -64,9 +64,7 @@ void initWptIcons()
     setWptIconByName("Virtual Cache", "://icons/cache/32x32/virtual.png");
     setWptIconByName("Webcam Cache", "://icons/cache/32x32/webcam.png");
 
-    QDir dirIcon(QDir::home().filePath(CONFIGDIR));
-    dirIcon.mkdir("WaypointIcons");
-    dirIcon.cd("WaypointIcons");
+    QDir dirIcon = CAppSetup::getPlattformInstance()->configDir("WaypointIcons");
 
     QString filename;
     QStringList filenames = dirIcon.entryList(QDir::Files);
@@ -94,7 +92,7 @@ void setWptIconByName(const QString& name, const QString& filename)
 
 void setWptIconByName(const QString& name, const QPixmap& icon)
 {
-    QDir dirIcon(QDir::home().filePath(CONFIGDIR "WaypointIcons"));
+    QDir dirIcon = CAppSetup::getPlattformInstance()->configDir("WaypointIcons");
     QString filename = dirIcon.filePath(name + ".png");
 
     icon.save(filename);
