@@ -29,14 +29,6 @@
         cmd; \
     } \
 
-#define PROGRESS_SETUP(lbl, parent) \
-    QProgressDialog progress(lbl, "Abort", 0, 100, parent); \
-    progress.setWindowModality(Qt::WindowModal); \
-
-#define PROGRESS(x, total, cmd) \
-    progress.setValue(qRound(x * 100.0 / total)); \
-    if (progress.wasCanceled()) { cmd; } \
-
 
 #endif //MACROS_H
 
