@@ -57,13 +57,13 @@ CGpxProject::CGpxProject(const QString &filename, const IGisProject * project, I
     *(IGisProject*)this = *project;
     blockUpdateItems(project->blockUpdateItems());
 
+    int res     = CSelectCopyAction::eResultNone;
     const int N = project->childCount();
     for(int n = 0; n < N; n++)
     {
         IGisItem * item = dynamic_cast<IGisItem*>(project->child(n));
         if(item)
         {
-            int res = CSelectCopyAction::eResultNone;
             insertCopyOfItem(item, NOIDX, res);
         }
     }
@@ -95,7 +95,7 @@ void CGpxProject::loadGpx(const QString& filename)
 
     if(!file.open(QIODevice::ReadOnly))
     {
-        QMessageBox::critical(&CMainWindow::self(), QObject::tr("Failed to open..."), QObject::tr("Failed to open %1").arg(filename), QMessageBox::Abort);
+        QMessageBox::critical(CMainWindow::getBestWidgetForParent(), QObject::tr("Failed to open..."), QObject::tr("Failed to open %1").arg(filename), QMessageBox::Abort);
         return;
     }
 
@@ -108,7 +108,7 @@ void CGpxProject::loadGpx(const QString& filename)
     if(!xml.setContent(&file, false, &msg, &line, &column))
     {
         file.close();
-        QMessageBox::critical(&CMainWindow::self(), QObject::tr("Failed to read..."), QObject::tr("Failed to read: %1\nline %2, column %3:\n %4").arg(filename).arg(line).arg(column).arg(msg), QMessageBox::Abort);
+        QMessageBox::critical(CMainWindow::getBestWidgetForParent(), QObject::tr("Failed to read..."), QObject::tr("Failed to read: %1\nline %2, column %3:\n %4").arg(filename).arg(line).arg(column).arg(msg), QMessageBox::Abort);
         return;
     }
     file.close();
@@ -117,7 +117,7 @@ void CGpxProject::loadGpx(const QString& filename)
     QDomElement xmlGpx = xml.documentElement();
     if(xmlGpx.tagName() != "gpx")
     {
-        QMessageBox::critical(&CMainWindow::self(), QObject::tr("Failed to read..."), QObject::tr("Not a GPX file: ") + filename, QMessageBox::Abort);
+        QMessageBox::critical(CMainWindow::getBestWidgetForParent(), QObject::tr("Failed to read..."), QObject::tr("Not a GPX file: ") + filename, QMessageBox::Abort);
         return;
     }
 
@@ -190,7 +190,6 @@ void CGpxProject::loadGpx(const QString& filename)
         new CGisItemOvlArea(xmlArea, this);
     }
 
-
     setupName(QFileInfo(filename).baseName().replace("_", " "));
     setToolTip(CGisListWks::eColumnName, getInfo());
     valid = true;
@@ -219,21 +218,20 @@ bool CGpxProject::saveAs()
     QString path = cfg.value("Paths/lastGisPath", QDir::homePath()).toString();
     path += "/" + getName() + ".gpx";
 
-    QString filter = "*.gpx";
-    QString fn = QFileDialog::getSaveFileName(&CMainWindow::self(), QObject::tr("Save GIS data to..."), path, "*.gpx;; *.qms", &filter);
+    QString filter = filedialogFilterGPX;
+    QString fn = QFileDialog::getSaveFileName(CMainWindow::getBestWidgetForParent(), QObject::tr("Save GIS data to..."), path, filedialogSaveFilters, &filter);
 
     if(fn.isEmpty())
     {
         return false;
     }
 
-
     bool res = false;
-    if(filter == "*.gpx")
+    if(filter == filedialogFilterGPX)
     {
         filename = fn;
         metadata.name.clear();
-        setupName(QFileInfo(filename).baseName().replace("_", " "));
+        setupName(QFileInfo(filename).baseName());
 
         res = saveAs(fn, *this);
         if(res)
@@ -241,7 +239,7 @@ bool CGpxProject::saveAs()
             markAsSaved();
         }
     }
-    else if(filter == "*.qms")
+    else if(filter == filedialogFilterQMS)
     {
         res = CQmsProject::saveAs(fn, *this);
     }
@@ -272,30 +270,20 @@ bool CGpxProject::saveAs(const QString& fn, IGisProject& project)
     if(file.exists())
     {
         file.open(QIODevice::ReadOnly);
-        try
+        bool createdByQMS = false;
+
+        // load file content to xml document
+        QDomDocument xml;
+        if(xml.setContent(&file, false))
         {
-            // load file content to xml document
-            QDomDocument xml;
-            QString msg;
-            int line;
-            int column;
-            if(xml.setContent(&file, false, &msg, &line, &column))
-            {
-                const QDomElement& docElem = xml.documentElement();
-                const QDomNamedNodeMap& attr = docElem.attributes();
-                if(!attr.namedItem("creator").nodeValue().startsWith("QMapShack"))
-                {
-                    throw 0;
-                }
-            }
-            else
-            {
-                throw 0;
-            }
+            const QDomElement& docElem = xml.documentElement();
+            const QDomNamedNodeMap& attr = docElem.attributes();
+            createdByQMS = attr.namedItem("creator").nodeValue().startsWith("QMapShack");
         }
-        catch(int)
+
+        if(!createdByQMS)
         {
-            int res = QMessageBox::warning(&CMainWindow::self(),QObject::tr("File exists ...")
+            int res = QMessageBox::warning(CMainWindow::getBestWidgetForParent(),QObject::tr("File exists ...")
                                            ,QObject::tr("The file exists and it has not been created by QMapShack. "
                                                         "If you press 'yes' all data in this file will be lost. "
                                                         "Even if this file contains GPX data and has been loaded by QMapShack, "
@@ -408,7 +396,8 @@ bool CGpxProject::saveAs(const QString& fn, IGisProject& project)
         }
         QTextStream out(&file);
         out.setCodec("UTF-8");
-        out << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << endl;;
+        out << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << endl;
+
         out << doc.toString();
         file.close();
         if(file.error() != QFile::NoError)
@@ -418,7 +407,7 @@ bool CGpxProject::saveAs(const QString& fn, IGisProject& project)
     }
     catch(const QString& msg)
     {
-        QMessageBox::warning(&CMainWindow::self(), QObject::tr("Saveing GIS data failed..."), msg, QMessageBox::Abort);
+        QMessageBox::warning(CMainWindow::getBestWidgetForParent(), QObject::tr("Saving GIS data failed..."), msg, QMessageBox::Abort);
         res = false;
     }
     project.umount();
