@@ -20,12 +20,14 @@
 #include "gis/ovl/CGisItemOvlArea.h"
 #include "gis/prj/CDetailsPrj.h"
 #include "gis/prj/IGisProject.h"
+#include "gis/rte/CGisItemRte.h"
 #include "gis/trk/CGisItemTrk.h"
 #include "gis/wpt/CGisItemWpt.h"
 #include "helpers/CLinksDialog.h"
-#include "helpers/CTextEditWidget.h"
+#include "helpers/CProgressDialog.h"
 #include "plot/CPlotProfile.h"
 #include "plot/CPlotTrack.h"
+#include "widgets/CTextEditWidget.h"
 
 #include <QtPrintSupport>
 #include <QtWidgets>
@@ -43,7 +45,12 @@ CDetailsPrj::CDetailsPrj(IGisProject &prj, QWidget *parent)
     connect(comboSort, SIGNAL(currentIndexChanged(int)), this, SLOT(slotSortMode(int)));
     connect(toolLock, SIGNAL(clicked(bool)), this, SLOT(slotLock(bool)));
 
-    slotSetupGui();
+    timerUpdateTime = new QTimer(this);
+    timerUpdateTime->setSingleShot(true);
+    timerUpdateTime->setInterval(20);
+    connect(timerUpdateTime, SIGNAL(timeout()), this, SLOT(slotSetupGui()));
+
+    timerUpdateTime->start();
 }
 
 CDetailsPrj::~CDetailsPrj()
@@ -53,7 +60,7 @@ CDetailsPrj::~CDetailsPrj()
 void CDetailsPrj::resizeEvent(QResizeEvent * e)
 {
     QWidget::resizeEvent(e);
-    slotSetupGui();
+    timerUpdateTime->start();
 }
 
 void CDetailsPrj::getTrackProfile(CGisItemTrk * trk, QImage& image)
@@ -72,8 +79,20 @@ void CDetailsPrj::getTrackOverview(CGisItemTrk * trk, QImage& image)
 
 void CDetailsPrj::slotSetupGui()
 {
-    textDesc->document()->setTextWidth(textDesc->size().width() - 20);
-    draw(*textDesc->document(), false);
+    if(!mutex.tryLock())
+    {
+        /*
+            What is this about?
+
+            When drawing the diary a progress dialog is used. This dialog is operating the event loop.
+            Consequently new events resulting into drawing the diary can be processed. But slotSetupGui()
+            is not reentrant. That is why we have to block these calls with a mutex. However as something
+            has changed the diary has to be redrawn again. That is why the timer is restarted.
+
+         */
+        timerUpdateTime->start(1000);
+        return;
+    }
 
     comboSort->blockSignals(true);
     comboSort->setCurrentIndex(prj.getSorting());
@@ -89,22 +108,50 @@ void CDetailsPrj::slotSetupGui()
         {
             comboSort->setCurrentIndex(IGisProject::eSortNone);
         }
+        timerUpdateTime->start();
+        mutex.unlock();
+        return;
     }
     comboSort->blockSignals(false);
 
     toolLock->blockSignals(true);
-    toolLock->setChecked(true);
     const int N = prj.childCount();
-    for(int n = 0; n < N; n++)
+    if(N == 0)
     {
-        IGisItem * item = dynamic_cast<IGisItem*>(prj.child(n));
-        if(item && !item->isReadOnly())
+        toolLock->setChecked(false);
+        toolLock->setEnabled(false);
+    }
+    else
+    {
+        toolLock->setChecked(true);
+        toolLock->setEnabled(true);
+        for(int n = 0; n < N; n++)
         {
-            toolLock->setChecked(false);
-            break;
+            IGisItem * item = dynamic_cast<IGisItem*>(prj.child(n));
+            if(item && !item->isReadOnly())
+            {
+                toolLock->setChecked(false);
+                break;
+            }
         }
     }
     toolLock->blockSignals(false);
+
+    textDesc->document()->setTextWidth(textDesc->size().width() - 20);
+    draw(*textDesc->document(), false);
+
+    QTabWidget * tabWidget = dynamic_cast<QTabWidget*>(parentWidget() ? parentWidget()->parentWidget() : 0);
+    if(tabWidget)
+    {
+        int idx = tabWidget->indexOf(this);
+        if(idx != NOIDX)
+        {
+            setObjectName(prj.getName());
+            tabWidget->setTabText(idx, prj.getName());
+        }
+    }
+
+    mutex.unlock();
 }
 
 #define ROOT_FRAME_MARGIN 5
@@ -120,11 +167,9 @@ bool sortWptByTime(const CGisItemWpt * wpt1, const CGisItemWpt * wpt2)
     return wpt1->getTime() < wpt2->getTime();
 }
 
-
-
 void CDetailsPrj::draw(QTextDocument& doc, bool printable)
 {
-    int cnt, w = doc.textWidth();
+    int w = doc.textWidth();
     int nItems = 0;
 
     QFontMetrics fm(QFont(font().family(),12));
@@ -142,6 +187,10 @@ void CDetailsPrj::draw(QTextDocument& doc, bool printable)
     fmtFrameStandard.setBottomMargin(5);
     fmtFrameStandard.setWidth(w - 2 * ROOT_FRAME_MARGIN);
 
+    fmtFrameTrackSummary.setBackground(Qt::white);
+    fmtFrameTrackSummary.setBorder(1);
+    fmtFrameTrackSummary.setPadding(10);
+
     fmtCharStandard.setFont(f);
 
     fmtBlockStandard.setTopMargin(10);
@@ -162,11 +211,22 @@ void CDetailsPrj::draw(QTextDocument& doc, bool printable)
     fmtTableStandard.setBottomMargin(20);
     fmtTableStandard.setWidth(w - 4 * ROOT_FRAME_MARGIN);
 
-    QVector<QTextLength> constraints;
-    constraints << QTextLength(QTextLength::FixedLength, 32);
-    constraints << QTextLength(QTextLength::VariableLength, 50);
-    constraints << QTextLength(QTextLength::VariableLength, 100);
-    fmtTableStandard.setColumnWidthConstraints(constraints);
+    QVector<QTextLength> constraints1;
+    constraints1 << QTextLength(QTextLength::FixedLength, 32);
+    constraints1 << QTextLength(QTextLength::VariableLength, 50);
+    constraints1 << QTextLength(QTextLength::VariableLength, 100);
+    fmtTableStandard.setColumnWidthConstraints(constraints1);
+
+    fmtTableHidden.setBorder(0);
+    fmtTableHidden.setCellPadding(4);
+    fmtTableHidden.setCellSpacing(0);
+    fmtTableHidden.setTopMargin(0);
+    fmtTableHidden.setBottomMargin(0);
+
+    QVector<QTextLength> constraints2;
+    constraints2 << QTextLength(QTextLength::PercentageLength, 70);
+    constraints2 << QTextLength(QTextLength::PercentageLength, 30);
+    fmtTableHidden.setColumnWidthConstraints(constraints2);
 
     fmtTableInfo.setBorder(0);
 
@@ -175,8 +235,7 @@ void CDetailsPrj::draw(QTextDocument& doc, bool printable)
     fmtCharHeader.setFontWeight(QFont::Bold);
     fmtCharHeader.setForeground(Qt::white);
 
-
-    bool isReadOnly = printable || prj.isOnDevice();
+    bool isReadOnly = printable || prj.isOnDevice() || toolLock->isChecked();
 
     setWindowTitle(prj.getName());
 
@@ -190,28 +249,16 @@ void CDetailsPrj::draw(QTextDocument& doc, bool printable)
     labelKeywords->setText(IGisItem::toLink(isReadOnly, "keywords", keywords, ""));
 
 
-    int scrollVal = textDesc->verticalScrollBar()->value();
+    scrollVal = textDesc->verticalScrollBar()->value();
 
     doc.clear();
     doc.rootFrame()->setFrameFormat(fmtFrameRoot);
     QTextCursor cursor = doc.rootFrame()->firstCursorPosition();
-
     cursor.insertHtml(IGisItem::toLink(isReadOnly, "name", QString("<h1>%1</h1>").arg(prj.getNameEx()), ""));
 
 
-    QTextFrame * diaryFrame = cursor.insertFrame(fmtFrameStandard);
-    {
-        QTextCursor cursor1(diaryFrame);
-
-        cursor1.setCharFormat(fmtCharStandard);
-        cursor1.setBlockFormat(fmtBlockStandard);
-        cursor1.insertHtml(IGisItem::createText(isReadOnly, prj.getDescription(), prj.getLinks()));
-
-        cursor.setPosition(cursor1.position()+1);
-    }
-
-
     QList<CGisItemTrk*> trks;
+    QList<CGisItemRte*> rtes;
     QList<CGisItemWpt*> wpts;
     QList<CGisItemOvlArea*> areas;
     const int N = prj.childCount();
@@ -225,6 +272,14 @@ void CDetailsPrj::draw(QTextDocument& doc, bool printable)
             continue;
         }
 
+        CGisItemRte * rte = dynamic_cast<CGisItemRte*>(prj.child(i));
+        if(rte != 0)
+        {
+            rtes << rte;
+            nItems++;
+            continue;
+        }
+
         CGisItemWpt * wpt = dynamic_cast<CGisItemWpt*>(prj.child(i));
         if(wpt != 0)
         {
@@ -242,55 +297,90 @@ void CDetailsPrj::draw(QTextDocument& doc, bool printable)
         }
     }
 
+    QTextFrame * diaryFrame = cursor.insertFrame(fmtFrameStandard);
+    {
+        QTextCursor cursor1(diaryFrame);
+        cursor1.setCharFormat(fmtCharStandard);
+        cursor1.setBlockFormat(fmtBlockStandard);
+
+        QTextTable * table = cursor1.insertTable(1, 2, fmtTableHidden);
+
+        QTextCursor cursor2 = table->cellAt(0,0).firstCursorPosition();
+        drawInfo(cursor2, isReadOnly);
+
+        if(prj.getItemCountByType(IGisItem::eTypeTrk) != 0)
+        {
+            QTextCursor cursor3 = table->cellAt(0,1).firstCursorPosition();
+            drawTrackSummary(cursor3, trks, isReadOnly);
+        }
+    }
+
 
     int n=1;
-    QProgressDialog progress(tr("Build diary..."), tr("Abort"), 0, 100, this);
-    progress.setWindowModality(Qt::WindowModal);
+    PROGRESS_SETUP(tr("Build diary..."), 0, nItems, this);
 
     if(comboSort->currentIndex() > IGisProject::eSortTime)
     {
-        drawByTrack(cursor, trks, wpts, progress, n, nItems, printable);
+        drawByTrack(cursor, trks, wpts, progress, n, isReadOnly);
     }
     else
     {
-        drawByGroup(cursor, trks, wpts, progress, n, nItems, printable);
+        drawByGroup(cursor, trks, wpts, progress, n, isReadOnly);
     }
 
-    if(!areas.isEmpty())
-    {
-        cursor.insertHtml(tr("<h2>Areas</h2>"));
-        QTextTable * table = cursor.insertTable(areas.count()+1, eMax1, fmtTableStandard);
+    drawRoute(cursor, rtes, progress, n, isReadOnly);
 
-        table->cellAt(0,eSym1).setFormat(fmtCharHeader);
-        table->cellAt(0,eInfo1).setFormat(fmtCharHeader);
-        table->cellAt(0,eComment1).setFormat(fmtCharHeader);
+    drawArea(cursor, areas, progress, n, isReadOnly);
 
-        table->cellAt(0,eInfo1).firstCursorPosition().insertText(tr("Info"));
-        table->cellAt(0,eComment1).firstCursorPosition().insertText(tr("Comment"));
-
-        cnt = 1;
-        foreach(CGisItemOvlArea * area, areas)
-        {
-            progress.setValue(n++ *100.0/nItems);
-            if(progress.wasCanceled())
-            {
-                return;
-            }
-
-
-            table->cellAt(cnt,eSym1).firstCursorPosition().insertImage(area->getIcon().toImage().scaledToWidth(16, Qt::SmoothTransformation));
-            table->cellAt(cnt,eInfo1).firstCursorPosition().insertHtml(area->getInfo());
-            table->cellAt(cnt,eComment1).firstCursorPosition().insertHtml(IGisItem::createText(area->isReadOnly()||printable, area->getComment(), area->getDescription(), area->getLinks(), area->getKey().item));
-            cnt++;
-        }
-
-        cursor.setPosition(table->lastPosition() + 1);
-    }
-
-    textDesc->verticalScrollBar()->setValue(scrollVal);
+    QTimer::singleShot(1, this, SLOT(slotSetScrollbar()));
 }
 
-void CDetailsPrj::drawByGroup(QTextCursor &cursor, QList<CGisItemTrk*>& trks, QList<CGisItemWpt*>& wpts, QProgressDialog& progress, int& n, int nItems, bool printable)
+void CDetailsPrj::slotSetScrollbar()
+{
+    textDesc->verticalScrollBar()->setValue(scrollVal);
+    comboSort->setEnabled(true);
+}
+
+void CDetailsPrj::drawInfo(QTextCursor& cursor, bool isReadOnly)
+{
+    QTextFrame * diaryFrame = cursor.insertFrame(fmtFrameStandard);
+
+    QTextCursor cursor1(diaryFrame);
+
+    cursor1.setCharFormat(fmtCharStandard);
+    cursor1.setBlockFormat(fmtBlockStandard);
+    cursor1.insertHtml(IGisItem::createText(isReadOnly, prj.getDescription(), prj.getLinks()));
+}
+
+void CDetailsPrj::drawTrackSummary(QTextCursor& cursor, const QList<CGisItemTrk*> trks, bool isReadOnly)
+{
+    quint32 flags = 0;
+    QVector<CActivityTrk::activity_summary_t> summaries(CGisItemTrk::trkpt_t::eActMaxNum + 1);
+    foreach(const CGisItemTrk* trk, trks)
+    {
+        const CActivityTrk& activities = trk->getActivities();
+        flags |= activities.getAllFlags();
+        activities.sumUp(summaries);
+    }
+
+
+    QTextFrame * diaryFrame = cursor.insertFrame(fmtFrameTrackSummary);
+
+    QTextCursor cursor1(diaryFrame);
+
+    cursor1.setCharFormat(fmtCharStandard);
+    cursor1.setBlockFormat(fmtBlockStandard);
+
+    QString str;
+    str += tr("<b>Summary over all tracks in project</b><br/>");
+    CActivityTrk::printSummary(summaries, flags, str);
+
+
+    cursor1.insertHtml(str);
+}
+
+
+void CDetailsPrj::drawByGroup(QTextCursor &cursor, QList<CGisItemTrk*>& trks, QList<CGisItemWpt*>& wpts, CProgressDialog& progress, int& n, bool printable)
 {
     int cnt, w = cursor.document()->textWidth();
 
@@ -315,12 +405,7 @@ void CDetailsPrj::drawByGroup(QTextCursor &cursor, QList<CGisItemTrk*>& trks, QL
         cnt = 1;
         foreach(CGisItemWpt * wpt, wpts)
         {
-            progress.setValue(n++ *100.0/nItems);
-            if(progress.wasCanceled())
-            {
-                return;
-            }
-
+            PROGRESS(n++, return );
 
             table->cellAt(cnt,eSym1).firstCursorPosition().insertImage(wpt->getIcon().toImage().scaledToWidth(16, Qt::SmoothTransformation));
             table->cellAt(cnt,eInfo1).firstCursorPosition().insertHtml(wpt->getInfo());
@@ -347,11 +432,7 @@ void CDetailsPrj::drawByGroup(QTextCursor &cursor, QList<CGisItemTrk*>& trks, QL
 
         foreach(CGisItemTrk * trk, trks)
         {
-            progress.setValue(n++ *100.0/nItems);
-            if(progress.wasCanceled())
-            {
-                return;
-            }
+            PROGRESS(n++, return );
 
             table->cellAt(cnt,eSym1).firstCursorPosition().insertImage(trk->getIcon().toImage().scaledToWidth(16, Qt::SmoothTransformation));
 
@@ -405,7 +486,7 @@ struct wpt_info_t
     qreal descend;
 };
 
-void CDetailsPrj::drawByTrack(QTextCursor& cursor, QList<CGisItemTrk *> &trks, QList<CGisItemWpt *> &wpts, QProgressDialog &progress, int &n, int nItems, bool printable)
+void CDetailsPrj::drawByTrack(QTextCursor& cursor, QList<CGisItemTrk *> &trks, QList<CGisItemWpt *> &wpts, CProgressDialog &progress, int &n, bool printable)
 {
     int cnt, w = cursor.document()->textWidth();
 
@@ -455,11 +536,7 @@ void CDetailsPrj::drawByTrack(QTextCursor& cursor, QList<CGisItemTrk *> &trks, Q
 
         foreach(const wpt_info_t &info, wptInfo)
         {
-            progress.setValue(n++ *100.0/nItems);
-            if(progress.wasCanceled())
-            {
-                return;
-            }
+            PROGRESS(n++, return );
 
             CGisItemWpt * wpt = dynamic_cast<CGisItemWpt*>(prj.getItemByKey(info.key));
             if(wpt != 0)
@@ -529,6 +606,66 @@ void CDetailsPrj::drawByTrack(QTextCursor& cursor, QList<CGisItemTrk *> &trks, Q
     }
 }
 
+void CDetailsPrj::drawArea(QTextCursor& cursor, QList<CGisItemOvlArea *> &areas, CProgressDialog &progress, int &n, bool printable)
+{
+    if(areas.isEmpty())
+    {
+        return;
+    }
+    cursor.insertHtml(tr("<h2>Areas</h2>"));
+    QTextTable * table = cursor.insertTable(areas.count()+1, eMax1, fmtTableStandard);
+
+    table->cellAt(0,eSym1).setFormat(fmtCharHeader);
+    table->cellAt(0,eInfo1).setFormat(fmtCharHeader);
+    table->cellAt(0,eComment1).setFormat(fmtCharHeader);
+
+    table->cellAt(0,eInfo1).firstCursorPosition().insertText(tr("Info"));
+    table->cellAt(0,eComment1).firstCursorPosition().insertText(tr("Comment"));
+
+    int cnt = 1;
+    foreach(CGisItemOvlArea * area, areas)
+    {
+        PROGRESS(n++, return );
+
+        table->cellAt(cnt,eSym1).firstCursorPosition().insertImage(area->getIcon().toImage().scaledToWidth(16, Qt::SmoothTransformation));
+        table->cellAt(cnt,eInfo1).firstCursorPosition().insertHtml(area->getInfo());
+        table->cellAt(cnt,eComment1).firstCursorPosition().insertHtml(IGisItem::createText(area->isReadOnly()||printable, area->getComment(), area->getDescription(), area->getLinks(), area->getKey().item));
+        cnt++;
+    }
+
+    cursor.setPosition(table->lastPosition() + 1);
+}
+
+void CDetailsPrj::drawRoute(QTextCursor& cursor, QList<CGisItemRte *> &rtes, CProgressDialog &progress, int &n, bool printable)
+{
+    if(rtes.isEmpty())
+    {
+        return;
+    }
+    cursor.insertHtml(tr("<h2>Routes</h2>"));
+    QTextTable * table = cursor.insertTable(rtes.count()+1, eMax1, fmtTableStandard);
+
+    table->cellAt(0,eSym1).setFormat(fmtCharHeader);
+    table->cellAt(0,eInfo1).setFormat(fmtCharHeader);
+    table->cellAt(0,eComment1).setFormat(fmtCharHeader);
+
+    table->cellAt(0,eInfo1).firstCursorPosition().insertText(tr("Info"));
+    table->cellAt(0,eComment1).firstCursorPosition().insertText(tr("Comment"));
+
+    int cnt = 1;
+    foreach(CGisItemRte * rte, rtes)
+    {
+        PROGRESS(n++, return );
+
+        table->cellAt(cnt,eSym1).firstCursorPosition().insertImage(rte->getIcon().toImage().scaledToWidth(16, Qt::SmoothTransformation));
+        table->cellAt(cnt,eInfo1).firstCursorPosition().insertHtml(rte->getInfo());
+        table->cellAt(cnt,eComment1).firstCursorPosition().insertHtml(IGisItem::createText(rte->isReadOnly()||printable, rte->getComment(), rte->getDescription(), rte->getLinks(), rte->getKey().item));
+        cnt++;
+    }
+
+    cursor.setPosition(table->lastPosition() + 1);
+}
+
 void CDetailsPrj::slotLinkActivated(const QString& link)
 {
     if(link == "name")
@@ -693,6 +830,7 @@ void CDetailsPrj::slotPrint()
 
 void CDetailsPrj::slotLock(bool on)
 {
+    prj.blockUpdateItems(true);
     const int N = prj.childCount();
     for(int n = 0; n < N; n++)
     {
@@ -702,13 +840,14 @@ void CDetailsPrj::slotLock(bool on)
             item->setReadOnlyMode(on);
         }
     }
-
+    prj.blockUpdateItems(false);
     slotSetupGui();
 }
 
 
 void CDetailsPrj::slotSortMode(int idx)
 {
+    comboSort->setEnabled(false);
     prj.setSorting(IGisProject::sorting_e(idx));
     slotSetupGui();
 }
