@@ -27,39 +27,58 @@
 #include "gis/rte/CGisItemRte.h"
 #include "gis/trk/CGisItemTrk.h"
 #include "gis/wpt/CGisItemWpt.h"
+#include "helpers/CProgressDialog.h"
 #include "helpers/CSelectCopyAction.h"
 
 #include <QtWidgets>
 
+const QString IGisProject::filedialogAllSupported = "All Supported (*.gpx *.qms)";
+const QString IGisProject::filedialogFilterGPX    = "GPS Exchange Format (*.gpx)";
+const QString IGisProject::filedialogFilterQMS    = "QMapShack Binary (*.qms)";
+const QString IGisProject::filedialogSaveFilters  = filedialogFilterGPX + ";; " + filedialogFilterQMS;
+const QString IGisProject::filedialogLoadFilters  = filedialogAllSupported +";; " + filedialogFilterGPX + ";; " + filedialogFilterQMS;
+
+
 
 IGisProject::IGisProject(type_e type, const QString &filename, CGisListWks *parent)
     : QTreeWidgetItem(parent)
     , type(type)
     , filename(filename)
-    , valid(false)
-    , noUpdate(false)
-    , noCorrelation(false)
-    , sorting(eSortNone)
-    , cntTrkPts(0)
-    , cntWpts(0)
 {
     memset(cntItemsByType, 0, sizeof(cntItemsByType));
     setCheckState(CGisListWks::eColumnDecoration, Qt::Checked);
+
+    if(parent)
+    {
+        // move project up the list until there a re only projects, no devices
+        int newIdx      = NOIDX;
+        const int myIdx = parent->topLevelItemCount() - 1;
+        for(int i = myIdx - 1; i >= 0; i--)
+        {
+            IDevice * device = dynamic_cast<IDevice*>(parent->topLevelItem(i));
+            if(device != 0)
+            {
+                newIdx = i;
+                continue;
+            }
+            break;
+        }
+
+        if(newIdx != NOIDX)
+        {
+            parent->takeTopLevelItem(myIdx);
+            parent->insertTopLevelItem(newIdx, this);
+        }
+    }
 }
 
 IGisProject::IGisProject(type_e type, const QString &filename, IDevice *parent)
     : QTreeWidgetItem(parent)
     , type(type)
     , filename(filename)
-    , valid(false)
-    , noUpdate(false)
-    , noCorrelation(false)
-    , sorting(eSortNone)
-    , cntTrkPts(0)
-    , cntWpts(0)
 {
+    memset(cntItemsByType, 0, sizeof(cntItemsByType));
     setCheckState(CGisListWks::eColumnDecoration, Qt::Checked);
-
     nameSuffix = parent->getName();
 }
 
@@ -74,9 +93,9 @@ bool IGisProject::askBeforClose()
     int res = QMessageBox::Ok;
     if(isChanged())
     {
-        QApplication::setOverrideCursor(Qt::ArrowCursor);
-        res = QMessageBox::question(&CMainWindow::self(), QObject::tr("Save project?"), QObject::tr("The project \"%1\" was changed. Save befor closing it?").arg(getName()), QMessageBox::Save|QMessageBox::No|QMessageBox::Abort, QMessageBox::No);
-        QApplication::restoreOverrideCursor();
+        CCanvas::setOverrideCursor(Qt::ArrowCursor, "askBeforClose");
+        res = QMessageBox::question(CMainWindow::getBestWidgetForParent(), QObject::tr("Save project?"), QObject::tr("<h3>%1</h3>The project was changed. Save before closing it?").arg(getName()), QMessageBox::Save|QMessageBox::No|QMessageBox::Abort, QMessageBox::No);
+        CCanvas::restoreOverrideCursor("askBeforClose");
 
         if(res == QMessageBox::Save)
         {
@@ -188,6 +207,8 @@ void IGisProject::setChanged()
 void IGisProject::switchOnCorrelation()
 {
     noCorrelation = false;
+    hashTrkWpt[0].clear();
+    hashTrkWpt[1].clear();
     updateItems();
 }
 
@@ -205,23 +226,26 @@ void IGisProject::updateItems()
         return;
     }
 
-    quint32 total = cntTrkPts * cntWpts;
+    if(hashTrkWpt[0] == hashTrkWpt[1])
+    {
+        return;
+    }
+
+    quint32 total   = cntTrkPts * cntWpts;
     quint32 current = 0;
 
-    QProgressDialog progress(QObject::tr("%1: Correlate tracks and waypoints.").arg(getName()), QObject::tr("Abort"), 0, 100, &CMainWindow::self());
-    progress.setWindowModality(Qt::WindowModal);
-    progress.setMinimumDuration(1000);
+    PROGRESS_SETUP(QObject::tr("%1: Correlate tracks and waypoints.").arg(getName()), 0, total, CMainWindow::getBestWidgetForParent());
 
     for(int i = 0; i < childCount(); i++)
     {
         CGisItemTrk * trk = dynamic_cast<CGisItemTrk*>(child(i));
         if(trk)
         {
-            trk->findWaypointsCloseBy(progress, current, total);
+            trk->findWaypointsCloseBy(progress, current);
             if(progress.wasCanceled())
             {
-                QString msg = QObject::tr("Did that take too long for you? Do you want to skip correlation of tracks and waypoints for this project (%1) in the future?").arg(getNameEx());
-                int res = QMessageBox::question(&CMainWindow::self(), QObject::tr("Cancelled correlation..."), msg, QMessageBox::Yes|QMessageBox::No, QMessageBox::Yes);
+                QString msg = QObject::tr("<h3>%1</h3>Did that take too long for you? Do you want to skip correlation of tracks and waypoints for this project in the future?").arg(getNameEx());
+                int res = QMessageBox::question(&progress, QObject::tr("Canceled correlation..."), msg, QMessageBox::Yes|QMessageBox::No, QMessageBox::Yes);
                 noCorrelation = res == QMessageBox::Yes;
                 break;
             }
@@ -235,7 +259,7 @@ void IGisProject::setupName(const QString &defaultName)
     {
         metadata.name = defaultName;
     }
-    setText(CGisListWks::eColumnName, getNameEx());
+    setText(CGisListWks::eColumnName, getName());
 }
 
 void IGisProject::markAsSaved()
@@ -397,7 +421,7 @@ bool IGisProject::delItemByKey(const IGisItem::key_t& key, QMessageBox::Standard
             if(last != QMessageBox::YesToAll)
             {
                 QString msg = QObject::tr("Are you sure you want to delete '%1' from project '%2'?").arg(item->getName()).arg(text(CGisListWks::eColumnName));
-                last = QMessageBox::question(&CMainWindow::self(), QObject::tr("Delete..."), msg, QMessageBox::YesToAll|QMessageBox::Cancel|QMessageBox::Ok|QMessageBox::No, QMessageBox::Ok);
+                last = QMessageBox::question(CMainWindow::getBestWidgetForParent(), QObject::tr("Delete..."), msg, QMessageBox::YesToAll|QMessageBox::Cancel|QMessageBox::Ok|QMessageBox::No, QMessageBox::Ok);
                 if((last == QMessageBox::No) || (last == QMessageBox::Cancel))
                 {
                     // as each item in the project has to be unique, we can stop searching.
@@ -407,7 +431,7 @@ bool IGisProject::delItemByKey(const IGisItem::key_t& key, QMessageBox::Standard
             delete item;
 
             /*
-                Database projects are a bit different. Deleteing an item does not really
+                Database projects are a bit different. Deleting an item does not really
                 mean the project is changed as the item is still stored in the database.
              */
             if(type != eTypeDb)
@@ -453,7 +477,7 @@ void IGisProject::insertCopyOfItem(IGisItem * item, int off, int& lastResult)
         int result = lastResult;
         if(lastResult == CSelectCopyAction::eResultNone)
         {
-            CSelectCopyAction dlg(item, item2, &CMainWindow::self());
+            CSelectCopyAction dlg(item, item2, CMainWindow::getBestWidgetForParent());
             dlg.exec();
             result = dlg.getResult();
             if(dlg.allOthersToo())
@@ -667,6 +691,16 @@ void IGisProject::updateItemCounters()
     memset(cntItemsByType, 0, sizeof(cntItemsByType));
     cntTrkPts = 0;
     cntWpts = 0;
+    totalDistance = 0;
+    totalAscend = 0;
+    totalDescend = 0;
+    totalElapsedSeconds = 0;
+    totalElapsedSecondsMoving = 0;
+
+    QByteArray buffer;
+    QDataStream stream(&buffer, QIODevice::WriteOnly);
+    stream.setByteOrder(QDataStream::LittleEndian);
+    stream.setVersion(QDataStream::Qt_5_2);
 
     for(int i = 0; i < childCount(); i++)
     {
@@ -681,15 +715,27 @@ void IGisProject::updateItemCounters()
         CGisItemTrk * trk = dynamic_cast<CGisItemTrk*>(item);
         if(trk)
         {
-            cntTrkPts += trk->getNumberOfVisiblePoints();
+            cntTrkPts       += trk->getNumberOfVisiblePoints();
+            totalDistance   += trk->getTotalDistance();
+            totalAscend     += trk->getTotalAscend();
+            totalDescend    += trk->getTotalDescend();
+            totalElapsedSeconds += trk->getTotalElapsedSeconds();
+            totalElapsedSecondsMoving += trk->getTotalElapsedSecondsMoving();
+            stream << trk->getHash();
         }
 
         CGisItemWpt * wpt = dynamic_cast<CGisItemWpt*>(item);
         if(wpt)
         {
             cntWpts++;
+            stream << wpt->getHash();
         }
     }
+    QCryptographicHash md5(QCryptographicHash::Md5);
+    md5.addData(buffer);
+
+    hashTrkWpt[1] = hashTrkWpt[0];
+    hashTrkWpt[0] = md5.result().toHex();
 }
 
 void IGisProject::blockUpdateItems(bool yes)
