@@ -26,14 +26,15 @@
 
 #include <QtWidgets>
 
-#define VER_TRK         quint8(1)
+#define VER_TRK         quint8(2)
 #define VER_WPT         quint8(2)
-#define VER_RTE         quint8(1)
+#define VER_RTE         quint8(2)
 #define VER_AREA        quint8(1)
 #define VER_LINK        quint8(1)
 #define VER_TRKSEG      quint8(1)
-#define VER_TRKPT       quint8(1)
-#define VER_RTEPT       quint8(1)
+#define VER_TRKPT       quint8(2)
+#define VER_RTEPT       quint8(2)
+#define VER_RTESUBPT    quint8(1)
 #define VER_WPT_T       quint8(1)
 #define VER_GC_T        quint8(1)
 #define VER_GCLOG_T     quint8(1)
@@ -163,6 +164,30 @@ QDataStream& operator>>(QDataStream& stream, IGisItem::history_t& h)
     stream >> h.histIdxInitial;
     stream >> h.histIdxCurrent;
     stream >> h.events;
+
+    if(h.histIdxCurrent >= h.events.size())
+    {
+        h.histIdxCurrent = h.events.size() - 1;
+    }
+
+    if(h.histIdxInitial >= h.events.size())
+    {
+        h.histIdxInitial = h.events.size() - 1;
+    }
+
+    if(h.histIdxCurrent < 0)
+    {
+        h.histIdxInitial = NOIDX;
+        h.histIdxCurrent = NOIDX;
+        h.events.clear();
+    }
+    if(h.histIdxInitial < 0)
+    {
+        h.histIdxInitial = NOIDX;
+        h.histIdxCurrent = NOIDX;
+        h.events.clear();
+    }
+
     return stream;
 }
 
@@ -314,6 +339,7 @@ QDataStream& operator<<(QDataStream& stream, const CGisItemTrk::trkpt_t& pt)
 {
     stream << VER_TRKPT << pt.flags;
     stream << (const IGisItem::wpt_t&)pt;
+    stream << pt.extensions;
     return stream;
 }
 
@@ -322,6 +348,48 @@ QDataStream& operator>>(QDataStream& stream, CGisItemTrk::trkpt_t& pt)
     quint8 version;
     stream >> version >> pt.flags;
     stream >> (IGisItem::wpt_t&)pt;
+    if(version > 1)
+    {
+        stream >> pt.extensions;
+    }
+    return stream;
+}
+
+QDataStream& operator<<(QDataStream& stream, const CGisItemRte::subpt_t& pt)
+{
+    stream << VER_RTESUBPT;
+    stream << pt.lon;
+    stream << pt.lat;
+    stream << pt.type;
+
+    stream << pt.turn;
+    stream << pt.bearing;
+    stream << pt.streets;
+
+    stream << pt.instruction;
+    stream << pt.distance;
+    stream << pt.time;
+
+    return stream;
+}
+
+QDataStream& operator>>(QDataStream& stream, CGisItemRte::subpt_t& pt)
+{
+    quint8 version;
+
+    stream >> version;
+    stream >> pt.lon;
+    stream >> pt.lat;
+    stream >> pt.type;
+
+    stream >> pt.turn;
+    stream >> pt.bearing;
+    stream >> pt.streets;
+
+    stream >> pt.instruction;
+    stream >> pt.distance;
+    stream >> pt.time;
+
     return stream;
 }
 
@@ -329,6 +397,8 @@ QDataStream& operator<<(QDataStream& stream, const CGisItemRte::rtept_t& pt)
 {
     stream << VER_RTEPT << pt.focus << pt.icon;
     stream << (const IGisItem::wpt_t&)pt;
+    stream << pt.fakeSubpt;
+    stream << pt.subpts;
     return stream;
 }
 
@@ -337,6 +407,11 @@ QDataStream& operator>>(QDataStream& stream, CGisItemRte::rtept_t& pt)
     quint8 version;
     stream >> version >> pt.focus >> pt.icon;
     stream >> (IGisItem::wpt_t&)pt;
+    if(version > 1)
+    {
+        stream >> pt.fakeSubpt;
+        stream >> pt.subpts;
+    }
     return stream;
 }
 
@@ -370,7 +445,7 @@ QDataStream& operator>>(QDataStream& stream, IGisProject::person_t& p)
 
 // ---------------- main objects ---------------------------------
 
-QDataStream& CGisItemTrk::operator>>(QDataStream& stream)
+QDataStream& CGisItemTrk::operator>>(QDataStream& stream) const
 {
     QByteArray buffer;
     QDataStream out(&buffer, QIODevice::WriteOnly);
@@ -387,6 +462,11 @@ QDataStream& CGisItemTrk::operator>>(QDataStream& stream)
     out << trk.number;
     out << trk.type;
     out << trk.color;
+
+    out << colorSource;
+    out << limitLow;
+    out << limitHigh;
+
     out << trk.segs;
 
     stream.writeRawData(MAGIC_TRK, MAGIC_SIZE);
@@ -430,14 +510,25 @@ QDataStream& CGisItemTrk::operator<<(QDataStream& stream)
     in >> trk.type;
     in >> trk.color;
 
+    // versions >= 2 contain colorized tracks
+    if(version >= 2)
+    {
+        QString source;
+        in >> colorSource;
+        in >> limitLow;
+        in >> limitHigh;
+    }
+
     trk.segs.clear();
     in >> trk.segs;
 
     deriveSecondaryData();
-    setColor(trk.color);
+    setColor(str2color(trk.color));
     setText(CGisListWks::eColumnName, trk.name);
     setToolTip(CGisListWks::eColumnName, getInfo());
 
+    notifyChange();
+
     return stream;
 }
 
@@ -484,7 +575,7 @@ QDataStream& CGisItemWpt::operator<<(QDataStream& stream)
     return stream;
 }
 
-QDataStream& CGisItemWpt::operator>>(QDataStream& stream)
+QDataStream& CGisItemWpt::operator>>(QDataStream& stream) const
 {
     QByteArray buffer;
     QDataStream out(&buffer, QIODevice::WriteOnly);
@@ -541,6 +632,14 @@ QDataStream& CGisItemRte::operator<<(QDataStream& stream)
     in >> rte.number;
     in >> rte.type;
     in >> rte.pts;
+    if(version > 1)
+    {
+        in >> lastRoutedWith;
+        in >> lastRoutedTime;
+        in >> totalDistance;
+        in >> totalTime;
+    }
+
 
     setSymbol();
     deriveSecondaryData();
@@ -550,7 +649,7 @@ QDataStream& CGisItemRte::operator<<(QDataStream& stream)
     return stream;
 }
 
-QDataStream& CGisItemRte::operator>>(QDataStream& stream)
+QDataStream& CGisItemRte::operator>>(QDataStream& stream) const
 {
     QByteArray buffer;
     QDataStream out(&buffer, QIODevice::WriteOnly);
@@ -567,6 +666,10 @@ QDataStream& CGisItemRte::operator>>(QDataStream& stream)
     out << rte.number;
     out << rte.type;
     out << rte.pts;
+    out << lastRoutedWith;
+    out << lastRoutedTime;
+    out << totalDistance;
+    out << totalTime;
 
     stream.writeRawData(MAGIC_RTE, MAGIC_SIZE);
     stream << VER_RTE;
@@ -616,6 +719,7 @@ QDataStream& CGisItemOvlArea::operator<<(QDataStream& stream)
     area.opacity = tmp8;
 
     deriveSecondaryData();
+
     setColor(str2color(area.color));
     setText(CGisListWks::eColumnName, area.name);
     setToolTip(CGisListWks::eColumnName, getInfo());
@@ -623,7 +727,7 @@ QDataStream& CGisItemOvlArea::operator<<(QDataStream& stream)
     return stream;
 }
 
-QDataStream& CGisItemOvlArea::operator>>(QDataStream& stream)
+QDataStream& CGisItemOvlArea::operator>>(QDataStream& stream) const
 {
     QByteArray buffer;
     QDataStream out(&buffer, QIODevice::WriteOnly);
@@ -728,8 +832,10 @@ QDataStream& IGisProject::operator<<(QDataStream& stream)
             item = new CGisItemOvlArea(history, this);
             break;
 
-        default:;
+        default:
+            ;
         }
+
         if(item && changed)
         {
             item->updateDecoration(IGisItem::eMarkChanged, IGisItem::eMarkNone);
