@@ -16,14 +16,18 @@
 
 **********************************************************************************************/
 
+
 #include "CMainWindow.h"
+#include "GeoMath.h"
 #include "canvas/CCanvas.h"
 #include "gis/CGisDraw.h"
 #include "gis/CGisListWks.h"
 #include "gis/WptIcons.h"
 #include "gis/prj/IGisProject.h"
+#include "gis/rte/CDetailsRte.h"
 #include "gis/rte/CGisItemRte.h"
 #include "gis/rte/CScrOptRte.h"
+#include "helpers/CDraw.h"
 
 #include <QtWidgets>
 #include <QtXml>
@@ -32,17 +36,27 @@
 const QPen CGisItemRte::penBackground(Qt::white, 5, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin);
 IGisItem::key_t CGisItemRte::keyUserFocus;
 
+#define MIN_DIST_FOCUS 200
+
+void CGisItemRte::rtept_t::updateIcon()
+{
+    if(sym.isEmpty())
+    {
+        icon  = QPixmap();
+        focus = NOPOINTF;
+    }
+    else
+    {
+        icon = getWptIconByName(sym, focus);
+    }
+}
 /// used to create a copy of route with new parent
 CGisItemRte::CGisItemRte(const CGisItemRte& parentRte, IGisProject * project, int idx, bool clone)
     : IGisItem(project, eTypeRte, idx)
-    , penForeground(Qt::darkBlue, 3, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin)
-    , lastRoutedCalcTime(0)
-    , totalDistance(NOFLOAT)
-    , totalDays(NOINT)
 {
-    *this = parentRte;
-    key.project = project->getKey();
-    key.device  = project->getDeviceKey();
+    history = parentRte.history;
+    loadHistory(history.histIdxCurrent);
+
 
     if(clone)
     {
@@ -74,10 +88,6 @@ CGisItemRte::CGisItemRte(const CGisItemRte& parentRte, IGisProject * project, in
 /// used to create route from GPX file
 CGisItemRte::CGisItemRte(const QDomNode& xml, IGisProject *parent)
     : IGisItem(parent, eTypeRte, parent->childCount())
-    , penForeground(Qt::darkBlue, 3, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin)
-    , lastRoutedCalcTime(0)
-    , totalDistance(NOFLOAT)
-    , totalDays(NOINT)
 {
     // --- start read and process data ----
     readRte(xml, rte);
@@ -90,10 +100,6 @@ CGisItemRte::CGisItemRte(const QDomNode& xml, IGisProject *parent)
 
 CGisItemRte::CGisItemRte(const history_t& hist, IGisProject * project)
     : IGisItem(project, eTypeRte, project->childCount())
-    , penForeground(Qt::darkBlue, 3, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin)
-    , lastRoutedCalcTime(0)
-    , totalDistance(NOFLOAT)
-    , totalDays(NOINT)
 {
     history = hist;
     loadHistory(hist.histIdxCurrent);
@@ -102,20 +108,12 @@ CGisItemRte::CGisItemRte(const history_t& hist, IGisProject * project)
 
 CGisItemRte::CGisItemRte(quint64 id, QSqlDatabase& db, IGisProject * project)
     : IGisItem(project, eTypeRte, NOIDX)
-    , penForeground(Qt::darkBlue, 3, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin)
-    , lastRoutedCalcTime(0)
-    , totalDistance(NOFLOAT)
-    , totalDays(NOINT)
 {
     loadFromDb(id, db);
 }
 
 CGisItemRte::CGisItemRte(const SGisLine &l, const QString &name, IGisProject *project, int idx)
     : IGisItem(project, eTypeRte, idx)
-    , penForeground(Qt::darkBlue, 3, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin)
-    , lastRoutedCalcTime(0)
-    , totalDistance(NOFLOAT)
-    , totalDays(NOINT)
 {
     rte.name = name;
     readRouteDataFromGisLine(l);
@@ -128,6 +126,25 @@ CGisItemRte::CGisItemRte(const SGisLine &l, const QString &name, IGisProject *pr
 
 CGisItemRte::~CGisItemRte()
 {
+    // reset user focus if focused on this track
+    if(key == keyUserFocus)
+    {
+        keyUserFocus.clear();
+    }
+}
+
+bool CGisItemRte::isCalculated()
+{
+    bool yes = true;
+    foreach(const rtept_t &pt, rte.pts)
+    {
+        if((pt.fakeSubpt.lat == NOFLOAT) || (pt.fakeSubpt.lon == NOFLOAT))
+        {
+            yes = false;
+        }
+    }
+
+    return yes;
 }
 
 void CGisItemRte::deriveSecondaryData()
@@ -137,8 +154,12 @@ void CGisItemRte::deriveSecondaryData()
     qreal south =  90;
     qreal west  =  180;
 
-    foreach(const rtept_t &rtept, rte.pts)
+    //foreach(const rtept_t &rtept, rte.pts)
+    const int N = rte.pts.count();
+
+    for(int i = 0; i < N; i++)
     {
+        rtept_t &rtept = rte.pts[i];
         if(rtept.lon < west)
         {
             west    = rtept.lon;
@@ -175,17 +196,31 @@ void CGisItemRte::deriveSecondaryData()
                 north   = subpt.lat;
             }
         }
+        rtept.updateIcon();
     }
 
     boundingRect = QRectF(QPointF(west * DEG_TO_RAD, north * DEG_TO_RAD), QPointF(east * DEG_TO_RAD,south * DEG_TO_RAD));
 }
 
+void CGisItemRte::edit()
+{
+    CDetailsRte dlg(*this, CMainWindow::getBestWidgetForParent());
+    dlg.exec();
+}
+
 void CGisItemRte::setSymbol()
 {
     icon = QPixmap("://icons/32x32/Route.png").scaled(22,22, Qt::KeepAspectRatio, Qt::SmoothTransformation);
     setIcon(CGisListWks::eColumnIcon, icon);
 }
 
+void CGisItemRte::setName(const QString& str)
+{
+    setText(CGisListWks::eColumnName, str);
+    rte.name = str;
+    changed(QObject::tr("Changed name."), "://icons/48x48/EditText.png");
+}
+
 void CGisItemRte::setComment(const QString& str)
 {
     rte.cmt = str;
@@ -232,16 +267,10 @@ QString CGisItemRte::getInfo(bool allowEdit) const
     }
 
     str += "<br/>\n";
-    if(totalTime.isValid())
+    if(totalTime != 0)
     {
-        if(totalDays != 0 && totalDays != NOINT)
-        {
-            str += QObject::tr("Time: %2 days %1").arg(totalTime.toString()).arg(totalDays);
-        }
-        else
-        {
-            str += QObject::tr("Time: %1").arg(totalTime.toString());
-        }
+        IUnit::self().seconds2time(totalTime, val1, unit1);
+        str += QObject::tr("Time: %1 %2").arg(val1).arg(unit1);
     }
     else
     {
@@ -254,19 +283,23 @@ QString CGisItemRte::getInfo(bool allowEdit) const
         str += QObject::tr("Last time routed:<br/>%1").arg(IUnit::datetime2string(lastRoutedTime, false, boundingRect.center()));
         str += "<br/>\n";
         str += QObject::tr("with %1").arg(lastRoutedWith);
-        str += "<br/>\n";
-        str += QObject::tr("Calculation took %1 sec.").arg(lastRoutedCalcTime/1000.0, 0, 'f', 2);
     }
     return str;
 }
 
 IScrOpt * CGisItemRte::getScreenOptions(const QPoint& origin, IMouse * mouse)
 {
-    return new CScrOptRte(this, origin, mouse);
+    if(scrOpt.isNull())
+    {
+        scrOpt = new CScrOptRte(this, origin, mouse);
+    }
+    return scrOpt;
 }
 
 QPointF CGisItemRte::getPointCloseBy(const QPoint& screenPos)
 {
+    QMutexLocker lock(&mutexItems);
+
     qint32 d    = NOINT;
     QPointF pt  = NOPOINTF;
     foreach(const QPointF &point, line)
@@ -286,15 +319,10 @@ QPointF CGisItemRte::getPointCloseBy(const QPoint& screenPos)
 
 bool CGisItemRte::isCloseTo(const QPointF& pos)
 {
-    foreach(const QPointF &pt, line)
-    {
-        if((pt - pos).manhattanLength() < 10)
-        {
-            return true;
-        }
-    }
+    QMutexLocker lock(&mutexItems);
 
-    return false;
+    qreal dist = GPS_Math_DistPointPolyline(line, pos);
+    return dist < 20;
 }
 
 void CGisItemRte::gainUserFocus(bool yes)
@@ -303,8 +331,20 @@ void CGisItemRte::gainUserFocus(bool yes)
 }
 
 
+void CGisItemRte::looseUserFocus()
+{
+    if(keyUserFocus == key)
+    {
+        keyUserFocus.clear();
+    }
+}
+
+
+
 void CGisItemRte::drawItem(QPainter& p, const QPolygonF& viewport, QList<QRectF> &blockedAreas, CGisDraw *gis)
 {
+    QMutexLocker lock(&mutexItems);
+
     line.clear();
     if(!isVisible(boundingRect, viewport, gis))
     {
@@ -317,7 +357,9 @@ void CGisItemRte::drawItem(QPainter& p, const QPolygonF& viewport, QList<QRectF>
     gis->convertRad2Px(p2);
     QRectF extViewport(p1,p2);
 
-    QVector<qint32> points;
+    QVector<qint32>  points;
+    QVector<QPixmap> icons;
+    QVector<QPointF> focus;
 
     foreach(const rtept_t &rtept, rte.pts)
     {
@@ -327,6 +369,8 @@ void CGisItemRte::drawItem(QPainter& p, const QPolygonF& viewport, QList<QRectF>
 
         line << pt;
         points << 1;
+        icons << rtept.icon;
+        focus << rtept.focus;
 
         blockedAreas << QRectF(pt - rtept.focus, rtept.icon.size());
         foreach(const subpt_t &subpt, rtept.subpts)
@@ -364,19 +408,24 @@ void CGisItemRte::drawItem(QPainter& p, const QPolygonF& viewport, QList<QRectF>
         }
     }
 
-    p.setPen(penForeground);
-    p.setBrush(penForeground.color());
-    drawArrows(line, extViewport, p);
+    p.setPen(hasUserFocus() ? penForegroundFocus : penForeground);
+    p.setBrush(hasUserFocus() ? penForegroundFocus.color() : penForeground.color());
+    CDraw::arrows(line, extViewport, p, 10, 80);
     p.drawPolyline(line);
 
     p.setPen(Qt::NoPen);
-    for(int i = 0; i < line.size(); i++)
+    for(int i = 0, n = 0; i < line.size(); i++)
     {
         switch(points[i])
         {
         case 1:
             p.setBrush(Qt::red);
             p.drawEllipse(line[i],5,5);
+            if(focus[n] != NOPOINTF)
+            {
+                p.drawPixmap(line[i] - focus[n], icons[n]);
+            }
+            n++;
             break;
 
         case 2:
@@ -387,8 +436,49 @@ void CGisItemRte::drawItem(QPainter& p, const QPolygonF& viewport, QList<QRectF>
     }
 }
 
+void CGisItemRte::drawItem(QPainter& p, const QRectF& viewport, CGisDraw * gis)
+{
+    QMutexLocker lock(&mutexItems);
+    if(rte.pts.isEmpty())
+    {
+        return;
+    }
+
+    if(hasUserFocus() && mouseMoveFocus && mouseMoveFocus->lon != NOFLOAT && mouseMoveFocus->lat != NOFLOAT)
+    {
+        QPointF anchor(mouseMoveFocus->lon, mouseMoveFocus->lat);
+        anchor *= DEG_TO_RAD;
+        gis->convertRad2Px(anchor);
+        p.drawEllipse(anchor, 5, 5);
+
+        QString str, val, unit;
+        IUnit::self().seconds2time(mouseMoveFocus->time, val, unit);
+        str += QObject::tr("Time: %1 %2").arg(val).arg(unit) + " ";
+        IUnit::self().meter2distance(mouseMoveFocus->distance, val, unit);
+        str += QObject::tr("Distance: %1 %2").arg(val).arg(unit);
+        str += "\n" + mouseMoveFocus->instruction;
+
+        // calculate bounding box of text
+        QFont f = CMainWindow::self().getMapFont();
+        QFontMetrics fm(f);
+        QRect rectText = fm.boundingRect(QRect(0,0,500,0), Qt::AlignLeft|Qt::AlignTop|Qt::TextWordWrap, str);
+        rectText.adjust(-5, -5, 5, 5);
+        rectText.moveBottomLeft(anchor.toPoint() + QPoint(-50,-50));
+
+        p.setFont(f);
+        CDraw::bubble(p, rectText, anchor.toPoint(), 18 /* px */, 21 /* px */);
+
+        p.save();
+        p.translate(5,5);
+        p.setPen(Qt::darkBlue);
+        p.drawText(rectText, str);
+        p.restore();
+    }
+}
+
 void CGisItemRte::drawLabel(QPainter& p, const QPolygonF& viewport, QList<QRectF> &blockedAreas, const QFontMetricsF &fm, CGisDraw *gis)
 {
+    QMutexLocker lock(&mutexItems);
     if(!isVisible(boundingRect, viewport, gis))
     {
         return;
@@ -429,14 +519,16 @@ void CGisItemRte::drawLabel(QPainter& p, const QPolygonF& viewport, QList<QRectF
             }
         }
 
-        CCanvas::drawText(rtept.name, p, rect.toRect(), Qt::darkBlue);
+        CDraw::text(rtept.name, p, rect.toRect(), Qt::darkBlue);
         blockedAreas << rect;
     }
 }
 
 void CGisItemRte::drawHighlight(QPainter& p)
 {
-    if(line.isEmpty())
+    QMutexLocker lock(&mutexItems);
+
+    if(line.isEmpty() || hasUserFocus())
     {
         return;
     }
@@ -471,7 +563,8 @@ void CGisItemRte::readRouteDataFromGisLine(const SGisLine &l)
 
 void CGisItemRte::setDataFromPolyline(const SGisLine &l)
 {
-//    delete dlgDetails;
+    QMutexLocker lock(&mutexItems);
+    mouseMoveFocus = 0;
 
     readRouteDataFromGisLine(l);
 
@@ -481,6 +574,7 @@ void CGisItemRte::setDataFromPolyline(const SGisLine &l)
 
 void CGisItemRte::getPolylineFromData(SGisLine& l)
 {
+    QMutexLocker lock(&mutexItems);
     l.clear();
     foreach(const rtept_t &rtept, rte.pts)
     {
@@ -498,50 +592,128 @@ void CGisItemRte::getPolylineFromData(SGisLine& l)
 
 void CGisItemRte::calc()
 {
+    QMutexLocker lock(&mutexItems);
+    mouseMoveFocus = 0;
     for(int i = 0; i < rte.pts.size(); i++)
     {
         rte.pts[i].subpts.clear();
     }
-    QTime time;
-    time.start();
     CRouterSetup::self().calcRoute(getKey());
-    lastRoutedCalcTime = time.elapsed();
 }
 
 void CGisItemRte::reset()
 {
+    QMutexLocker lock(&mutexItems);
     for(int i = 0; i < rte.pts.size(); i++)
     {
-        rte.pts[i].subpts.clear();
+        rtept_t& pt = rte.pts[i];
+        pt.subpts.clear();
+        pt.fakeSubpt = subpt_t();
     }
 
-    totalDays       = NOINT;
+    mouseMoveFocus  = 0;
     totalDistance   = NOFLOAT;
-    totalTime       = QTime();
+    totalTime       = 0;
     lastRoutedTime  = QDateTime();
     lastRoutedWith  = "";
-    lastRoutedCalcTime = 0;
 
     deriveSecondaryData();
     updateHistory();
+
+    if(key == keyUserFocus)
+    {
+        gainUserFocus(false);
+    }
 }
 
-void CGisItemRte::setResult(T_RoutinoRoute * route, const QString& options)
+
+QPointF CGisItemRte::setMouseFocusByPoint(const QPoint& pt, focusmode_e fmode, const QString &owner)
 {
+    QMutexLocker lock(&mutexItems);
+
+    const subpt_t * newPointOfFocus = 0;
+    quint32 idx = 0;
+
+    if(pt != NOPOINT && GPS_Math_DistPointPolyline(line, pt) < MIN_DIST_FOCUS)
+    {
+        quint32 i = 0;
+        qint32 d1 = NOINT;
+
+        foreach(const QPointF &point, line)
+        {
+            int tmp = (pt - point).manhattanLength();
+            if(tmp <= d1)
+            {
+                idx = i;
+                d1  = tmp;
+            }
+            i++;
+        }
+
+        newPointOfFocus = getSubPtByIndex(idx);
+    }
+
+    if(newPointOfFocus && (newPointOfFocus->type == subpt_t::eTypeNone))
+    {
+        newPointOfFocus = 0;
+    }
+
+
+    mouseMoveFocus = newPointOfFocus;
+
+    return newPointOfFocus ? ((int)idx < line.size() ? line[idx] : NOPOINTF) : NOPOINTF;
+}
+
+const CGisItemRte::subpt_t * CGisItemRte::getSubPtByIndex(quint32 idx)
+{
+    quint32 cnt = 0;
+    foreach(const rtept_t &rtept, rte.pts)
+    {
+        if(cnt == idx)
+        {
+            return &rtept.fakeSubpt;
+        }
+
+        foreach(const subpt_t &subpt, rtept.subpts)
+        {
+            cnt++;
+            if(cnt == idx)
+            {
+                return &subpt;
+            }
+        }
+        cnt++;
+    }
+
+    return 0;
+}
+
+void CGisItemRte::setResult(Routino_Output * route, const QString& options)
+{
+    QMutexLocker lock(&mutexItems);
+
     qint32 idxRtept = -1;
     rtept_t * rtept = 0;
 
-    T_RoutinoRoute * next = route;
+    Routino_Output * next = route;
     while(next)
     {
-        if(next->type == IMP_WAYPOINT)
+        if(next->type == ROUTINO_POINT_WAYPOINT)
         {
             idxRtept++;
             rtept = &rte.pts[idxRtept];
             rtept->subpts.clear();
-        }
+            rtept->fakeSubpt.lon       = next->lon * RAD_TO_DEG;
+            rtept->fakeSubpt.lat       = next->lat * RAD_TO_DEG;
 
-        if(rtept != 0)
+            rtept->fakeSubpt.turn      = next->turn;
+            rtept->fakeSubpt.bearing   = next->bearing;
+            rtept->fakeSubpt.distance  = next->dist * 1000;
+            rtept->fakeSubpt.time      = next->time * 60;
+            rtept->fakeSubpt.type      = subpt_t::eTypeWpt;
+            rtept->fakeSubpt.instruction = QString(next->desc1) + ".\n" + QString(next->desc2) + ".";
+        }
+        else if(rtept != 0)
         {
             rtept->subpts << subpt_t();
             subpt_t& subpt  = rtept->subpts.last();
@@ -550,15 +722,15 @@ void CGisItemRte::setResult(T_RoutinoRoute * route, const QString& options)
 
             subpt.turn      = next->turn;
             subpt.bearing   = next->bearing;
-            subpt.distance  = next->dist;
-            subpt.time      = subpt.time.addSecs(next->time/10);
+            subpt.distance  = next->dist * 1000;
+            subpt.time      = next->time * 60;
 
-            if(next->string != 0)
+            if(next->name != 0)
             {
-                subpt.names << next->string;
+                subpt.streets << next->name;
             }
 
-            if(next->type > IMP_CHANGE)
+            if(next->type > ROUTINO_POINT_CHANGE)
             {
                 subpt.type = subpt_t::eTypeJunct;
             }
@@ -569,7 +741,7 @@ void CGisItemRte::setResult(T_RoutinoRoute * route, const QString& options)
 
             totalDistance = subpt.distance;
             totalTime     = subpt.time;
-            totalDays     = qFloor(next->time/864000);
+            subpt.instruction = QString(next->desc1) + ".\n" + QString(next->desc2) + ".";
         }
 
         next = next->next;
@@ -581,3 +753,153 @@ void CGisItemRte::setResult(T_RoutinoRoute * route, const QString& options)
     deriveSecondaryData();
     updateHistory();
 }
+
+struct maneuver_t
+{
+    QStringList streets;
+    QString instruction;
+    quint32 time;
+    qreal dist;
+    qint32 bearing;
+    qint32 turn;
+};
+
+static const qint32 idx2bearing[] =
+{
+    NOINT
+    , 0
+    , -45
+    , 45
+    , 180
+    , 135
+    , -135
+    , -90
+    , 90
+};
+
+
+void CGisItemRte::setResult(const QDomDocument& xml, const QString &options)
+{
+    QMutexLocker lock(&mutexItems);
+
+    QDomElement response    = xml.firstChildElement("response");
+    QDomElement route       = response.firstChildElement("route");
+
+    // get time of travel
+    QDomElement xmlTime     = route.firstChildElement("time");
+    totalTime = xmlTime.text().toUInt();
+
+
+    // build list of maneuvers
+    QDomNodeList xmlLegs       = route.firstChildElement("legs").elementsByTagName("leg");
+    const qint32 L = xmlLegs.size();
+
+    QList<maneuver_t> maneuvers;
+
+    for(int l = 0; l < L; l++)
+    {
+        QDomNode xmlLeg = xmlLegs.item(l);
+        QDomNodeList xmlManeuvers = xmlLeg.firstChildElement("maneuvers").elementsByTagName("maneuver");
+        const qint32 M = xmlManeuvers.size();
+        for(int m = 0; m < M; m++)
+        {
+            maneuvers << maneuver_t();
+            maneuver_t& maneuver    = maneuvers.last();
+            QDomNode xmlManeuver    = xmlManeuvers.item(m);
+            maneuver.instruction    = xmlManeuver.firstChildElement("narrative").text();
+            maneuver.time           = xmlManeuver.firstChildElement("time").text().toUInt();
+            maneuver.dist           = xmlManeuver.firstChildElement("distance").text().toFloat();
+
+            maneuver.bearing        = idx2bearing[xmlManeuver.firstChildElement("direction").text().toUInt()];
+            maneuver.turn           = xmlManeuver.firstChildElement("turnType").text().toInt();
+
+            QDomNodeList xmlStreets = xmlManeuver.toElement().elementsByTagName("streets");
+            const int S = xmlStreets.size();
+            for(int s = 0; s < S; s++)
+            {
+                QDomNode xmlStreet = xmlStreets.item(s);
+                maneuver.streets << xmlStreet.toElement().text();
+            }
+        }
+    }
+
+    QVector<subpt_t> shape;
+
+    // read the shape
+    QDomElement xmlShape        = route.firstChildElement("shape");
+    QDomElement xmlShapePoints  = xmlShape.firstChildElement("shapePoints");
+    QDomNodeList xmlLatLng      = xmlShapePoints.elementsByTagName("latLng");
+    const qint32 N = xmlLatLng.size();
+    for(int n = 0; n < N; n++)
+    {
+        QDomNode elem   = xmlLatLng.item(n);
+        QDomElement lat = elem.firstChildElement("lat");
+        QDomElement lng = elem.firstChildElement("lng");
+
+        shape << subpt_t();
+        subpt_t& subpt = shape.last();
+        subpt.lon = lng.text().toFloat();
+        subpt.lat = lat.text().toFloat();
+    }
+
+
+    QVector<quint32> idxLegs;
+    QDomElement xmlLegIndexes = xmlShape.firstChildElement("legIndexes");
+    QDomNodeList xmlIndex     = xmlLegIndexes.elementsByTagName("index");
+    const qint32 I = xmlIndex.size();
+    for(int i = 0; i < I; i++)
+    {
+        QDomNode elem = xmlIndex.item(i);
+        idxLegs << elem.toElement().text().toUInt();
+    }
+
+    quint32 time = 0;
+    quint32 dist = 0;
+    QDomElement xmlManeuverIndexes = xmlShape.firstChildElement("maneuverIndexes");
+    xmlIndex                       = xmlManeuverIndexes.elementsByTagName("index");
+    qint32 M = xmlIndex.size();
+    for(int m = 0; m < M; m++)
+    {
+        QDomNode elem           = xmlIndex.item(m);
+        quint32 idx             = elem.toElement().text().toUInt();
+        subpt_t& subpt          = shape[idx];
+        maneuver_t& maneuver    = maneuvers[m];
+        subpt.type              = subpt_t::eTypeJunct;
+        subpt.instruction       = maneuver.instruction;
+
+        subpt.time              = time;
+        time += maneuver.time;
+
+        subpt.distance          = dist;
+        dist += maneuver.dist * 1000;
+
+        subpt.bearing           = maneuver.bearing;
+        subpt.turn              = maneuver.turn;
+
+        subpt.streets           = maneuver.streets;
+    }
+
+    for(int i = 0; i < rte.pts.size() - 1; i++ )
+    {
+        quint32 idx1 = idxLegs[i];
+        quint32 idx2 = idxLegs[i+1];
+
+        rtept_t& rtept      = rte.pts[i];
+        rtept.subpts        = shape.mid(idx1, idx2 - idx1 + 1);
+        rtept.fakeSubpt.lon = rtept.lon;
+        rtept.fakeSubpt.lat = rtept.lat;
+    }
+
+    rtept_t& rtept = rte.pts.last();
+    rtept.fakeSubpt.lon = rtept.lon;
+    rtept.fakeSubpt.lat = rtept.lat;
+
+    totalDistance  = dist;
+    lastRoutedTime = QDateTime::currentDateTimeUtc();
+    lastRoutedWith = "MapQuest" + options;
+
+    deriveSecondaryData();
+    updateHistory();
+}
+
+
