@@ -24,61 +24,73 @@
 #include <routino.h>
 
 #include <QPen>
+#include <QPointer>
 
 class QDomNode;
 class IGisProject;
 class CQlgtRoute;
+class CScrOptRte;
 
 class CGisItemRte : public IGisItem, public IGisLine
 {
 public:
+
+    enum focusmode_e
+    {
+        eFocusMouseMove
+        ,eFocusMouseClick
+    };
+
     struct subpt_t
     {
-        subpt_t() : lon(NOFLOAT), lat(NOFLOAT), time(0,0)
-        {
-        }
-
         enum type_e
         {
             eTypeNone
+            , eTypeWpt
             , eTypeJunct
         };
 
-        qreal lon;
-        qreal lat;
-        quint8 type;
+        qreal lon = NOFLOAT;
+        qreal lat = NOFLOAT;
+        quint8 type = eTypeNone;
 
-        qreal turn;
-        qreal bearing;
-        QStringList names;
+        qreal turn = NOFLOAT;
+        qreal bearing = NOFLOAT;
+        QStringList streets;
 
-        qreal distance;
-        QTime time;
+        QString instruction;
+        qreal distance = 0;
+        quint32 time = 0;
     };
 
     struct rtept_t : public wpt_t
     {
+        rtept_t()
+        {
+            fakeSubpt.type = subpt_t::eTypeWpt;
+        }
+
+        void updateIcon();
+
         QPixmap icon;
         QPointF focus;
+
+        subpt_t fakeSubpt;
         QVector<subpt_t> subpts;
     };
 
     struct rte_t
     {
-        rte_t() : number(0)
-        {
-        }
         // -- all gpx tags - start
         QString name;
         QString cmt;
         QString desc;
         QString src;
         QList<link_t> links;
-        quint64 number;
+        quint64 number = 0;
         QString type;
         QVector<rtept_t> pts;
         // -- all gpx tags - stop
-        QMap<QString, QVariant> extensions;
     };
 
     CGisItemRte(const QDomNode &xml, IGisProject *parent);
@@ -90,21 +102,56 @@ public:
     virtual ~CGisItemRte();
 
     QDataStream& operator<<(QDataStream& stream);
-    QDataStream& operator>>(QDataStream& stream);
+    QDataStream& operator>>(QDataStream& stream) const;
 
     const QString& getName() const
     {
-        return rte.name;
+        return rte.name.isEmpty() ? noName : rte.name;
     }
+
     QString getInfo(bool allowEdit = false) const;
     IScrOpt * getScreenOptions(const QPoint &origin, IMouse * mouse);
     QPointF getPointCloseBy(const QPoint& screenPos);
     void drawItem(QPainter& p, const QPolygonF& viewport, QList<QRectF>& blockedAreas, CGisDraw * gis);
+    void drawItem(QPainter& p, const QRectF& viewport, CGisDraw * gis);
     void drawLabel(QPainter& p, const QPolygonF& viewport, QList<QRectF>& blockedAreas, const QFontMetricsF& fm, CGisDraw * gis);
     void drawHighlight(QPainter& p);
     void save(QDomNode& gpx);
     bool isCloseTo(const QPointF& pos);
+    /**
+       @brief Switch user focus on and off.
+
+       If the focus is switched on any other route having the focus will loose it.
+
+       @param yes   set true to gain focus.
+     */
     void gainUserFocus(bool yes);
+    /**
+       @brief Make sure the route has lost focus.
+
+       If the route has the focus, keyUserFocus will be reset. In all other cases nothing will be done.
+
+     */
+    void looseUserFocus();
+    /**
+       @brief Check for user focus
+
+       @return True if the route has user focus
+     */
+    bool hasUserFocus() const
+    {
+        return key == keyUserFocus;
+    }
+
+    /**
+       @brief Get the key of the current track with user focus
+
+       @return If no route has the focus an empty string is returned
+     */
+    static const key_t& getKeyUserFocus()
+    {
+        return keyUserFocus;
+    }
 
     void setDataFromPolyline(const SGisLine& l);
 
@@ -123,6 +170,12 @@ public:
         return rte.links;
     }
 
+    const rte_t& getRoute() const
+    {
+        return rte;
+    }
+
+    void setName(const QString& str);
     void setComment(const QString& str);
     void setDescription(const QString& str);
     void setLinks(const QList<link_t>& links);
@@ -131,29 +184,40 @@ public:
 
     void reset();
 
-    void setResult(T_RoutinoRoute * route, const QString &options);
+    void edit();
+
+    QPointF setMouseFocusByPoint(const QPoint& pt, focusmode_e fmode, const QString &owner);
+
+    void setResult(Routino_Output * route, const QString &options);
+    void setResult(const QDomDocument& xml, const QString &options);
+
+    bool isCalculated();
 
 private:
     void deriveSecondaryData();
     void setSymbol();
     void readRte(const QDomNode& xml, rte_t& rte);
     void readRouteDataFromGisLine(const SGisLine &l);
+    const subpt_t * getSubPtByIndex(quint32 idx);
 
     static key_t keyUserFocus;
 
     static const QPen penBackground;
-    QPen penForeground;
+    QPen penForeground {Qt::darkBlue, 3, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin};
+    QPen penForegroundFocus {Qt::magenta, 3, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin};
 
     rte_t rte;
     QPolygonF line;
 
     QString lastRoutedWith;
     QDateTime lastRoutedTime;
-    quint32 lastRoutedCalcTime;
 
-    qreal totalDistance;
-    QTime totalTime;
-    quint32 totalDays;
+    qreal totalDistance = NOFLOAT;
+    quint32 totalTime = 0;
+
+    const subpt_t * mouseMoveFocus = 0;
+
+    QPointer<CScrOptRte>  scrOpt;
 };
 
 #endif //CGISITEMRTE_H
