@@ -21,6 +21,7 @@
 #include "gis/CGisWidget.h"
 #include "gis/rte/CGisItemRte.h"
 #include "gis/rte/CScrOptRte.h"
+#include "helpers/CDraw.h"
 #include "mouse/IMouse.h"
 
 CScrOptRte::CScrOptRte(CGisItemRte *rte, const QPoint& point, IMouse *parent)
@@ -35,24 +36,51 @@ CScrOptRte::CScrOptRte(CGisItemRte *rte, const QPoint& point, IMouse *parent)
     label->setText(rte->getInfo());
     adjustSize();
 
+    toolInstruction->setEnabled(rte->isCalculated());
+    toolInstruction->setChecked(rte->hasUserFocus());
+
+    bool isOnDevice = rte->isOnDevice();
+    toolEdit->setDisabled(isOnDevice);
+
     anchor = rte->getPointCloseBy(point);
+    if((anchor - point).manhattanLength() > 50)
+    {
+        anchor = point;
+    }
     move(anchor.toPoint() + QPoint(-width()/2,SCR_OPT_OFFSET));
     show();
 
+    connect(toolEditDetails, SIGNAL(clicked()), this, SLOT(hide()));
+    connect(toolDelete, SIGNAL(clicked()), this, SLOT(hide()));
+    connect(toolCopy, SIGNAL(clicked()), this, SLOT(hide()));
+    connect(toolCalc, SIGNAL(clicked()), this, SLOT(hide()));
+    connect(toolReset, SIGNAL(clicked()), this, SLOT(hide()));
+    connect(toolEdit, SIGNAL(clicked()), this, SLOT(hide()));
+    connect(toolInstruction, SIGNAL(toggled(bool)), this, SLOT(hide()));
+
+    connect(toolEditDetails, SIGNAL(clicked()), this, SLOT(slotEditDetails()));
     connect(toolDelete, SIGNAL(clicked()), this, SLOT(slotDelete()));
     connect(toolCopy, SIGNAL(clicked()), this, SLOT(slotCopy()));
     connect(toolCalc, SIGNAL(clicked()), this, SLOT(slotCalc()));
     connect(toolReset, SIGNAL(clicked()), this, SLOT(slotReset()));
     connect(toolEdit, SIGNAL(clicked()), this, SLOT(slotEdit()));
+    connect(toolInstruction, SIGNAL(toggled(bool)), this, SLOT(slotInstruction(bool)));
 }
 
 CScrOptRte::~CScrOptRte()
 {
 }
 
+void CScrOptRte::slotEditDetails()
+{
+    CGisWidget::self().editItemByKey(key);
+    deleteLater();
+}
+
 void CScrOptRte::slotDelete()
 {
     CGisWidget::self().delItemByKey(key);
+    deleteLater();
 }
 
 void CScrOptRte::slotCopy()
@@ -79,6 +107,11 @@ void CScrOptRte::slotEdit()
     deleteLater();
 }
 
+void CScrOptRte::slotInstruction(bool on)
+{
+    CGisWidget::self().focusRteByKey(on, key);
+    deleteLater();
+}
 
 void CScrOptRte::draw(QPainter& p)
 {
@@ -90,6 +123,6 @@ void CScrOptRte::draw(QPainter& p)
     }
     item->drawHighlight(p);
 
-    drawBubble2(anchor, p);
+    CDraw::bubble(p, geometry(), anchor.toPoint());
 }
 
