@@ -22,6 +22,11 @@
 #include "gis/rte/router/IRouter.h"
 #include "ui_IRouterMapQuest.h"
 
+class QNetworkAccessManager;
+class CGisItemRte;
+class QNetworkReply;
+class QTimer;
+
 class CRouterMapQuest : public IRouter, private Ui::IRouterMapQuest
 {
     Q_OBJECT
@@ -30,12 +35,25 @@ public:
     virtual ~CRouterMapQuest();
 
     void calcRoute(const IGisItem::key_t& key);
-    bool calcRoute(const QPointF& p1, const QPointF& p2, QPolygonF& coords)
+    int calcRoute(const QPointF& p1, const QPointF& p2, QPolygonF& coords)
     {
-        return false;
+        return -1;
     }
 
     QString getOptions();
+
+private slots:
+    void slotRequestFinished(QNetworkReply* reply);
+    void slotCloseStatusMsg();
+
+private:
+    void addMapQuestLocations(QDomDocument& xml, QDomElement& locations, CGisItemRte& rte);
+
+    static const QByteArray keyMapQuest;
+
+    QNetworkAccessManager * networkAccessManager;
+
+    QTimer * timerCloseStatusMsg;
 };
 
 #endif //CROUTERMAPQUEST_H
