@@ -30,7 +30,7 @@ public:
     virtual ~IRouter();
 
     virtual void calcRoute(const IGisItem::key_t& key) = 0;
-    virtual bool calcRoute(const QPointF& p1, const QPointF& p2, QPolygonF& coords) = 0;
+    virtual int calcRoute(const QPointF& p1, const QPointF& p2, QPolygonF& coords) = 0;
     virtual bool hasFastRouting()
     {
         return fastRouting;
