@@ -67,7 +67,6 @@ static QStringList writeCompeTime( const QDateTime& t, bool isTrack)
 {
     QStringList result;
     QString dateFormat;
-    QString monthStr;
 
     if(!t.isValid())
     {
@@ -84,56 +83,8 @@ static QStringList writeCompeTime( const QDateTime& t, bool isTrack)
 
     QDateTime timestamp = t.toTimeSpec(Qt::UTC);
 
-    switch(timestamp.date().month())
-    {
-    case 1:
-        monthStr = "Jan";
-        break;
-
-    case 2:
-        monthStr = "Feb";
-        break;
-
-    case 3:
-        monthStr = "Mar";
-        break;
-
-    case 4:
-        monthStr = "Apr";
-        break;
-
-    case 5:
-        monthStr = "May";
-        break;
-
-    case 6:
-        monthStr = "Jun";
-        break;
-
-    case 7:
-        monthStr = "Jul";
-        break;
-
-    case 8:
-        monthStr = "Aug";
-        break;
-
-    case 9:
-        monthStr = "Sep";
-        break;
-
-    case 10:
-        monthStr = "Oct";
-        break;
-
-    case 11:
-        monthStr = "Nov";
-        break;
-
-    case 12:
-        monthStr = "Dec";
-        break;
-    }
+    QString monthStrs[] = { "", "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" };
+    QString monthStr    = monthStrs[timestamp.date().month()];
 
     if(isTrack)
     {
@@ -165,59 +116,24 @@ static QDateTime readCompeTime(QString str, bool isTrack)
 
     if(re.exactMatch(str))
     {
-        QString monthNum;
         QString monthStr = re.cap(2);
 
-        if(monthStr.toUpper() == "JAN")
-        {
-            monthNum = "01";
-        }
-        else if(monthStr.toUpper() == "FEB")
-        {
-            monthNum = "02";
-        }
-        else if(monthStr.toUpper() == "MAR")
-        {
-            monthNum = "03";
-        }
-        else if(monthStr.toUpper() == "APR")
-        {
-            monthNum = "04";
-        }
-        else if(monthStr.toUpper() == "MAY")
-        {
-            monthNum = "05";
-        }
-        else if(monthStr.toUpper() == "JUN")
-        {
-            monthNum = "06";
-        }
-        else if(monthStr.toUpper() == "JUL")
-        {
-            monthNum = "07";
-        }
-        else if(monthStr.toUpper() == "AUG")
-        {
-            monthNum = "08";
-        }
-        else if(monthStr.toUpper() == "SEP")
-        {
-            monthNum = "09";
-        }
-        else if(monthStr.toUpper() == "OCT")
-        {
-            monthNum = "10";
-        }
-        else if(monthStr.toUpper() == "NOV")
-        {
-            monthNum = "11";
-        }
-        else if(monthStr.toUpper() == "DEC")
-        {
-            monthNum = "12";
-        }
+        QHash<QString, QString> monthStr2Num {
+            {"JAN", "01"}
+            ,{"FEB", "02"}
+            ,{"MAR", "03"}
+            ,{"APR", "04"}
+            ,{"MAY", "05"}
+            ,{"JUN", "06"}
+            ,{"JUL", "07"}
+            ,{"AUG", "08"}
+            ,{"SEP", "09"}
+            ,{"OCT", "10"}
+            ,{"NOV", "11"}
+            ,{"DEC", "12"}
+        };
 
-        str.replace(monthStr, monthNum);
+        str.replace(monthStr, monthStr2Num.value(monthStr.toUpper()));
 
         if(isTrack)
         {
@@ -292,7 +208,7 @@ bool CGisItemTrk::saveTwoNav(const QString &filename)
     QFile file(filename);
     if(!file.open(QIODevice::WriteOnly))
     {
-        QMessageBox::critical(&CMainWindow::self(), QObject::tr("Error..."), QObject::tr("Failed to open %1.").arg(filename), QMessageBox::Abort);
+        QMessageBox::critical(CMainWindow::getBestWidgetForParent(), QObject::tr("Error..."), QObject::tr("Failed to open %1.").arg(filename), QMessageBox::Abort);
         return false;
     }
 
@@ -428,7 +344,7 @@ bool CGisItemTrk::readTwoNav(const QString& filename)
     QFile file(filename);
     if(!file.open(QIODevice::ReadOnly))
     {
-        QMessageBox::information(&CMainWindow::self(),QObject::tr("Error..."), QObject::tr("Failed to open %1.").arg(filename),QMessageBox::Abort,QMessageBox::Abort);
+        QMessageBox::information(CMainWindow::getBestWidgetForParent(),QObject::tr("Error..."), QObject::tr("Failed to open %1.").arg(filename),QMessageBox::Abort,QMessageBox::Abort);
         return false;
     }
     QTextStream in(&file);
@@ -457,7 +373,7 @@ bool CGisItemTrk::readTwoNav(const QString& filename)
             QString name  = line.mid(1).simplified();
             if(name != "WGS 84")
             {
-                QMessageBox::information(&CMainWindow::self(),QObject::tr("Error..."), QObject::tr("Only support lon/lat WGS 84 format."),QMessageBox::Abort,QMessageBox::Abort);
+                QMessageBox::information(CMainWindow::getBestWidgetForParent(),QObject::tr("Error..."), QObject::tr("Only support lon/lat WGS 84 format."),QMessageBox::Abort,QMessageBox::Abort);
                 return false;
             }
             break;
@@ -468,7 +384,7 @@ bool CGisItemTrk::readTwoNav(const QString& filename)
             QString name  = line.mid(1).simplified();
             if(name != "1")
             {
-                QMessageBox::information(&CMainWindow::self(),QObject::tr("Error..."), QObject::tr("Only support lon/lat WGS 84 format."),QMessageBox::Abort,QMessageBox::Abort);
+                QMessageBox::information(CMainWindow::getBestWidgetForParent(),QObject::tr("Error..."), QObject::tr("Only support lon/lat WGS 84 format."),QMessageBox::Abort,QMessageBox::Abort);
                 return false;
             }
             break;
@@ -501,13 +417,13 @@ bool CGisItemTrk::readTwoNav(const QString& filename)
 
             if(values.size() < 8)
             {
-                QMessageBox::information(&CMainWindow::self(),QObject::tr("Error..."), QObject::tr("Failed to read data."),QMessageBox::Abort,QMessageBox::Abort);
+                QMessageBox::information(CMainWindow::getBestWidgetForParent(),QObject::tr("Error..."), QObject::tr("Failed to read data."),QMessageBox::Abort,QMessageBox::Abort);
                 return false;
             }
 
             QString lat = values[2].replace(QChar(186),"").replace(QChar(-3),"");
             QString lon = values[3].replace(QChar(186),"").replace(QChar(-3),"");
-            GPS_Math_Str_To_Deg(lat + " " + lon, pt.lon, pt.lat);
+            IUnit::strToDeg(lat + " " + lon, pt.lon, pt.lat);
 
             pt.time = readCompeTime(values[4] + " " + values[5], true);
             pt.ele = values[7].toFloat();
@@ -641,7 +557,7 @@ bool CTwoNavProject::loadWpts(const QString& filename, const QDir& dir)
     QFile file(filename);
     if(!file.open(QIODevice::ReadOnly))
     {
-        QMessageBox::information(&CMainWindow::self(),QObject::tr("Error..."), QObject::tr("Failed to open %1.").arg(filename),QMessageBox::Abort,QMessageBox::Abort);
+        QMessageBox::information(CMainWindow::getBestWidgetForParent(),QObject::tr("Error..."), QObject::tr("Failed to open %1.").arg(filename),QMessageBox::Abort,QMessageBox::Abort);
         return false;
     }
     QTextStream in(&file);
@@ -669,7 +585,7 @@ bool CTwoNavProject::loadWpts(const QString& filename, const QDir& dir)
             QString name  = line.mid(1).simplified();
             if(name != "WGS 84")
             {
-                QMessageBox::information(&CMainWindow::self(),QObject::tr("Error..."), QObject::tr("Only support lon/lat WGS 84 format."),QMessageBox::Abort,QMessageBox::Abort);
+                QMessageBox::information(CMainWindow::getBestWidgetForParent(),QObject::tr("Error..."), QObject::tr("Only support lon/lat WGS 84 format."),QMessageBox::Abort,QMessageBox::Abort);
                 return false;
             }
             break;
@@ -680,7 +596,7 @@ bool CTwoNavProject::loadWpts(const QString& filename, const QDir& dir)
             QString name  = line.mid(1).simplified();
             if(name != "1")
             {
-                QMessageBox::information(&CMainWindow::self(),QObject::tr("Error..."), QObject::tr("Only support lon/lat WGS 84 format."),QMessageBox::Abort,QMessageBox::Abort);
+                QMessageBox::information(CMainWindow::getBestWidgetForParent(),QObject::tr("Error..."), QObject::tr("Only support lon/lat WGS 84 format."),QMessageBox::Abort,QMessageBox::Abort);
                 return false;
             }
             break;
@@ -698,7 +614,7 @@ bool CTwoNavProject::loadWpts(const QString& filename, const QDir& dir)
 
             if(values.size() < 8)
             {
-                QMessageBox::information(&CMainWindow::self(),QObject::tr("Error..."), QObject::tr("Failed to read data."),QMessageBox::Abort,QMessageBox::Abort);
+                QMessageBox::information(CMainWindow::getBestWidgetForParent(),QObject::tr("Error..."), QObject::tr("Failed to read data."),QMessageBox::Abort,QMessageBox::Abort);
                 return false;
             }
 
@@ -706,7 +622,7 @@ bool CTwoNavProject::loadWpts(const QString& filename, const QDir& dir)
 
             QString lat = values[3].replace(QChar(186),"").replace(QChar(-3),"");
             QString lon = values[4].replace(QChar(186),"").replace(QChar(-3),"");
-            GPS_Math_Str_To_Deg(lat + " " + lon, wpt.lon, wpt.lat);
+            IUnit::strToDeg(lat + " " + lon, wpt.lon, wpt.lat);
 
             wpt.time = readCompeTime(values[5] + " " + values[6], false);
             wpt.ele  = values[7].toFloat();
@@ -726,7 +642,7 @@ bool CTwoNavProject::loadWpts(const QString& filename, const QDir& dir)
 
             if(values.size() < 10)
             {
-                QMessageBox::information(&CMainWindow::self(),QObject::tr("Error..."), QObject::tr("Failed to read data."),QMessageBox::Abort,QMessageBox::Abort);
+                QMessageBox::information(CMainWindow::getBestWidgetForParent(),QObject::tr("Error..."), QObject::tr("Failed to read data."),QMessageBox::Abort,QMessageBox::Abort);
                 return false;
             }
 
@@ -800,7 +716,7 @@ bool CTwoNavProject::loadWpts(const QString& filename, const QDir& dir)
             QStringList values = line.mid(1).simplified().split(',', QString::KeepEmptyParts);
             if(values.size() < 1)
             {
-                QMessageBox::information(&CMainWindow::self(),QObject::tr("Error..."), QObject::tr("Failed to read data."),QMessageBox::Abort,QMessageBox::Abort);
+                QMessageBox::information(CMainWindow::getBestWidgetForParent(),QObject::tr("Error..."), QObject::tr("Failed to read data."),QMessageBox::Abort,QMessageBox::Abort);
                 return false;
             }
 
