@@ -16,14 +16,14 @@
 
 **********************************************************************************************/
 
+#include "gis/prj/IGisProject.h"
 #include "gis/trk/CCombineTrk.h"
 #include "gis/trk/CGisItemTrk.h"
-#include "gis/IGisProject.h"
 #include "plot/CPlotTrack.h"
 
 #include <QtWidgets>
 
-CCombineTrk::CCombineTrk(CGisItemTrk& trk, IGisProject& project, QWidget * parent)
+CCombineTrk::CCombineTrk(CGisItemTrk& trk, const QList<IGisItem::key_t> &keysPreSel, IGisProject& project, QWidget * parent)
     : QDialog(parent)
     , trk(trk)
     , project(project)
@@ -39,21 +39,35 @@ CCombineTrk::CCombineTrk(CGisItemTrk& trk, IGisProject& project, QWidget * paren
             continue;
         }
 
-        if(trk.getKey() == trk1->getKey())
+        if(keysPreSel.contains(trk1->getKey()))
         {
             continue;
         }
 
+        const IGisItem::key_t& key = trk1->getKey();
         QListWidgetItem * item = new QListWidgetItem(listAvailable);
         item->setText(trk1->getName());
         item->setIcon(trk1->getIcon());
-        item->setData(Qt::UserRole, trk1->getKey());
+        item->setData(Qt::UserRole + 1, key.item);
+        item->setData(Qt::UserRole + 2, key.project);
+        item->setData(Qt::UserRole + 3, key.device);
     }
 
-    QListWidgetItem * item = new QListWidgetItem(listSelected);
-    item->setText(trk.getName());
-    item->setIcon(trk.getIcon());
-    item->setData(Qt::UserRole, trk.getKey());
+    foreach(const IGisItem::key_t& key, keysPreSel)
+    {
+        IGisItem * gisItem = dynamic_cast<IGisItem*>(project.getItemByKey(key));
+        if(gisItem == 0)
+        {
+            continue;
+        }
+
+        QListWidgetItem * item = new QListWidgetItem(listSelected);
+        item->setText(gisItem->getName());
+        item->setIcon(gisItem->getIcon());
+        item->setData(Qt::UserRole + 1, key.item);
+        item->setData(Qt::UserRole + 2, key.project);
+        item->setData(Qt::UserRole + 3, key.device);
+    }
 
     connect(listAvailable, SIGNAL(itemSelectionChanged()), this, SLOT(slotSelectionChanged()));
     connect(listSelected, SIGNAL(itemSelectionChanged()), this, SLOT(slotSelectionChanged()));
@@ -67,19 +81,20 @@ CCombineTrk::CCombineTrk(CGisItemTrk& trk, IGisProject& project, QWidget * paren
 
     slotSelectionChanged();
     updatePreview();
-
 }
 
 CCombineTrk::~CCombineTrk()
 {
-
 }
 
 void CCombineTrk::accept()
 {
     for(int i = 0; i < listSelected->count(); i++)
     {
-        QString key = listSelected->item(i)->data(Qt::UserRole).toString();
+        IGisItem::key_t key;
+        key.item    = listSelected->item(i)->data(Qt::UserRole + 1).toString();
+        key.project = listSelected->item(i)->data(Qt::UserRole + 2).toString();
+        key.device  = listSelected->item(i)->data(Qt::UserRole + 3).toString();
         CGisItemTrk * trk1 = dynamic_cast<CGisItemTrk*>(project.getItemByKey(key));
         if(trk1 == 0)
         {
@@ -139,11 +154,22 @@ void CCombineTrk::slotRemove()
     QListWidgetItem * item;
     item = listSelected->currentItem();
 
-    if((item == 0) || (item->data(Qt::UserRole).toString() == trk.getKey()))
+    if(item == 0)
     {
         return;
     }
 
+    IGisItem::key_t key;
+    key.item    = item->data(Qt::UserRole + 1).toString();
+    key.project = item->data(Qt::UserRole + 2).toString();
+    key.device  = item->data(Qt::UserRole + 3).toString();
+
+    if(key == trk.getKey())
+    {
+        return;
+    }
+
+
     listSelected->takeItem(listSelected->row(item));
     listAvailable->addItem(item);
 
@@ -157,14 +183,16 @@ void CCombineTrk::slotUp()
     if(item)
     {
         int row = listSelected->row(item);
-        if(row == 0) return;
+        if(row == 0)
+        {
+            return;
+        }
         listSelected->takeItem(row);
         row = row - 1;
         listSelected->insertItem(row,item);
         listSelected->setCurrentItem(item);
     }
     updatePreview();
-
 }
 
 void CCombineTrk::slotDown()
@@ -173,7 +201,10 @@ void CCombineTrk::slotDown()
     if(item)
     {
         int row = listSelected->row(item);
-        if(row == (listSelected->count() - 1)) return;
+        if(row == (listSelected->count() - 1))
+        {
+            return;
+        }
         listSelected->takeItem(row);
         row = row + 1;
         listSelected->insertItem(row,item);
@@ -188,14 +219,19 @@ void CCombineTrk::updatePreview()
     QPolygonF line;
     for(int i = 0; i < listSelected->count(); i++)
     {
-        QString key = listSelected->item(i)->data(Qt::UserRole).toString();
+        IGisItem::key_t key;
+        key.item    = listSelected->item(i)->data(Qt::UserRole + 1).toString();
+        key.project = listSelected->item(i)->data(Qt::UserRole + 2).toString();
+        key.device  = listSelected->item(i)->data(Qt::UserRole + 3).toString();
+
+
         CGisItemTrk * trk1 = dynamic_cast<CGisItemTrk*>(project.getItemByKey(key));
         if(trk1 == 0)
         {
             continue;
         }
         QPolygonF line1;
-        trk1->getData(line1);
+        trk1->getPolylineFromData(line1);
 
         line += line1;
     }
