@@ -21,9 +21,12 @@
 
 #include "gis/IGisItem.h"
 #include "gis/IGisLine.h"
+#include "gis/trk/CActivityTrk.h"
+#include "helpers/INotifiable.h"
 
 #include <QPen>
 #include <QPointer>
+#include <functional>
 
 class QDomNode;
 class IGisProject;
@@ -34,12 +37,15 @@ class QSqlDatabase;
 class CQlgtTrack;
 class IQlgtOverlay;
 class QDir;
-class QProgressDialog;
+class CProgressDialog;
+class CPropertyTrk;
 
-#define TRK_N_COLORS 17
+#define TRK_N_COLORS          17
+#define ASCEND_THRESHOLD       5
 
 #include <QDebug>
 
+
 class CGisItemTrk : public IGisItem, public IGisLine
 {
 public:
@@ -139,31 +145,67 @@ public:
        @param stream  the data stream to write to.
        @return A reference to the stream
      */
-    QDataStream& operator>>(QDataStream& stream);
+    QDataStream& operator>>(QDataStream& stream) const;
 
+    /// get name of track
     const QString& getName() const
     {
-        return trk.name;
+        return trk.name.isEmpty() ? noName : trk.name;
     }
+
+    /// get the track color as index into the Garmin color table
     int getColorIdx() const
     {
         return colorIdx;
     }
 
+    /// get the track color a Qt color object
     const QColor& getColor() const
     {
         return color;
     }
 
+
+    /**
+       @brief get a summary of the track
+       @param allowEdit if true the track name is a link to allow interactions like edit
+       @return
+     */
     QString getInfo(bool allowEdit = false) const;
+    /// get a summary of a selected range
     QString getInfoRange();
-    QString getInfoTrkPt(const trkpt_t& pt);
-    QString getInfoProgress(const trkpt_t& pt);
+    /// get a summary of a selected range defined by two track points
     QString getInfoRange(const trkpt_t& pt1, const trkpt_t& pt2);
+    /// get a summary for a track point
+    QString getInfoTrkPt(const trkpt_t& pt);
+    /// get a progress summary for a selected track point
+    QString getInfoProgress(const trkpt_t& pt);
+
     quint32 getTotalElapsedSeconds() const
     {
         return totalElapsedSeconds;
     }
+
+    quint32 getTotalElapsedSecondsMoving()
+    {
+        return totalElapsedSecondsMoving;
+    }
+
+    qreal getTotalAscend() const
+    {
+        return totalAscend;
+    }
+
+    qreal getTotalDescend() const
+    {
+        return totalDescend;
+    }
+
+    qreal getTotalDistance() const
+    {
+        return totalDistance;
+    }
+
     const QString& getComment() const
     {
         return trk.cmt;
@@ -176,8 +218,11 @@ public:
     {
         return trk.links;
     }
+    /// get the track as a simple coordinate polyline
     void getPolylineFromData(QPolygonF &l);
+    /// get the track as polyline with elevation, pixel and GIS coordinates.
     void getPolylineFromData(SGisLine& l);
+
     const QDateTime& getTimeStart() const
     {
         return timeStart;
@@ -188,14 +233,75 @@ public:
         return cntVisiblePoints;
     }
 
-    /**
-       @brief Get the indeces of visible points for a selected range
+    const CActivityTrk& getActivities() const
+    {
+        return activities;
+    }
 
-       If no range is selected both indeces will be NOIDX.
+    const CPropertyTrk * getPropertyHandler() const
+    {
+        return propHandler;
+    }
+    /** @defgroup ColorSource Stuff related to coloring tracks using data from different sources
+
+        @{
+     */
+public:
+    static const struct ColorizeSource unknownColorizeSource;
+
+    /** @brief Set the colorize source to the source specified.
+
+        @param src  The new source to use.
+     */
+    void setColorizeSource(QString src);
+
+    /** @brief Get the current colorize source.
+
+        @return  The new source to use.
+     */
+    QString getColorizeSource()
+    {
+        return colorSource;
+    }
+
+    QStringList getExistingDataSources() const;
+
+    void setColorizeLimitLow(qreal limit);
+    qreal getColorizeLimitLow() const
+    {
+        return limitLow;
+    }
+
+    void setColorizeLimitHigh(qreal limit);
+    qreal getColorizeLimitHigh() const
+    {
+        return limitHigh;
+    }
+
+    const QString getColorizeUnit() const;
+
+    void getExtrema(qreal &min, qreal &max, const QString &source) const;
+
+private:
+    QString colorSource  = "";
+
+    // the low and high limit for (slope-)colored drawing of tracks
+    qreal limitLow  = -10;
+    qreal limitHigh =  10;
+
+    void drawColorized(QPainter &p);
+    /**@}*/
+
+
+    /**
+       @brief Get the indices of visible points for a selected range
+
+       If no range is selected both indices will be NOIDX.
 
        @param idx1 a reference to receive the first index
        @param idx2 a reference to receive the second index
      */
+public:
     void getSelectedVisiblePoints(qint32& idx1, qint32& idx2);
 
     void setName(const QString& str);
@@ -206,8 +312,25 @@ public:
     void setLinks(const QList<link_t>& links);
     void setDataFromPolyline(const SGisLine &l);
 
+    /**
+       @brief display the track screen options
+
+       @param origin    the point on screen to anchor the options
+       @param mouse     the mouse object causing the request
+       @return          a pointer to the screen option widget
+     */
     IScrOpt * getScreenOptions(const QPoint &origin, IMouse * mouse);
+    /**
+       @brief Get a screen pixel of the track close to the given position on the screen
+       @param screenPos Screen position as pixel coordinate
+       @return The screen coordinates as pixel of a track point close by
+     */
     QPointF getPointCloseBy(const QPoint& screenPos);
+    /**
+       @brief isCloseTo
+       @param pos Screen position as pixel coordinate
+       @return True if point is considered close enough
+     */
     bool isCloseTo(const QPointF& pos);
 
     void drawItem(QPainter& p, const QPolygonF& viewport, QList<QRectF>& blockedAreas, CGisDraw * gis);
@@ -278,6 +401,23 @@ public:
      */
     void showSelectedPoints();
 
+    /**
+       @brief Set the activity flag for all track points
+       @param flag  one of trkpt_t::flag_e::eAct...
+       @param name  the name of the activity
+       @param icon  a resource icon string to display with the activity
+     */
+    void setActivity(quint32 flag, const QString &name, const QString &icon);
+
+    /**
+       @brief Sets the activity flag for a selected range of track points
+
+       The range has to be selected already. The activity will be selected by a dialog displayed
+       in this method.
+
+     */
+    void setActivity();
+
     /**
        @brief Copy a section into a new track object
 
@@ -308,7 +448,7 @@ public:
     }
 
     /**
-       @brief Each plot widget that operates on the track must register during it's contruction
+       @brief Each plot widget that operates on the track must register during it's construction
 
        see registeredPlots for a detailed discussion
 
@@ -362,6 +502,13 @@ public:
        @param dist the Douglas Peuker distance in meters
      */
     void filterReducePoints(qreal dist);
+
+    /**
+       @brief Remove track points without valid location at the beginning of the track
+
+       @note All filter implementations are found in src/gis/trk/filter/filter.cpp
+     */
+    void filterRemoveNullPoints();
     /**
        @brief filterReset
 
@@ -419,10 +566,16 @@ public:
      */
     void filterSpeed(qreal speed);
 
-    void findWaypointsCloseBy(QProgressDialog &progress, quint32 &current, quint32 total);
+    /**
+       @brief Correlate waypoints with the track points
 
-    static const QColor lineColors[TRK_N_COLORS];
-    static const QString bulletColors[TRK_N_COLORS];
+       If a waypoint correlates with a trackpoint it's key is written to
+       trkpt_t::keyWpt.
+
+       @param progress  a progress dialog as this operation can take quite some time
+       @param current   the current progress if the operation is done for several tracks
+     */
+    void findWaypointsCloseBy(CProgressDialog &progress, quint32 &current);
 
 private:
     void setSymbol();
@@ -445,6 +598,24 @@ private:
      */
     void deriveSecondaryData();
 
+
+    /** @defgroup ExtremaExtensions Stuff related to calculation of extremas/extensions
+
+        @{
+     */
+public:
+    struct limits_t
+    {
+        qreal min;
+        qreal max;
+    };
+    /**@}*/
+
+private:
+    QSet<QString> existingExtensions;
+    QHash<QString, limits_t> extrema;
+    void updateExtremaAndExtensions();
+
     /**
        @brief Try to get access Nth visible point matching the idx
 
@@ -483,8 +654,8 @@ private:
        @brief Tell the point of focus to all plots and the detail dialog
 
        @param pt        A pointer to the point itself
-       @param mode      The reason for the focus
-       @param initiator A pointer to an IPlot object that has set the point of focus. Can be 0.
+       @param fmode     The reason for the focus
+       @param owner     A string to identify owner of the operation
      */
     bool publishMouseFocus(const trkpt_t * pt, focusmode_e fmode, const QString &owner);
     void publishMouseFocusNormalMode(const trkpt_t * pt, focusmode_e fmode);
@@ -501,8 +672,8 @@ private:
        @brief Overide IGisItem::changed() method
 
        As the CDetailsTrk is no modal dialog that blocks the GUI from any other input the track
-       can be changed while the widget is visible. Therfore it needs some feedback to update the
-       CDetailsTrk widget. Usualy this would be a signal. However CGisItemTrk is a QTreeWidgetItem
+       can be changed while the widget is visible. Therefore it needs some feedback to update the
+       CDetailsTrk widget. Usually this would be a signal. However CGisItemTrk is a QTreeWidgetItem
        and therefor no QObject. Fortunately there the dlgDetails pointer. So CDetailsTrk::setupGui()
        can be called from changed()
 
@@ -511,14 +682,15 @@ private:
      */
     void changed(const QString& what, const QString& icon);
 
+    /// setup colorIdx, color, bullet and icon
     void setColor(const QColor& c);
-    void setIcon(const QString& c);
+    /// setup track icon by color
+    void setIcon(const QString& iconColor);
 
 public:
     struct trkpt_t : public wpt_t
     {
         trkpt_t()
-            : flags(0)
         {
             reset();
         }
@@ -539,10 +711,23 @@ public:
 
         enum flag_e
         {
-            eHidden   = 0x00000004      ///< mark point as deleted
+            eHidden     = 0x00000004      ///< mark point as deleted
+
+                          // activity flags
+            ,eActNone   = 0x00000000
+            ,eActFoot   = 0x80000000
+            ,eActCycle  = 0x40000000
+            ,eActBike   = 0x20000000
+            ,eActCar    = 0x10000000
+            ,eActCable  = 0x08000000
+            ,eActSwim   = 0x04000000
+            ,eActShip   = 0x02000000
+            ,eActAero   = 0x01000000
+            ,eActMask   = 0xFF000000    ///< mask for activity flags
+            ,eActMaxNum = 8             ///< maximum number of activity flags. this is defined by the mask
         };
 
-        quint32 flags;
+        quint32 flags = 0;
         /// index within the complete track
         qint32 idxTotal;
         /// offset into lineSimple
@@ -568,17 +753,18 @@ public:
         qreal elapsedSecondsMoving;
         /// the key of an attached waypoint
         key_t keyWpt;
+        /// track point extensions
+        QHash<QString,QVariant> extensions;
     };
 
     struct trkseg_t
     {
         QVector<trkpt_t> pts;
-        QMap<QString, QVariant> extensions;
     };
 
     struct trk_t
     {
-        trk_t() : number(0)
+        trk_t()
         {
         }
         // -- all gpx tags - start
@@ -587,11 +773,10 @@ public:
         QString desc;
         QString src;
         QList<link_t> links;
-        quint64 number;
+        quint64 number = 0;
         QString type;
         QVector<trkseg_t> segs;
         // -- all gpx tags - stop
-        QMap<QString, QVariant> extensions;
 
         QString color;
     };
@@ -605,36 +790,53 @@ public:
         return trk;
     }
 
+    void registerNotification(INotifiable *obj);
+    void unregisterNotification(INotifiable *obj);
+
 private:
+    /// this is the GPX structure oriented data of the track
     trk_t trk;
 
+    /// the key of the track having the user focus.
     static key_t keyUserFocus;
+    /// background (border) color of all tracks
     static const QPen penBackground;
+    /// drawing and mouse interaction is dependent on the mode
+    mode_e mode = eModeNormal;
 
-    QPen penForeground;
-
-    mode_e mode;
-
-    qint32 cntTotalPoints;
-    qint32 cntVisiblePoints;
+    /**
+       \defgroup TrackStatistics Some statistical values over the complete track
+     */
+    /**@{*/
+    qint32 cntTotalPoints   = 0;
+    qint32 cntVisiblePoints = 0;
     QDateTime timeStart;
     QDateTime timeEnd;
-    qreal totalDistance;
-    qreal totalAscend;
-    qreal totalDescend;
-    qreal totalElapsedSeconds;
-    qreal totalElapsedSecondsMoving;
+    qreal totalDistance = 0;
+    qreal totalAscend   = 0;
+    qreal totalDescend  = 0;
+    qreal totalElapsedSeconds = 0;
+    qreal totalElapsedSecondsMoving = 0;
+    /**@}*/
 
+    /**
+        \defgroup DrawUtilies Objects used to draw the track
+     */
+    /**@{*/
+    /// the track line color by index
+    unsigned colorIdx = 4;
     /// the track line color
     QColor color;
-    /// the trakpoint bullet icon
+    /// the pen with the actual track color
+    QPen penForeground {Qt::blue, 3, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin};
+    /// the trackpoint bullet icon
     QPixmap bullet;
-    /// the track line color by index
-    unsigned colorIdx;
     /// the current track line as screen pixel coordinates
     QPolygonF lineSimple;
     /// visible and invisible points
     QPolygonF lineFull;
+    /**@}*/
+
 
     /**
         A list of plot objects that need to get informed on any change in data.
@@ -657,14 +859,13 @@ private:
      */
     QSet<IPlot*> registeredPlots;
 
-    const trkpt_t * mouseMoveFocus;
-    const trkpt_t * mouseClickFocus;
-    const trkpt_t * mouseRange1;
-    const trkpt_t * mouseRange2;
-
-    QPointer<CDetailsTrk> dlgDetails;
-    QPointer<CScrOptTrk>  scrOpt;
+    QSet<INotifiable*> notifyOnChange;
+    void notifyChange();
 
+    /**
+        \defgroup FocusRange Variables to handle mouse focus and range selection
+     */
+    /**@{*/
     enum rangestate_e
     {
         eRangeStateIdle
@@ -672,10 +873,41 @@ private:
         , eRangeState2nd
     };
 
-    rangestate_e rangeState;
+    /// state variable for range selection
+    rangestate_e rangeState = eRangeStateIdle;
 
+    /**
+        @brief Identify source of current range selection
+
+        Each range selection operation has to provide an owner string.
+        If mouseFocusOwner is not empty and different to the passed
+        owner string the operation must be rejected.
+
+     */
     QString mouseFocusOwner;
+
+    /// the current track point selected by mouse movement
+    const trkpt_t * mouseMoveFocus = 0;
+    /// the last track point the user clicked on
+    const trkpt_t * mouseClickFocus = 0;
+    /// the first point of a range selection
+    const trkpt_t * mouseRange1 = 0;
+    /// the second point of a range selection
+    const trkpt_t * mouseRange2 = 0;
+    /**@}*/
+
+    /// the track's details dialog if any
+    QPointer<CDetailsTrk> dlgDetails;
+    /// the track's screen option if visible
+    QPointer<CScrOptTrk>  scrOpt;
+
+    /// all function concerning track activities have been moved to CActivityTrk
+    CActivityTrk activities = {this};
+
+    /// all functions and data concerning graphs
+    CPropertyTrk * propHandler = nullptr;
 };
 
-#endif //CGISITEMTRK_H
+using fTrkPtGetVal = std::function<qreal(const CGisItemTrk::trkpt_t&)>;
 
+#endif //CGISITEMTRK_H
