@@ -17,10 +17,10 @@
 **********************************************************************************************/
 
 #include "CMainWindow.h"
-#include "canvas/CCanvas.h"
 #include "gis/CGisWidget.h"
 #include "gis/trk/CGisItemTrk.h"
 #include "gis/trk/CScrOptTrk.h"
+#include "helpers/CDraw.h"
 #include "mouse/IMouse.h"
 
 CScrOptTrk::CScrOptTrk(CGisItemTrk * trk, const QPoint& point, IMouse *parent)
@@ -36,16 +36,32 @@ CScrOptTrk::CScrOptTrk(CGisItemTrk * trk, const QPoint& point, IMouse *parent)
 
     toolProfile->setChecked(trk->hasUserFocus());
 
-    anchor = trk->getPointCloseBy(point);
-    move(anchor.toPoint() + QPoint(-width()/2,SCR_OPT_OFFSET));
-    show();
-
     bool isOnDevice = trk->isOnDevice();
     toolCut->setDisabled(isOnDevice);
     toolEdit->setDisabled(isOnDevice);
     toolReverse->setDisabled(isOnDevice);
     toolRange->setDisabled(isOnDevice);
 
+    anchor = trk->getPointCloseBy(point);
+    if((anchor - point).manhattanLength() > 50)
+    {
+        anchor = point;
+        toolCut->setEnabled(false);
+    }
+
+    move(anchor.toPoint() + QPoint(-width()/2,SCR_OPT_OFFSET));
+    show();
+
+    connect(toolEditDetails, SIGNAL(clicked()), this, SLOT(hide()));
+    connect(toolDelete, SIGNAL(clicked()), this, SLOT(hide()));
+    connect(toolCopy, SIGNAL(clicked()), this, SLOT(hide()));
+    connect(toolProfile, SIGNAL(toggled(bool)), this, SLOT(hide()));
+    connect(toolCut, SIGNAL(clicked()), this, SLOT(hide()));
+    connect(toolEdit, SIGNAL(clicked()), this, SLOT(hide()));
+    connect(toolReverse, SIGNAL(clicked()), this, SLOT(hide()));
+    connect(toolCombine, SIGNAL(clicked()), this, SLOT(hide()));
+    connect(toolRange, SIGNAL(clicked()), this, SLOT(hide()));
+
     connect(toolEditDetails, SIGNAL(clicked()), this, SLOT(slotEditDetails()));
     connect(toolDelete, SIGNAL(clicked()), this, SLOT(slotDelete()));
     connect(toolCopy, SIGNAL(clicked()), this, SLOT(slotCopy()));
@@ -56,6 +72,7 @@ CScrOptTrk::CScrOptTrk(CGisItemTrk * trk, const QPoint& point, IMouse *parent)
     connect(toolCombine, SIGNAL(clicked()), this, SLOT(slotCombine()));
     connect(toolRange, SIGNAL(clicked()), this, SLOT(slotRange()));
 
+
     // reset user focus if the track has it
     trk->setMouseFocusByPoint(NOPOINT, CGisItemTrk::eFocusMouseMove, "CScrOptTrk");
     trk->setMouseFocusByPoint(point, CGisItemTrk::eFocusMouseClick, "CScrOptTrk");
@@ -129,5 +146,5 @@ void CScrOptTrk::draw(QPainter& p)
     }
     item->drawHighlight(p);
 
-    drawBubble2(anchor, p);
+    CDraw::bubble(p, geometry(), anchor.toPoint());
 }
