@@ -28,33 +28,19 @@
 #include "gis/wpt/CGisItemWpt.h"
 #include "gis/wpt/CScrOptWpt.h"
 #include "gis/wpt/CSetupNewWpt.h"
+#include "helpers/CDraw.h"
+#include "helpers/CSettings.h"
 #include "mouse/IMouse.h"
 #include "units/IUnit.h"
 
-
-
 #include <QtWidgets>
 #include <QtXml>
 
 IGisItem::key_t CGisItemWpt::keyUserFocus;
-QString CGisItemWpt::lastName;
-QString CGisItemWpt::lastIcon;
 
 /// used to add a new waypoint
 CGisItemWpt::CGisItemWpt(const QPointF& pos, const QString& name, const QString &icon, IGisProject *project)
     : IGisItem(project, eTypeWpt, NOIDX)
-    , proximity(NOFLOAT)
-    , posScreen(NOPOINTF)
-    , doBubble(false)
-    , doSpecialCursor(false)
-    , doBubbleMove(false)
-    , doBubbleSize(false)
-    , mouseIsOverBubble(false)
-    , rectBubbleMove(0,0,16,16)
-    , rectBubbleEdit(0,0,16,16)
-    , rectBubbleSize(0,0,16,16)
-    , offsetBubble(-320, -150)
-    , widthBubble(300)
 {
     wpt.name    = name;
     wpt.sym     = icon;
@@ -75,18 +61,6 @@ CGisItemWpt::CGisItemWpt(const QPointF& pos, const QString& name, const QString
 /// used to move a copy of waypoint
 CGisItemWpt::CGisItemWpt(const QPointF& pos, const CGisItemWpt& parentWpt, IGisProject *project)
     : IGisItem(project, eTypeWpt, NOIDX)
-    , proximity(NOFLOAT)
-    , posScreen(NOPOINTF)
-    , doBubble(false)
-    , doSpecialCursor(false)
-    , doBubbleMove(false)
-    , doBubbleSize(false)
-    , mouseIsOverBubble(false)
-    , rectBubbleMove(0,0,16,16)
-    , rectBubbleEdit(0,0,16,16)
-    , rectBubbleSize(0,0,16,16)
-    , offsetBubble(-320, -150)
-    , widthBubble(300)
 {
     *this = parentWpt;
     wpt.lon     = pos.x();
@@ -109,35 +83,19 @@ CGisItemWpt::CGisItemWpt(const QPointF& pos, const CGisItemWpt& parentWpt, IGisP
 /// used to create a copy of waypoint with new parent
 CGisItemWpt::CGisItemWpt(const CGisItemWpt &parentWpt, IGisProject *project, int idx, bool clone)
     : IGisItem(project, eTypeWpt, idx)
-    , proximity(NOFLOAT)
-    , posScreen(NOPOINTF)
-    , doBubble(false)
-    , doSpecialCursor(false)
-    , doBubbleMove(false)
-    , doBubbleSize(false)
-    , mouseIsOverBubble(false)
-    , rectBubbleMove(0,0,16,16)
-    , rectBubbleEdit(0,0,16,16)
-    , rectBubbleSize(0,0,16,16)
-    , offsetBubble(-320, -150)
-    , widthBubble(300)
 {
-    *this = parentWpt;
-    key.project = project->getKey();
-    key.device  = project->getDeviceKey();
+    history = parentWpt.history;
+    loadHistory(history.histIdxCurrent);
 
     if(clone)
     {
         wpt.name += QObject::tr("_Clone");
         key.clear();
         history.events.clear();
+        setupHistory();
     }
 
-    if(parentWpt.isOnDevice())
-    {
-        flags |= eFlagWriteAllowed;
-    }
-    else if(!parentWpt.isReadOnly())
+    if(parentWpt.isOnDevice() || !parentWpt.isReadOnly())
     {
         flags |= eFlagWriteAllowed;
     }
@@ -146,25 +104,12 @@ CGisItemWpt::CGisItemWpt(const CGisItemWpt &parentWpt, IGisProject *project, int
         flags &= ~eFlagWriteAllowed;
     }
 
-    setupHistory();
     updateDecoration(eMarkChanged, eMarkNone);
 }
 
 /// used to create waypoint from GPX file
 CGisItemWpt::CGisItemWpt(const QDomNode &xml, IGisProject *project)
     : IGisItem(project, eTypeWpt, project->childCount())
-    , proximity(NOFLOAT)
-    , posScreen(NOPOINTF)
-    , doBubble(false)
-    , doSpecialCursor(false)
-    , doBubbleMove(false)
-    , doBubbleSize(false)
-    , mouseIsOverBubble(false)
-    , rectBubbleMove(0,0,16,16)
-    , rectBubbleEdit(0,0,16,16)
-    , rectBubbleSize(0,0,16,16)
-    , offsetBubble(-320, -150)
-    , widthBubble(300)
 {
     readGpx(xml);
     boundingRect = QRectF(QPointF(wpt.lon,wpt.lat)*DEG_TO_RAD,QPointF(wpt.lon,wpt.lat)*DEG_TO_RAD);
@@ -176,18 +121,6 @@ CGisItemWpt::CGisItemWpt(const QDomNode &xml, IGisProject *project)
 
 CGisItemWpt::CGisItemWpt(const history_t& hist, IGisProject * project)
     : IGisItem(project, eTypeWpt, project->childCount())
-    , proximity(NOFLOAT)
-    , posScreen(NOPOINTF)
-    , doBubble(false)
-    , doSpecialCursor(false)
-    , doBubbleMove(false)
-    , doBubbleSize(false)
-    , mouseIsOverBubble(false)
-    , rectBubbleMove(0,0,16,16)
-    , rectBubbleEdit(0,0,16,16)
-    , rectBubbleSize(0,0,16,16)
-    , offsetBubble(-320, -150)
-    , widthBubble(300)
 {
     history = hist;
     loadHistory(hist.histIdxCurrent);
@@ -196,18 +129,6 @@ CGisItemWpt::CGisItemWpt(const history_t& hist, IGisProject * project)
 
 CGisItemWpt::CGisItemWpt(quint64 id, QSqlDatabase& db, IGisProject * project)
     : IGisItem(project, eTypeWpt, NOIDX)
-    , proximity(NOFLOAT)
-    , posScreen(NOPOINTF)
-    , doBubble(false)
-    , doSpecialCursor(false)
-    , doBubbleMove(false)
-    , doBubbleSize(false)
-    , mouseIsOverBubble(false)
-    , rectBubbleMove(0,0,16,16)
-    , rectBubbleEdit(0,0,16,16)
-    , rectBubbleSize(0,0,16,16)
-    , offsetBubble(-320, -150)
-    , widthBubble(300)
 {
     loadFromDb(id, db);
     boundingRect = QRectF(QPointF(wpt.lon,wpt.lat)*DEG_TO_RAD,QPointF(wpt.lon,wpt.lat)*DEG_TO_RAD);
@@ -215,18 +136,6 @@ CGisItemWpt::CGisItemWpt(quint64 id, QSqlDatabase& db, IGisProject * project)
 
 CGisItemWpt::CGisItemWpt(const CTwoNavProject::wpt_t &tnvWpt, IGisProject * project)
     : IGisItem(project, eTypeWpt, NOIDX)
-    , proximity(NOFLOAT)
-    , posScreen(NOPOINTF)
-    , doBubble(false)
-    , doSpecialCursor(false)
-    , doBubbleMove(false)
-    , doBubbleSize(false)
-    , mouseIsOverBubble(false)
-    , rectBubbleMove(0,0,16,16)
-    , rectBubbleEdit(0,0,16,16)
-    , rectBubbleSize(0,0,16,16)
-    , offsetBubble(-320, -150)
-    , widthBubble(300)
 {
     readTwoNav(tnvWpt);
     boundingRect = QRectF(QPointF(wpt.lon,wpt.lat)*DEG_TO_RAD,QPointF(wpt.lon,wpt.lat)*DEG_TO_RAD);
@@ -247,6 +156,10 @@ void CGisItemWpt::setSymbol()
 
 bool CGisItemWpt::getNewWptData(QPointF& pt, QString& icon, QString& name)
 {
+    SETTINGS;
+    QString lastName = cfg.value("Waypoint/lastName", "wpt").toString();
+    QString lastIcon = cfg.value("Waypoint/lastIcon", "Waypoint").toString();
+
     const int s = lastName.size();
     if(s != 0)
     {
@@ -272,14 +185,14 @@ bool CGisItemWpt::getNewWptData(QPointF& pt, QString& icon, QString& name)
     name = lastName;
     icon = lastIcon;
 
-    CSetupNewWpt dlg(pt, icon, name, &CMainWindow::self());
+    CSetupNewWpt dlg(pt, icon, name, CMainWindow::getBestWidgetForParent());
     if(dlg.exec() != QDialog::Accepted)
     {
         return false;
     }
 
-    lastName = name;
-    lastIcon = icon;
+    cfg.setValue("Waypoint/lastName", name);
+    cfg.setValue("Waypoint/lastIcon", icon);
 
     return true;
 }
@@ -390,8 +303,11 @@ void CGisItemWpt::setIcon()
 
 void CGisItemWpt::setName(const QString& str)
 {
+    SETTINGS;
+    cfg.setValue("Waypoint/lastName", str);
+
     setText(CGisListWks::eColumnName, str);
-    lastName = str;
+
     wpt.name = str;
     changed(QObject::tr("Changed name"),"://icons/48x48/EditText.png");
 }
@@ -420,7 +336,9 @@ void CGisItemWpt::setProximity(qreal val)
 
 void CGisItemWpt::setIcon(const QString& name)
 {
-    lastIcon = name;
+    SETTINGS;
+    cfg.setValue("Waypoint/lastIcon", name);
+
     wpt.sym  = name;
 
     QPointF focus;
@@ -480,12 +398,12 @@ void CGisItemWpt::edit()
 {
     if(geocache.hasData)
     {
-        CDetailsGeoCache dlg(*this, &CMainWindow::self());
+        CDetailsGeoCache dlg(*this, CMainWindow::getBestWidgetForParent());
         dlg.exec();
     }
     else
     {
-        CDetailsWpt dlg(*this, &CMainWindow::self());
+        CDetailsWpt dlg(*this, CMainWindow::getBestWidgetForParent());
         dlg.exec();
     }
 }
@@ -591,7 +509,7 @@ void CGisItemWpt::drawLabel(QPainter& p, const QPolygonF &viewport, QList<QRectF
         }
     }
 
-    CCanvas::drawText(wpt.name,p,rect.toRect(), Qt::darkBlue);
+    CDraw::text(wpt.name,p,rect.toRect(), Qt::darkBlue);
     blockedAreas << rect;
 }
 
@@ -639,8 +557,8 @@ void CGisItemWpt::drawBubble(QPainter& p)
     rectBubbleSize.moveBottomRight(rectBubble.bottomRight() - QPoint(5,5));
 
     QPolygonF frame = makePolyline(posScreen, rectBubble);
-    p.setPen(CCanvas::penBorderGray);
-    p.setBrush(CCanvas::brushBackWhite);
+    p.setPen(CDraw::penBorderGray);
+    p.setBrush(CDraw::brushBackWhite);
     p.drawPolygon(frame);
 
     p.save();
@@ -842,7 +760,7 @@ bool CGisItemWpt::processMouseOverBubble(const QPoint &pos)
     {
         if(!doSpecialCursor)
         {
-            QApplication::setOverrideCursor(Qt::PointingHandCursor);
+            CCanvas::setOverrideCursor(Qt::PointingHandCursor, "processMouseOverBubble");
             doSpecialCursor = true;
         }
     }
@@ -850,7 +768,7 @@ bool CGisItemWpt::processMouseOverBubble(const QPoint &pos)
     {
         if(doSpecialCursor)
         {
-            QApplication::restoreOverrideCursor();
+            CCanvas::restoreOverrideCursor("processMouseOverBubble");
             doSpecialCursor = false;
         }
     }
