@@ -23,6 +23,7 @@
 #include "gis/wpt/CGisItemWpt.h"
 #include "gis/wpt/CProjWpt.h"
 #include "gis/wpt/CScrOptWpt.h"
+#include "helpers/CDraw.h"
 #include "mouse/IMouse.h"
 
 #include <QtWidgets>
@@ -30,7 +31,7 @@
 CScrOptWpt::CScrOptWpt(CGisItemWpt *wpt, const QPoint& point, IMouse *parent)
     : IScrOpt(parent)
 {
-    key         = wpt->getKey();
+    key = wpt->getKey();
 
     setupUi(this);
     setOrigin(point);
@@ -38,7 +39,6 @@ CScrOptWpt::CScrOptWpt(CGisItemWpt *wpt, const QPoint& point, IMouse *parent)
     label->setText(wpt->getInfo());
     adjustSize();
 
-
     toolProj->setDisabled(wpt->isGeocache() || wpt->isOnDevice());
     toolMove->setDisabled(wpt->isGeocache() || wpt->isOnDevice());
     photoAlbum->reload(wpt->getImages());
@@ -48,11 +48,18 @@ CScrOptWpt::CScrOptWpt(CGisItemWpt *wpt, const QPoint& point, IMouse *parent)
     move(anchor.toPoint() + QPoint(-width()/2,SCR_OPT_OFFSET));
     show();
 
+    connect(toolDelete, SIGNAL(clicked()), this, SLOT(hide()));
+    connect(toolEdit,   SIGNAL(clicked()), this, SLOT(hide()));
+    connect(toolCopy,   SIGNAL(clicked()), this, SLOT(hide()));
+    connect(toolMove,   SIGNAL(clicked()), this, SLOT(hide()));
+    connect(toolProj,   SIGNAL(clicked()), this, SLOT(hide()));
+    connect(toolBubble, SIGNAL(clicked()), this, SLOT(hide()));
+
     connect(toolDelete, SIGNAL(clicked()), this, SLOT(slotDelete()));
-    connect(toolEdit, SIGNAL(clicked()), this, SLOT(slotEdit()));
-    connect(toolCopy, SIGNAL(clicked()), this, SLOT(slotCopy()));
-    connect(toolMove, SIGNAL(clicked()), this, SLOT(slotMove()));
-    connect(toolProj, SIGNAL(clicked()), this, SLOT(slotProj()));
+    connect(toolEdit,   SIGNAL(clicked()), this, SLOT(slotEdit()));
+    connect(toolCopy,   SIGNAL(clicked()), this, SLOT(slotCopy()));
+    connect(toolMove,   SIGNAL(clicked()), this, SLOT(slotMove()));
+    connect(toolProj,   SIGNAL(clicked()), this, SLOT(slotProj()));
     connect(toolBubble, SIGNAL(clicked()), this, SLOT(slotBubble()));
 
     adjustSize();
@@ -108,5 +115,5 @@ void CScrOptWpt::draw(QPainter& p)
     }
     item->drawHighlight(p);
 
-    drawBubble2(anchor, p);
+    CDraw::bubble(p, geometry(), anchor.toPoint());
 }
