@@ -20,6 +20,7 @@
 #include "GeoMath.h"
 #include "canvas/CCanvas.h"
 #include "grid/CGrid.h"
+#include "helpers/CDraw.h"
 #include "helpers/CSettings.h"
 #include "map/CMapDraw.h"
 
@@ -28,11 +29,6 @@
 CGrid::CGrid(CMapDraw *map)
     : QObject(map)
     , map(map)
-    , pjWGS84(0)
-    , pjGrid(0)
-    , projstr("+proj=longlat +datum=WGS84 +no_defs")
-    , color(Qt::magenta)
-
 {
     pjWGS84 = pj_init_plus("+proj=longlat +datum=WGS84 +no_defs");
     setProjAndColor(projstr, color);
@@ -44,7 +40,7 @@ CGrid::~CGrid()
     pj_free(pjGrid);
 }
 
-void CGrid::convertPos2Str(const QPointF& pos, QString& info)
+void CGrid::convertPos2Str(const QPointF& pos, QString& info, bool simple)
 {
     if(pjGrid == 0)
     {
@@ -60,11 +56,25 @@ void CGrid::convertPos2Str(const QPointF& pos, QString& info)
         pt *= RAD_TO_DEG;
         lat = pt.y() < 0 ? "S" : "N";
         lng = pt.x() < 0 ? "W" : "E";
-        info += tr("[Grid: %1%2%5 %3%4%5] ").arg(lat).arg(qAbs(pt.y()), 0, 'f', 6).arg(lng).arg(qAbs(pt.x()), 0, 'f', 6).arg(QChar('\260'));
+        if(simple)
+        {
+            info += tr("%1 %2 ").arg(pt.y(), 0, 'f', 6).arg(pt.x(), 0, 'f', 6);
+        }
+        else
+        {
+            info += tr("%1%2%5 %3%4%5 ").arg(lat).arg(qAbs(pt.y()), 0, 'f', 6).arg(lng).arg(qAbs(pt.x()), 0, 'f', 6).arg(QChar('\260'));
+        }
     }
     else
     {
-        info += tr("[Grid: N %1m, E %2m] ").arg(pt.y(),0,'f',0).arg(pt.x(),0,'f',0);
+        if(simple)
+        {
+            info += tr("%1m, %2m ").arg(pt.y(),0,'f',0).arg(pt.x(),0,'f',0);
+        }
+        else
+        {
+            info += tr("N %1m, E %2m ").arg(pt.y(),0,'f',0).arg(pt.x(),0,'f',0);
+        }
     }
 }
 
@@ -361,22 +371,22 @@ void CGrid::draw(QPainter& p, const QRect& rect)
 
         foreach(const val_t &val, horzTopTicks)
         {
-            CCanvas::drawText(qAbs(val.val)<1.e-5 ? "0" : QString("%1%2").arg(val.val * RAD_TO_DEG).arg(QChar(0260)), p, QPoint(val.pos, yoff), textColor);
+            CDraw::text(qAbs(val.val)<1.e-5 ? "0" : QString("%1%2").arg(val.val * RAD_TO_DEG).arg(QChar(0260)), p, QPoint(val.pos, yoff), textColor);
         }
 
         foreach(const val_t &val, horzBtmTicks)
         {
-            CCanvas::drawText(qAbs(val.val)<1.e-5 ? "0" : QString("%1%2").arg(val.val * RAD_TO_DEG).arg(QChar(0260)), p, QPoint(val.pos, h), textColor);
+            CDraw::text(qAbs(val.val)<1.e-5 ? "0" : QString("%1%2").arg(val.val * RAD_TO_DEG).arg(QChar(0260)), p, QPoint(val.pos, h), textColor);
         }
 
         foreach(const val_t &val, vertLftTicks)
         {
-            CCanvas::drawText(qAbs(val.val)<1.e-5 ? "0" : QString("%1%2").arg(val.val * RAD_TO_DEG).arg(QChar(0260)), p, QPoint(xoff, val.pos), textColor);
+            CDraw::text(qAbs(val.val)<1.e-5 ? "0" : QString("%1%2").arg(val.val * RAD_TO_DEG).arg(QChar(0260)), p, QPoint(xoff, val.pos), textColor);
         }
 
         foreach(const val_t &val, vertRgtTicks)
         {
-            CCanvas::drawText(qAbs(val.val)<1.e-5 ? "0" : QString("%1%2").arg(val.val * RAD_TO_DEG).arg(QChar(0260)), p, QPoint(w - xoff, val.pos), textColor);
+            CDraw::text(qAbs(val.val)<1.e-5 ? "0" : QString("%1%2").arg(val.val * RAD_TO_DEG).arg(QChar(0260)), p, QPoint(w - xoff, val.pos), textColor);
         }
     }
     else
@@ -387,22 +397,22 @@ void CGrid::draw(QPainter& p, const QRect& rect)
 
         foreach(const val_t &val, horzTopTicks)
         {
-            CCanvas::drawText(QString("%1").arg(qint32(val.val/1000)), p, QPoint(val.pos, yoff), textColor);
+            CDraw::text(QString("%1").arg(qint32(val.val/1000)), p, QPoint(val.pos, yoff), textColor);
         }
 
         foreach(const val_t &val, horzBtmTicks)
         {
-            CCanvas::drawText(QString("%1").arg(qint32(val.val/1000)), p, QPoint(val.pos, h), textColor);
+            CDraw::text(QString("%1").arg(qint32(val.val/1000)), p, QPoint(val.pos, h), textColor);
         }
 
         foreach(const val_t &val, vertLftTicks)
         {
-            CCanvas::drawText(QString("%1").arg(qint32(val.val/1000)), p, QPoint(xoff, val.pos), textColor);
+            CDraw::text(QString("%1").arg(qint32(val.val/1000)), p, QPoint(xoff, val.pos), textColor);
         }
 
         foreach(const val_t &val, vertRgtTicks)
         {
-            CCanvas::drawText(QString("%1").arg(qint32(val.val/1000)), p, QPoint(w - xoff, val.pos), textColor);
+            CDraw::text(QString("%1").arg(qint32(val.val/1000)), p, QPoint(w - xoff, val.pos), textColor);
         }
     }
 }
