@@ -23,7 +23,11 @@
 #include <QtWidgets>
 #include <proj_api.h>
 
-struct mitab_entry_t {QString name; int idx; };
+struct mitab_entry_t
+{
+    QString name;
+    int idx;
+};
 
 static bool mitabLessThan(const mitab_entry_t &s1, const mitab_entry_t &s2)
 {
@@ -31,7 +35,7 @@ static bool mitabLessThan(const mitab_entry_t &s1, const mitab_entry_t &s2)
 }
 
 CProjWizard::CProjWizard(QLineEdit &line)
-    : QDialog(&CMainWindow::self())
+    : QDialog(CMainWindow::getBestWidgetForParent())
     , line(line)
 {
     setupUi(this);
@@ -45,7 +49,8 @@ CProjWizard::CProjWizard(QLineEdit &line)
         entry.name  = di->pszOGCDatumName;
         entry.idx   = idx;
         list << entry;
-        ++di; ++idx;
+        ++di;
+        ++idx;
     }
     qSort(list.begin(), list.end(), mitabLessThan);
 
@@ -137,7 +142,8 @@ void CProjWizard::findDatum(const QString& str)
             break;
         }
 
-        ++di; ++idx;
+        ++di;
+        ++idx;
     }
 }
 
@@ -212,7 +218,7 @@ bool CProjWizard::validProjStr(const QString projStr)
 
     if (!projCheck)
     {
-        QMessageBox::warning(&CMainWindow::self(), tr("Error..."),tr("The value\n'%1'\nis not a valid coordinate system definition:\n%2").arg(projStr).arg(pj_strerrno(pj_errno)),QMessageBox::Abort,QMessageBox::Abort);
+        QMessageBox::warning(CMainWindow::getBestWidgetForParent(), tr("Error..."),tr("The value\n'%1'\nis not a valid coordinate system definition:\n%2").arg(projStr).arg(pj_strerrno(pj_errno)),QMessageBox::Abort,QMessageBox::Abort);
         return false;
     }
     else
