@@ -20,24 +20,55 @@
 #define CFILEEXT_H
 
 #include <QFile>
+#include <QtCore>
 
 class CFileExt : public QFile
 {
-    public:
-        CFileExt(const QString &filename)
-            : QFile(filename)
-            , mapped(NULL)
-            {}
+public:
+    CFileExt(const QString &filename)
+        : QFile(filename)
+        , mapped(NULL)
+    {
+        cnt++;
+    }
 
-        // data access function
-        const char *data(qint64 offset)
+    ~CFileExt()
+    {
+        cnt--;
+    }
+
+#ifndef Q_OS_WIN32
+    // data access function
+    const char *data(qint64 offset, qint64 s)
+    {
+        mapped = map(offset, s);
+        mappedSections << mapped;
+        return (const char*)mapped;
+    }
+
+    void free()
+    {
+        foreach(uchar * p, mappedSections)
         {
-            if(!mapped)
-                mapped = reinterpret_cast<const char*>(map(0, size()));
-            return mapped + offset;
+            unmap(p);
         }
-    private:
-        const char *mapped;
+        mappedSections.clear();
+    }
+
+#else
+    // data access function
+    const char *data(qint64 offset, qint64 s)
+    {
+        uchar * p = map(offset,s);
+        return (const char *)p;
+    }
+#endif
+
+private:
+    static int cnt;
+
+    uchar *mapped;
+    QSet<uchar*> mappedSections;
 };
 
 
