@@ -83,7 +83,7 @@ public:
 
         /// the center longitude of the area covered by this subdivision
         qint32 iCenterLng;
-        /// the center latiude of the area covered by this subdivision
+        /// the center latitude of the area covered by this subdivision
         qint32 iCenterLat;
 
         /// north boundary of area covered by this subsection []
@@ -156,7 +156,7 @@ public:
        @brief Find a matching street polyline
 
        The polyline must be close enough in terms of pixel to point 1 and 2. "Close enough" is defined by
-       the threshold. The returned poylline uses lon/lat as coordinates.
+       the threshold. The returned polyline uses lon/lat as coordinates.
 
        @param pt1           first point in [rad]
        @param pt2           second point in [rad]
@@ -534,7 +534,7 @@ private:
      */
     QMap<QString,subfile_desc_t> subfiles;
     /// relay the transparent flags from the subfiles
-    bool transparent;
+    bool transparent = false;
 
     QRectF maparea;
 
