@@ -17,6 +17,7 @@
 **********************************************************************************************/
 
 #include "CMainWindow.h"
+#include "helpers/CDraw.h"
 #include "map/CMapDraw.h"
 #include "map/CMapTMS.h"
 #include "map/cache/CDiskCache.h"
@@ -52,10 +53,6 @@ inline double tile2lat(int y, int z)
 
 CMapTMS::CMapTMS(const QString &filename, CMapDraw *parent)
     : IMap(eFeatVisibility|eFeatTileCache, parent)
-    , minZoomLevel(1)
-    , maxZoomLevel(21)
-    , diskCache(0)
-    , lastRequest(false)
 {
     qDebug() << "------------------------------";
     qDebug() << "TMS: try to open" << filename;
@@ -67,7 +64,7 @@ CMapTMS::CMapTMS(const QString &filename, CMapDraw *parent)
     QFile file(filename);
     if(!file.open(QIODevice::ReadOnly))
     {
-        QMessageBox::critical(&CMainWindow::self(), tr("Error..."), tr("Failed to open %1").arg(filename), QMessageBox::Abort, QMessageBox::Abort);
+        QMessageBox::critical(CMainWindow::getBestWidgetForParent(), tr("Error..."), tr("Failed to open %1").arg(filename), QMessageBox::Abort, QMessageBox::Abort);
         return;
     }
 
@@ -77,7 +74,7 @@ CMapTMS::CMapTMS(const QString &filename, CMapDraw *parent)
     if(!dom.setContent(&file, true, &msg, &line, &column))
     {
         file.close();
-        QMessageBox::critical(&CMainWindow::self(), tr("Error..."), tr("Failed to read: %1\nline %2, column %3:\n %4").arg(filename).arg(line).arg(column).arg(msg), QMessageBox::Abort, QMessageBox::Abort);
+        QMessageBox::critical(CMainWindow::getBestWidgetForParent(), tr("Error..."), tr("Failed to read: %1\nline %2, column %3:\n %4").arg(filename).arg(line).arg(column).arg(msg), QMessageBox::Abort, QMessageBox::Abort);
         return;
     }
     file.close();
@@ -127,6 +124,18 @@ CMapTMS::CMapTMS(const QString &filename, CMapDraw *parent)
         {
             layers[idx].maxZoomLevel = xmlLayer.firstChildElement("MaxZoomLevel").text().toInt();
         }
+
+        if(layers[idx].strUrl.toLower().startsWith("https") && !QSslSocket::supportsSsl())
+        {
+            QString msg = tr(
+                "This map requires OpenSSL support. However due to legal restrictions in some countries "
+                "OpenSSL is not packaged with QMapShack. You can have a look at the "
+                "<a href='https://www.openssl.org/community/binaries.html'>OpenSSL Homepage</a> "
+                "for binaries. You have to copy libeay32.dll and ssleay32.dll into the QMapShack program directory."
+                );
+            QMessageBox::critical(CMainWindow::getBestWidgetForParent(),tr("Error..."),msg,QMessageBox::Abort);
+            return;
+        }
     }
 
     const QDomElement& xmlRawHeader = xmlTms.firstChildElement("RawHeader");
@@ -168,6 +177,8 @@ CMapTMS::~CMapTMS()
 
 void CMapTMS::getLayers(QListWidget& list)
 {
+    QMutexLocker lock(&mutex);
+
     list.clear();
     if(layers.size() < 2)
     {
@@ -188,13 +199,15 @@ void CMapTMS::getLayers(QListWidget& list)
 
 void CMapTMS::saveConfig(QSettings& cfg)
 {
+    QMutexLocker lock(&mutex);
+
     IMap::saveConfig(cfg);
     if(layers.size() < 2)
     {
         return;
     }
 
-    // save indices of enbaled layers
+    // save indices of enabled layers
     QStringList enabled;
     for(int i = 0; i< layers.size(); i++)
     {
@@ -208,6 +221,8 @@ void CMapTMS::saveConfig(QSettings& cfg)
 
 void CMapTMS::loadConfig(QSettings& cfg)
 {
+    QMutexLocker lock(&mutex);
+
     IMap::loadConfig(cfg);
     if(layers.size() < 2)
     {
@@ -238,6 +253,8 @@ void CMapTMS::loadConfig(QSettings& cfg)
 
 void CMapTMS::configureCache()
 {
+    QMutexLocker lock(&mutex);
+
     delete diskCache;
     diskCache = new CDiskCache(getCachePath(), getCacheSize(), getCacheExpiration(), this);
 }
@@ -296,6 +313,8 @@ void CMapTMS::slotQueueChanged()
 
 void CMapTMS::slotRequestFinished(QNetworkReply* reply)
 {
+    QMutexLocker lock(&mutex);
+
     QString url = reply->url().toString();
     if(urlPending.contains(url))
     {
@@ -327,6 +346,8 @@ void CMapTMS::slotRequestFinished(QNetworkReply* reply)
 
 void CMapTMS::slotLayersChanged(QListWidgetItem * item)
 {
+    QMutexLocker lock(&mutex);
+
     bool isChecked = (item->checkState() == Qt::Checked);
     int idx = item->data(Qt::UserRole).toInt();
     if(idx < 0)
@@ -353,6 +374,8 @@ void CMapTMS::slotLayersChanged(QListWidgetItem * item)
 
 QString CMapTMS::createUrl(const layer_t& layer, int x, int y, int z)
 {
+    QMutexLocker lock(&mutex);
+
     if(layer.strUrl.startsWith("script"))
     {
         QString filename = layer.strUrl.mid(9);
