@@ -17,7 +17,7 @@
 **********************************************************************************************/
 
 #include "CMainWindow.h"
-#include "canvas/CCanvas.h"
+#include "helpers/CDraw.h"
 #include "map/CMapDraw.h"
 #include "map/CMapVRT.h"
 #include "units/IUnit.h"
@@ -34,8 +34,6 @@
 CMapVRT::CMapVRT(const QString &filename, CMapDraw *parent)
     : IMap(eFeatVisibility,parent)
     , filename(filename)
-    , rasterBandCount(0)
-    , hasOverviews(false)
 {
     qDebug() << "------------------------------";
     qDebug() << "VRT: try to open" << filename;
@@ -44,7 +42,7 @@ CMapVRT::CMapVRT(const QString &filename, CMapDraw *parent)
 
     if(dataset == 0)
     {
-        QMessageBox::warning(&CMainWindow::self(), tr("Error..."), tr("Failed to load file: %1").arg(filename));
+        QMessageBox::warning(CMainWindow::getBestWidgetForParent(), tr("Error..."), tr("Failed to load file: %1").arg(filename));
         return;
     }
 
@@ -57,8 +55,9 @@ CMapVRT::CMapVRT(const QString &filename, CMapDraw *parent)
 
         if(pBand == 0)
         {
-            delete dataset; dataset = 0;
-            QMessageBox::warning(&CMainWindow::self(), tr("Error..."), tr("Failed to load file: %1").arg(filename));
+            delete dataset;
+            dataset = 0;
+            QMessageBox::warning(CMainWindow::getBestWidgetForParent(), tr("Error..."), tr("Failed to load file: %1").arg(filename));
             return;
         }
 
@@ -85,8 +84,9 @@ CMapVRT::CMapVRT(const QString &filename, CMapDraw *parent)
         }
         else
         {
-            delete dataset; dataset = 0;
-            QMessageBox::warning(&CMainWindow::self(), tr("Error..."), tr("File must be 8 bit palette or gray indexed."));
+            delete dataset;
+            dataset = 0;
+            QMessageBox::warning(CMainWindow::getBestWidgetForParent(), tr("Error..."), tr("File must be 8 bit palette or gray indexed."));
             return;
         }
 
@@ -121,8 +121,9 @@ CMapVRT::CMapVRT(const QString &filename, CMapDraw *parent)
     free(ptr);
     if(pjsrc == 0)
     {
-        delete dataset; dataset = 0;
-        QMessageBox::warning(&CMainWindow::self(), tr("Error..."), tr("No georeference information found."));
+        delete dataset;
+        dataset = 0;
+        QMessageBox::warning(CMainWindow::getBestWidgetForParent(), tr("Error..."), tr("No georeference information found."));
         return;
     }
 
@@ -267,7 +268,7 @@ void CMapVRT::draw(IDrawContext::buffer_t& buf)
     qreal nTiles = ((right - left) * (bottom - top) / (dx*dy));
     if(hasOverviews)
     {
-        // if there are overviews tiles canbe reduced by reading
+        // if there are overviews tiles can be reduced by reading
         // with a scale factor from file. Increase amount of pixel
         // read until tile limit is met.
         while(nTiles > TILELIMIT)
