@@ -17,6 +17,7 @@
 **********************************************************************************************/
 
 #include "CMainWindow.h"
+#include "helpers/CDraw.h"
 #include "map/CMapDraw.h"
 #include "map/CMapWMTS.h"
 #include "map/cache/CDiskCache.h"
@@ -31,9 +32,6 @@
 
 CMapWMTS::CMapWMTS(const QString &filename, CMapDraw *parent)
     : IMap(eFeatVisibility|eFeatTileCache, parent)
-    , diskCache(0)
-    , lastRequest(false)
-
 {
     qDebug() << "------------------------------";
     qDebug() << "WTMS: try to open" << filename;
@@ -42,7 +40,7 @@ CMapWMTS::CMapWMTS(const QString &filename, CMapDraw *parent)
     QFile file(filename);
     if(!file.open(QIODevice::ReadOnly))
     {
-        QMessageBox::critical(&CMainWindow::self(), tr("Error..."), tr("Failed to open %1").arg(filename), QMessageBox::Abort, QMessageBox::Abort);
+        QMessageBox::critical(CMainWindow::getBestWidgetForParent(), tr("Error..."), tr("Failed to open %1").arg(filename), QMessageBox::Abort, QMessageBox::Abort);
         return;
     }
 
@@ -52,7 +50,7 @@ CMapWMTS::CMapWMTS(const QString &filename, CMapDraw *parent)
     if(!dom.setContent(&file, true, &msg, &line, &column))
     {
         file.close();
-        QMessageBox::critical(&CMainWindow::self(), tr("Error..."), tr("Failed to read: %1\nline %2, column %3:\n %4").arg(filename).arg(line).arg(column).arg(msg), QMessageBox::Abort, QMessageBox::Abort);
+        QMessageBox::critical(CMainWindow::getBestWidgetForParent(), tr("Error..."), tr("Failed to read: %1\nline %2, column %3:\n %4").arg(filename).arg(line).arg(column).arg(msg), QMessageBox::Abort, QMessageBox::Abort);
         return;
     }
     file.close();
@@ -62,7 +60,7 @@ CMapWMTS::CMapWMTS(const QString &filename, CMapDraw *parent)
     const QDomElement& xmlCapabilities = dom.documentElement();
     if(xmlCapabilities.tagName() != "Capabilities")
     {
-        QMessageBox::critical(&CMainWindow::self(), tr("Error..."), tr("Failed to read: %1\nUnknown structure.").arg(filename), QMessageBox::Abort, QMessageBox::Abort);
+        QMessageBox::critical(CMainWindow::getBestWidgetForParent(), tr("Error..."), tr("Failed to read: %1\nUnknown structure.").arg(filename), QMessageBox::Abort, QMessageBox::Abort);
         return;
     }
     const QDomNode& xmlServiceIdentification = xmlCapabilities.namedItem("ServiceIdentification");
@@ -71,7 +69,7 @@ CMapWMTS::CMapWMTS(const QString &filename, CMapDraw *parent)
 
     if(!ServiceType.contains("WMTS", Qt::CaseInsensitive) || ServiceTypeVersion != "1.0.0")
     {
-        QMessageBox::critical(&CMainWindow::self(), tr("Error..."), tr("Unexpexted service. '* WMTS 1.0.0' is expected. '%1 %2' is read.").arg(ServiceType).arg(ServiceTypeVersion), QMessageBox::Abort, QMessageBox::Abort);
+        QMessageBox::critical(CMainWindow::getBestWidgetForParent(), tr("Error..."), tr("Unexpected service. '* WMTS 1.0.0' is expected. '%1 %2' is read.").arg(ServiceType).arg(ServiceTypeVersion), QMessageBox::Abort, QMessageBox::Abort);
         return;
     }
 
@@ -148,6 +146,19 @@ CMapWMTS::CMapWMTS(const QString &filename, CMapDraw *parent)
             layer.resourceURL  = layer.resourceURL.replace("{" + Identifier + "}", Default, Qt::CaseInsensitive);
         }
 
+        if(layer.resourceURL.toLower().startsWith("https") && !QSslSocket::supportsSsl())
+        {
+            QString msg = tr(
+                "This map requires OpenSSL support. However due to legal restrictions in some countries "
+                "OpenSSL is not packaged with QMapShack. You can have a look at the "
+                "<a href='https://www.openssl.org/community/binaries.html'>OpenSSL Homepage</a> "
+                "for binaries. You have to copy libeay32.dll and ssleay32.dll into the QMapShack program directory."
+                );
+            QMessageBox::critical(CMainWindow::getBestWidgetForParent(),tr("Error..."),msg,QMessageBox::Abort);
+            return;
+        }
+
+
         // enable layer by default
         layer.enabled     = true;
         layers << layer;
@@ -203,7 +214,7 @@ CMapWMTS::CMapWMTS(const QString &filename, CMapDraw *parent)
 
         if(tileset.pjsrc == 0)
         {
-            QMessageBox::warning(&CMainWindow::self(), tr("Error..."), tr("No georeference information found."));
+            QMessageBox::warning(CMainWindow::getBestWidgetForParent(), tr("Error..."), tr("No georeference information found."));
             return;
         }
 
@@ -251,6 +262,8 @@ CMapWMTS::~CMapWMTS()
 
 void CMapWMTS::getLayers(QListWidget& list)
 {
+    QMutexLocker lock(&mutex);
+
     list.clear();
     if(layers.size() < 2)
     {
@@ -270,13 +283,15 @@ void CMapWMTS::getLayers(QListWidget& list)
 
 void CMapWMTS::saveConfig(QSettings& cfg)
 {
+    QMutexLocker lock(&mutex);
+
     IMap::saveConfig(cfg);
     if(layers.size() < 2)
     {
         return;
     }
 
-    // save indices of enbaled layers
+    // save indices of enabled layers
     QStringList enabled;
     for(int i = 0; i< layers.size(); i++)
     {
@@ -290,6 +305,8 @@ void CMapWMTS::saveConfig(QSettings& cfg)
 
 void CMapWMTS::loadConfig(QSettings& cfg)
 {
+    QMutexLocker lock(&mutex);
+
     IMap::loadConfig(cfg);
     if(layers.size() < 2)
     {
@@ -319,12 +336,16 @@ void CMapWMTS::loadConfig(QSettings& cfg)
 
 void CMapWMTS::configureCache()
 {
+    QMutexLocker lock(&mutex);
+
     delete diskCache;
     diskCache = new CDiskCache(getCachePath(), getCacheSize(), getCacheExpiration(), this);
 }
 
 void CMapWMTS::slotLayersChanged(QListWidgetItem * item)
 {
+    QMutexLocker lock(&mutex);
+
     bool isChecked = (item->checkState() == Qt::Checked);
     int idx = item->data(Qt::UserRole).toInt();
     if(idx < 0)
@@ -399,6 +420,8 @@ void CMapWMTS::slotQueueChanged()
 
 void CMapWMTS::slotRequestFinished(QNetworkReply* reply)
 {
+    QMutexLocker lock(&mutex);
+
     QString url = reply->url().toString();
     if(urlPending.contains(url))
     {
