@@ -76,7 +76,8 @@ public:
      */
     virtual void getInfo(const QPoint& px, QString& str)
     {
-        Q_UNUSED(px); Q_UNUSED(str);
+        Q_UNUSED(px);
+        Q_UNUSED(str);
     }
     /**
        @brief getToolTip
@@ -85,7 +86,8 @@ public:
      */
     virtual void getToolTip(const QPoint& px, QString& str)
     {
-        Q_UNUSED(px); Q_UNUSED(str);
+        Q_UNUSED(px);
+        Q_UNUSED(str);
     }
 
     /**
@@ -149,7 +151,7 @@ public:
        @brief Find a matching street polyline
 
        The polyline must be close enough in terms of pixel to point 1 and 2. "Close enough" is defined by
-       the threshold. The returned poylline uses lon/lat as coordinates.
+       the threshold. The returned polyline uses lon/lat as coordinates.
 
        @param pt1           first point in [rad]
        @param pt2           second point in [rad]
@@ -175,15 +177,18 @@ public slots:
 
     void slotSetCachePath(const QString& path)
     {
-        cachePath = path; configureCache();
+        cachePath = path;
+        configureCache();
     }
     void slotSetCacheSize(qint32 size)
     {
-        cacheSizeMB = size; configureCache();
+        cacheSizeMB = size;
+        configureCache();
     }
     void slotSetCacheExpiration(qint32 days)
     {
-        cacheExpiration = days; configureCache();
+        cacheExpiration = days;
+        configureCache();
     }
 
 
@@ -193,7 +198,7 @@ protected:
 
 
     /**
-       @brief Reproject (translate, rotate, scale) tile befor drwaing it.
+       @brief Reproject (translate, rotate, scale) tile before drawing it.
        @param img   the tile as QImage
        @param l     a 4 point polygon to fit the tile in
        @param p     the QPainter used to paint the tile
@@ -206,19 +211,19 @@ protected:
     /// source projection of the current map file
     /**
         Has to be set by subclass. Destruction has to be
-        handeled by subclass.
+        handled by subclass.
      */
-    projPJ pjsrc;
+    projPJ pjsrc = 0;
     /// target projection
     /**
         Is set by IMap() to WGS84. Will be freed by ~IMap()
      */
-    projPJ pjtar;
+    projPJ pjtar = 0;
 
     /**
        @brief True if map was loaded successfully
      */
-    bool isActivated;
+    bool isActivated = false;
 
     /// the setup dialog. Use getSetup() for access
     QPointer<IMapProp> setup;
@@ -227,18 +232,18 @@ protected:
     quint32 flagsFeature;
 
     /// vector maps only: hide/show polygons
-    bool showPolygons;
+    bool showPolygons = true;
     /// vector maps only: hide/show polylines
-    bool showPolylines;
+    bool showPolylines = true;
     /// vector maps only: hide/show point of interest
-    bool showPOIs;
+    bool showPOIs = true;
 
     /// streaming map only: path to cached tiles
     QString cachePath;
     /// streaming map only: maximum size of all tiles in cache [MByte]
-    qint32 cacheSizeMB;
+    qint32 cacheSizeMB = 100;
     /// streaming map only: maximum age of tiles in cache [days]
-    qint32 cacheExpiration;
+    qint32 cacheExpiration = 8;
 
     /// a copyright string to be displayed as tool tip
     QString copyright;
