@@ -28,19 +28,6 @@
 
 #include <QtCore>
 
-CGarminPoint::CGarminPoint()
-    : type(0)
-    , isLbl6(false)
-    , hasSubType(false)
-    , lbl_ptr(0xFFFFFFFF)
-{
-}
-
-
-CGarminPoint::~CGarminPoint()
-{
-}
-
 
 quint32 CGarminPoint::decode(qint32 iCenterLon, qint32 iCenterLat, quint32 shift, const quint8 * pData)
 {
@@ -57,8 +44,10 @@ quint32 CGarminPoint::decode(qint32 iCenterLon, qint32 iCenterLat, quint32 shift
 
     pData += 3;
 
-    dLng = gar_ptr_load(int16_t, pData); pData += 2;
-    dLat = gar_ptr_load(int16_t, pData); pData += 2;
+    dLng = gar_ptr_load(int16_t, pData);
+    pData += 2;
+    dLat = gar_ptr_load(int16_t, pData);
+    pData += 2;
 
     qint32 x1,y1;
 
@@ -98,8 +87,10 @@ quint32 CGarminPoint::decode2(qint32 iCenterLon, qint32 iCenterLat, quint32 shif
         byte_size += 1;
     }
 
-    dLng = gar_ptr_load(int16_t, pData); pData += 2;
-    dLat = gar_ptr_load(int16_t, pData); pData += 2;
+    dLng = gar_ptr_load(int16_t, pData);
+    pData += 2;
+    dLat = gar_ptr_load(int16_t, pData);
+    pData += 2;
 
     qint32 x1,y1;
 
