@@ -30,14 +30,6 @@
 
 #undef DBG
 
-CGarminTyp::CGarminTyp()
-{
-}
-
-
-CGarminTyp::~CGarminTyp()
-{
-}
 
 bool CGarminTyp::decode(const QByteArray& array, QMap<quint32, polygon_property>& polygons, QMap<quint32, polyline_property>& polylines, QList<quint32>& drawOrder, QMap<quint32, point_property>& points)
 {
@@ -235,7 +227,7 @@ bool CGarminTyp::parsePolygon(QDataStream& in, QMap<quint32, polygon_property>&
     const int N = sectPolygons.arraySize / sectPolygons.arrayModulo;
     for (int element = 0; element < N; element++)
     {
-        quint16 t16_1, t16_2, subtyp;
+        quint16 t16_1 = 0, t16_2, subtyp;
         quint8 t8;
         quint32 typ, offset=0;
         bool hasLocalization = false;
@@ -462,7 +454,7 @@ bool CGarminTyp::parsePolygon(QDataStream& in, QMap<quint32, polygon_property>&
         default:
             if(!tainted)
             {
-                QMessageBox::warning(&CMainWindow::self(), QObject::tr("Warning..."), QObject::tr("This is a typ file with unknown polygon encoding. Please report!"), QMessageBox::Abort, QMessageBox::Abort);
+                QMessageBox::warning(CMainWindow::getBestWidgetForParent(), QObject::tr("Warning..."), QObject::tr("This is a typ file with unknown polygon encoding. Please report!"), QMessageBox::Abort, QMessageBox::Abort);
                 tainted = true;
             }
             qDebug() << "Failed polygon:" << typ << subtyp << hex << typ << subtyp << ctyp;
@@ -549,7 +541,7 @@ bool CGarminTyp::parsePolyline(QDataStream& in, QMap<quint32, polyline_property>
     const int N = sectPolylines.arraySize / sectPolylines.arrayModulo;
     for (int element = 0; element < N; element++)
     {
-        quint16 t16_1, t16_2, subtyp;
+        quint16 t16_1 = 0, t16_2, subtyp;
         quint8 t8_1, t8_2;
         quint32 typ, offset=0;
         bool hasLocalization = false;
@@ -843,13 +835,14 @@ bool CGarminTyp::parsePolyline(QDataStream& in, QMap<quint32, polyline_property>
         default:
             if(!tainted)
             {
-                QMessageBox::warning(&CMainWindow::self(), QObject::tr("Warning..."), QObject::tr("This is a typ file with unknown polyline encoding. Please report!"), QMessageBox::Abort, QMessageBox::Abort);
+                QMessageBox::warning(CMainWindow::getBestWidgetForParent(), QObject::tr("Warning..."), QObject::tr("This is a typ file with unknown polyline encoding. Please report!"), QMessageBox::Abort, QMessageBox::Abort);
                 tainted = true;
             }
 
             qDebug() << "Failed polyline" <<  hex << ":" << typ <<  ctyp << rows;
             continue;
         }
+
         property.imgDay     = property.imgDay.convertToFormat(QImage::Format_ARGB32_Premultiplied);
         property.imgNight   = property.imgNight.convertToFormat(QImage::Format_ARGB32_Premultiplied);
         if(hasLocalization)
@@ -1136,7 +1129,7 @@ bool CGarminTyp::parsePoint(QDataStream& in, QMap<quint32, point_property>& poin
     const int N = sectPoints.arraySize / sectPoints.arrayModulo;
     for (int element=0; element < N; element++)
     {
-        quint16 t16_1, t16_2, subtyp;
+        quint16 t16_1 = 0, t16_2, subtyp;
         quint8 t8_1;
         quint32 typ, offset=0;
         bool hasLocalization = false;
