@@ -19,32 +19,30 @@
 #ifndef CMOUSEEDITAREA_H
 #define CMOUSEEDITAREA_H
 
-#include "mouse/IMouseEditLine.h"
+#include "gis/IGisItem.h"
+#include "mouse/line/IMouseEditLine.h"
 
 class CGisItemOvlArea;
 
 class CMouseEditArea : public IMouseEditLine
 {
     Q_OBJECT
-    public:
-        CMouseEditArea(const QPointF& point, CGisDraw * gis, CCanvas * parent);
-        CMouseEditArea(CGisItemOvlArea &area, CGisDraw * gis, CCanvas * parent);
-        virtual ~CMouseEditArea();
+public:
+    CMouseEditArea(const QPointF& point, CGisDraw * gis, CCanvas * parent);
+    CMouseEditArea(CGisItemOvlArea &area, CGisDraw * gis, CCanvas * parent);
+    virtual ~CMouseEditArea();
 
-        void mousePressEvent(QMouseEvent * e);
+    void mousePressEvent(QMouseEvent * e);
 
-    protected slots:
-        void slotAbort();
-        void slotCopyToNew();
-        void slotCopyToOrig();
+protected slots:
+    void slotAbort();
+    void slotCopyToNew();
+    void slotCopyToOrig();
 
-    protected:
-        virtual void drawLine(const QPolygonF& l, QPainter& p);
-        IGisLine * getGisLine();
-
-    private:
-        QString     key;
+protected:
+    void drawLine(const QPolygonF &l, const QColor color, int width, QPainter& p);
 
+    IGisLine * getGisLine();
 };
 
 #endif //CMOUSEEDITAREA_H
