@@ -22,6 +22,7 @@
 #include "gis/CGisWidget.h"
 #include "gis/WptIcons.h"
 #include "gis/wpt/CGisItemWpt.h"
+#include "helpers/CDraw.h"
 #include "mouse/CMouseMoveWpt.h"
 #include "units/IUnit.h"
 
@@ -79,7 +80,7 @@ void CMouseMoveWpt::draw(QPainter& p,  CCanvas::redraw_e needsRedraw, const QRec
     p.drawPolygon(arrow);
     p.restore();
 
-    CCanvas::drawText(str, p, (p2 + QPoint(0, -30)).toPoint(), Qt::darkBlue);
+    CDraw::text(str, p, (p2 + QPoint(0, -30)).toPoint(), Qt::darkBlue);
 
     p.drawPixmap(p1 - focus, icon);
     p.drawPixmap(p2 - focus, icon);
@@ -103,6 +104,8 @@ void CMouseMoveWpt::mousePressEvent(QMouseEvent * e)
     }
     else if(e->button() == Qt::LeftButton)
     {
+        QMutexLocker lock(&IGisItem::mutexItems);
+
         QPointF pos = e->pos();
         gis->convertPx2Rad(pos);
         CGisItemWpt * wpt = dynamic_cast<CGisItemWpt*>(CGisWidget::self().getItemByKey(key));
