@@ -16,7 +16,6 @@
 
 **********************************************************************************************/
 
-#include "GeoMath.h"
 #include "canvas/CCanvas.h"
 #include "gis/CGisDraw.h"
 #include "gis/CGisWidget.h"
@@ -24,16 +23,14 @@
 #include "gis/rte/CGisItemRte.h"
 #include "gis/trk/CGisItemTrk.h"
 #include "gis/wpt/CGisItemWpt.h"
-#include "helpers/CFadingIcon.h"
 #include "mouse/CMouseNormal.h"
 #include "mouse/CScrOptUnclutter.h"
+#include "widgets/CFadingIcon.h"
 
 #include <QtWidgets>
 
 CMouseNormal::CMouseNormal(CGisDraw *gis, CCanvas *canvas)
     : IMouse(gis, canvas)
-    , mapMove(false)
-    , stateItemSel(eStateIdle)
 {
     cursor = QCursor(QPixmap(":/cursors/cursorMoveMap.png"),0,0);
     screenUnclutter = new CScrOptUnclutter(this);
@@ -46,6 +43,7 @@ CMouseNormal::CMouseNormal(CGisDraw *gis, CCanvas *canvas)
 
     menu->addSeparator();
     menu->addAction(QIcon("://icons/32x32/Copy.png"), tr("Copy position"), this, SLOT(slotCopyPosition()));
+    menu->addAction(QIcon("://icons/32x32/Copy.png"), tr("Copy position (Grid)"), this, SLOT(slotCopyPositionGrid()));
 }
 
 CMouseNormal::~CMouseNormal()
@@ -114,20 +112,32 @@ void CMouseNormal::mouseMoveEvent(QMouseEvent * e)
         case eStateHooverSingle:
         case eStateHooverMultiple:
         {
-            const IGisItem::key_t& key = CGisItemTrk::getKeyUserFocus();
-            if(!key.item.isEmpty())
+            const IGisItem::key_t& keyTrk = CGisItemTrk::getKeyUserFocus();
+            if(!keyTrk.item.isEmpty())
             {
-                CGisItemTrk * trk = dynamic_cast<CGisItemTrk*>(CGisWidget::self().getItemByKey(key));
+                CGisItemTrk * trk = dynamic_cast<CGisItemTrk*>(CGisWidget::self().getItemByKey(keyTrk));
                 if(trk != 0)
                 {
                     trk->setMouseFocusByPoint(point, CGisItemTrk::eFocusMouseMove, "CMouseNormal");
                 }
             }
+
+            const IGisItem::key_t& keyRte = CGisItemRte::getKeyUserFocus();
+            if(!keyRte.item.isEmpty())
+            {
+                CGisItemRte * rte = dynamic_cast<CGisItemRte*>(CGisWidget::self().getItemByKey(keyRte));
+                if(rte != 0)
+                {
+                    rte->setMouseFocusByPoint(point, CGisItemRte::eFocusMouseMove, "CMouseNormal");
+                }
+            }
             break;
         }
 
-        default:;
+        default:
+            ;
         }
+
         canvas->displayInfo(point);
         canvas->update();
     }
@@ -191,20 +201,20 @@ void CMouseNormal::mouseReleaseEvent(QMouseEvent *e)
                         }
                     }
                 }
-                screenUnclutter->clear();
-                stateItemSel = eStateIdle;
+                resetState();
                 break;
             }
 
             case eStateShowItemOptions:
             {
-                delete screenItemOption;
-                stateItemSel = eStateIdle;
+                resetState();
                 break;
             }
 
-            default:;
+            default:
+                ;
             }
+
             canvas->update();
         }
         mapMove     = false;
@@ -216,15 +226,31 @@ void CMouseNormal::mouseDoubleClickEvent(QMouseEvent *e)
 {
     if(stateItemSel == eStateIdle)
     {
-        const IGisItem::key_t& key = CGisItemTrk::getKeyUserFocus();
-        CGisWidget::self().focusTrkByKey(false, key);
+        const IGisItem::key_t& keyTrk = CGisItemTrk::getKeyUserFocus();
+        CGisWidget::self().focusTrkByKey(false, keyTrk);
+
+        const IGisItem::key_t& keyRte = CGisItemRte::getKeyUserFocus();
+        CGisWidget::self().focusRteByKey(false, keyRte);
     }
 }
 
 void CMouseNormal::wheelEvent(QWheelEvent * e)
+{
+    resetState();
+}
+
+void CMouseNormal::keyPressEvent(QKeyEvent * e)
+{
+    resetState();
+}
+
+void CMouseNormal::resetState()
 {
     screenUnclutter->clear();
-    delete screenItemOption;
+    if(!screenItemOption.isNull())
+    {
+        screenItemOption->deleteLater();
+    }
     stateItemSel = eStateIdle;
 }
 
@@ -306,11 +332,16 @@ void CMouseNormal::draw(QPainter& p, CCanvas::redraw_e needsRedraw, const QRect
             break;
         }
 
-        screenItemOption->draw(p);
+        // the screen option might not be destroyed yet, but already hidden
+        if(screenItemOption->isVisible())
+        {
+            screenItemOption->draw(p);
+        }
         break;
     }
 
-    default:;
+    default:
+        ;
     }
 }
 
@@ -334,6 +365,7 @@ void CMouseNormal::slotAddWpt()
         return;
     }
 
+    QMutexLocker lock(&IGisItem::mutexItems);
     CGisItemWpt * wpt = new CGisItemWpt(pt, name, icon, project);
     wpt->edit();
 
@@ -374,7 +406,19 @@ void CMouseNormal::slotCopyPosition()
     gis->convertPx2Rad(pt);
 
     QString position;
-    GPS_Math_Deg_To_Str(pt.x() * RAD_TO_DEG, pt.y() * RAD_TO_DEG, position);
+    IUnit::degToStr(pt.x() * RAD_TO_DEG, pt.y() * RAD_TO_DEG, position);
+
+    QClipboard *clipboard = QApplication::clipboard();
+    clipboard->setText(position);
+}
+
+void CMouseNormal::slotCopyPositionGrid()
+{
+    QString position;
+    QPointF pt = point;
+    gis->convertPx2Rad(pt);
+
+    canvas->convertGridPos2Str(pt * RAD_TO_DEG, position, true);
 
     QClipboard *clipboard = QApplication::clipboard();
     clipboard->setText(position);
