@@ -44,6 +44,7 @@ public:
     void mouseReleaseEvent(QMouseEvent *e);
     void mouseDoubleClickEvent(QMouseEvent *e);
     void wheelEvent(QWheelEvent * e);
+    void keyPressEvent(QKeyEvent * e);
 
 private slots:
     void slotAddWpt();
@@ -51,18 +52,20 @@ private slots:
     void slotAddRte();
     void slotAddArea();
     void slotCopyPosition();
+    void slotCopyPositionGrid();
 
 private:
     bool setScreenOption(const QPoint& pt, IGisItem * item);
 
 protected:
     void stopTracking();
+    void resetState();
 
 
     /// the flag is true if the map moving is in progress
-    bool mapMove;
+    bool mapMove = false;
     /// the flag is true if the map has been moved actually
-    bool mapDidMove;
+    bool mapDidMove = false;
     /// always the last seen mouse cursor position
     QPoint lastPos;
 
@@ -81,7 +84,7 @@ protected:
         , eStateShowItemOptions = 4
     };
 
-    item_selection_states_e stateItemSel;
+    item_selection_states_e stateItemSel = eStateIdle;
 
     CScrOptUnclutter * screenUnclutter;
     QPointer<IScrOpt>  screenItemOption;
