@@ -28,8 +28,6 @@
 
 CMouseRangeTrk::CMouseRangeTrk(CGisItemTrk &trk, CGisDraw *gis, CCanvas *parent)
     : IMouse(gis, parent)
-    , state(eStateIdle)
-    , anchor(NOPOINTF)
 {
     cursor      = QCursor(QPixmap("://cursors/cursorSelectRange.png"),0,0);
     key         = trk.getKey();
@@ -124,6 +122,7 @@ void CMouseRangeTrk::mousePressEvent(QMouseEvent * e)
                 scrOptRange = new CScrOptRangeTrk(pt, trk, this);
                 connect(scrOptRange->toolHidePoints, SIGNAL(clicked()), this, SLOT(slotHidePoints()));
                 connect(scrOptRange->toolShowPoints, SIGNAL(clicked()), this, SLOT(slotShowPoints()));
+                connect(scrOptRange->toolActivity, SIGNAL(clicked()), this, SLOT(slotActivity()));
                 connect(scrOptRange->toolCopy, SIGNAL(clicked()), this, SLOT(slotCopy()));
 
                 state = eStateRangeSelected;
@@ -135,19 +134,13 @@ void CMouseRangeTrk::mousePressEvent(QMouseEvent * e)
 
         case eStateRangeSelected:
         {
-            scrOptRange->deleteLater();
-            CGisItemTrk * trk = dynamic_cast<CGisItemTrk*>(CGisWidget::self().getItemByKey(key));
-            if(trk != 0)
-            {
-                trk->setMouseFocusByPoint(NOPOINT, CGisItemTrk::eFocusMouseMove, "CMouseRangeTrk");
-                trk->setMouseFocusByPoint(NOPOINT, CGisItemTrk::eFocusMouseClick, "CMouseRangeTrk");
-            }
-            state = eStateIdle;
+            resetState();
             canvas->update();
             break;
         }
 
-        default:;
+        default:
+            ;
         }
     }
 }
@@ -191,7 +184,8 @@ void CMouseRangeTrk::mouseMoveEvent(QMouseEvent * e)
         break;
     }
 
-    default:;
+    default:
+        ;
     }
 
     lastPoint = point;
@@ -210,17 +204,37 @@ void CMouseRangeTrk::mouseReleaseEvent(QMouseEvent *e)
 
 void CMouseRangeTrk::wheelEvent(QWheelEvent * e)
 {
+    resetState();
 }
 
-void CMouseRangeTrk::slotHidePoints()
+void CMouseRangeTrk::keyPressEvent(QKeyEvent * e)
+{
+    resetState();
+}
+
+void CMouseRangeTrk::resetState()
 {
     CGisItemTrk * trk = dynamic_cast<CGisItemTrk*>(CGisWidget::self().getItemByKey(key));
     if(trk != 0)
     {
-        if(!trk->setReadOnlyMode(false))
-        {
-            return;
-        }
+        trk->setMouseFocusByPoint(NOPOINT, CGisItemTrk::eFocusMouseMove, "CMouseRangeTrk");
+        trk->setMouseFocusByPoint(NOPOINT, CGisItemTrk::eFocusMouseClick, "CMouseRangeTrk");
+    }
+
+    if(!scrOptRange.isNull())
+    {
+        scrOptRange->deleteLater();
+    }
+    state = eStateIdle;
+}
+
+void CMouseRangeTrk::slotHidePoints()
+{
+    QMutexLocker lock(&IGisItem::mutexItems);
+
+    CGisItemTrk * trk = dynamic_cast<CGisItemTrk*>(CGisWidget::self().getItemByKey(key));
+    if(trk != 0)
+    {
         trk->hideSelectedPoints();
         canvas->slotTriggerCompleteUpdate(CCanvas::eRedrawGis);
     }
@@ -231,14 +245,11 @@ void CMouseRangeTrk::slotHidePoints()
 
 void CMouseRangeTrk::slotShowPoints()
 {
+    QMutexLocker lock(&IGisItem::mutexItems);
+
     CGisItemTrk * trk = dynamic_cast<CGisItemTrk*>(CGisWidget::self().getItemByKey(key));
     if(trk != 0)
     {
-        if(!trk->setReadOnlyMode(false))
-        {
-            return;
-        }
-
         trk->showSelectedPoints();
         canvas->slotTriggerCompleteUpdate(CCanvas::eRedrawGis);
     }
@@ -247,8 +258,25 @@ void CMouseRangeTrk::slotShowPoints()
     canvas->resetMouse();
 }
 
+void CMouseRangeTrk::slotActivity()
+{
+    QMutexLocker lock(&IGisItem::mutexItems);
+
+    CGisItemTrk * trk = dynamic_cast<CGisItemTrk*>(CGisWidget::self().getItemByKey(key));
+    if(trk != 0)
+    {
+        trk->setActivity();
+        canvas->slotTriggerCompleteUpdate(CCanvas::eRedrawGis);
+    }
+
+    scrOptRange->deleteLater();
+    canvas->resetMouse();
+}
+
 void CMouseRangeTrk::slotCopy()
 {
+    QMutexLocker lock(&IGisItem::mutexItems);
+
     CGisItemTrk * trk = dynamic_cast<CGisItemTrk*>(CGisWidget::self().getItemByKey(key));
     if(trk != 0)
     {
