@@ -40,13 +40,16 @@ public:
     void mouseMoveEvent(QMouseEvent * e);
     void mouseReleaseEvent(QMouseEvent *e);
     void wheelEvent(QWheelEvent * e);
+    void keyPressEvent(QKeyEvent * e);
 
 private slots:
     void slotHidePoints();
     void slotShowPoints();
+    void slotActivity();
     void slotCopy();
 
 private:
+    void resetState();
     IGisItem::key_t key;
 
     enum state_e
@@ -57,9 +60,9 @@ private:
         ,eStateRangeSelected
     };
 
-    state_e state;
+    state_e state = eStateIdle;
 
-    QPointF anchor;
+    QPointF anchor = NOPOINTF;
 
     QPoint lastPoint;
 
