@@ -18,6 +18,7 @@
 
 #include "CMainWindow.h"
 #include "gis/trk/CGisItemTrk.h"
+#include "helpers/CDraw.h"
 #include "mouse/CScrOptRangeTrk.h"
 
 #include <QtWidgets>
@@ -38,6 +39,11 @@ CScrOptRangeTrk::CScrOptRangeTrk(const QPointF &point, CGisItemTrk * trk, IMouse
 
     move(point.toPoint() + QPoint(-width()/2,SCR_OPT_OFFSET));
     show();
+
+    connect(toolHidePoints, SIGNAL(clicked()), this, SLOT(hide()));
+    connect(toolShowPoints, SIGNAL(clicked()), this, SLOT(hide()));
+    connect(toolActivity,   SIGNAL(clicked()), this, SLOT(hide()));
+    connect(toolCopy,       SIGNAL(clicked()), this, SLOT(hide()));
 }
 
 CScrOptRangeTrk::~CScrOptRangeTrk()
@@ -46,6 +52,9 @@ CScrOptRangeTrk::~CScrOptRangeTrk()
 
 void CScrOptRangeTrk::draw(QPainter& p)
 {
-    drawBubble2(origin, p);
+    if(isVisible())
+    {
+        CDraw::bubble(p, geometry(), origin);
+    }
 }
 
