@@ -26,11 +26,11 @@ class CGisItemTrk;
 
 class CScrOptRangeTrk : public IScrOpt, public Ui::IScrOptRangeTrk
 {
-    public:
-        CScrOptRangeTrk(const QPointF& point, CGisItemTrk *trk, QWidget * parent);
-        virtual ~CScrOptRangeTrk();
+public:
+    CScrOptRangeTrk(const QPointF& point, CGisItemTrk *trk, IMouse *mouse, QWidget * parent = 0);
+    virtual ~CScrOptRangeTrk();
 
-        void draw(QPainter& p);
+    void draw(QPainter& p);
 };
 
 #endif //CSCROPTRANGETRK_H
