@@ -20,6 +20,7 @@
 #include "canvas/CCanvas.h"
 #include "gis/IGisItem.h"
 #include "gis/trk/CGisItemTrk.h"
+#include "helpers/CDraw.h"
 #include "mouse/CScrOptUnclutter.h"
 
 #include <QtWidgets>
@@ -93,7 +94,6 @@ const QPoint CScrOptUnclutter::positions[9][8] =
 
 CScrOptUnclutter::CScrOptUnclutter(IMouse *mouse)
     : IScrOpt(mouse)
-    , doSpecialCursor(false)
 {
 }
 
@@ -105,7 +105,7 @@ void CScrOptUnclutter::clear()
 {
     if(doSpecialCursor)
     {
-        QApplication::restoreOverrideCursor();
+        CCanvas::restoreOverrideCursor("CScrOptUnclutter::clear()");
         doSpecialCursor = false;
     }
     items.clear();
@@ -121,7 +121,7 @@ void CScrOptUnclutter::mouseMoveEvent(QMouseEvent * e)
         {
             if(!doSpecialCursor)
             {
-                QApplication::setOverrideCursor(Qt::PointingHandCursor);
+                CCanvas::setOverrideCursor(Qt::PointingHandCursor,"CScrOptUnclutter::mouseMoveEvent");
                 doSpecialCursor = true;
             }
             return;
@@ -130,7 +130,7 @@ void CScrOptUnclutter::mouseMoveEvent(QMouseEvent * e)
 
     if(doSpecialCursor)
     {
-        QApplication::restoreOverrideCursor();
+        CCanvas::restoreOverrideCursor("CScrOptUnclutter::mouseMoveEvent");
         doSpecialCursor = false;
         return;
     }
@@ -208,7 +208,7 @@ void CScrOptUnclutter::draw(QPainter& p)
         p.drawEllipse(item.area.center(), 18,18);
 
         p.drawPixmap(item.area, item.icon);
-        CCanvas::drawText(item.name, p, item.text, Qt::darkBlue);
+        CDraw::text(item.name, p, item.text, Qt::darkBlue);
     }
 }
 
