@@ -16,7 +16,7 @@
 
 **********************************************************************************************/
 
-#include "canvas/CCanvas.h"
+#include "helpers/CDraw.h"
 #include "mouse/IMouse.h"
 #include "mouse/IScrOpt.h"
 #include "units/IUnit.h"
@@ -32,9 +32,9 @@ IScrOpt::IScrOpt(IMouse *mouse)
 
 IScrOpt::~IScrOpt()
 {
-    if(!mouse.isNull() && hasFocus())
+    if(hasFocus() && !mouse.isNull())
     {
-        QApplication::changeOverrideCursor(*mouse);
+        CCanvas::setOverrideCursor(*mouse,"IScrOpt::~IScrOpt");
     }
 }
 
@@ -47,7 +47,7 @@ void IScrOpt::mouseMoveEvent(QMouseEvent * e)
 void IScrOpt::enterEvent(QEvent * e)
 {
     QWidget::enterEvent(e);
-    QApplication::changeOverrideCursor(Qt::ArrowCursor);
+    CCanvas::restoreOverrideCursor("IScrOpt::enterEvent");
 }
 
 
@@ -56,45 +56,7 @@ void IScrOpt::leaveEvent(QEvent * e)
     QWidget::leaveEvent(e);
     if(!mouse.isNull())
     {
-        QApplication::changeOverrideCursor(*mouse);
+        CCanvas::setOverrideCursor(*mouse,"IScrOpt::leaveEvent");
     }
 }
 
-
-void IScrOpt::drawBubble1(const QPointF& pt, QPainter& p)
-{
-    QRectF r = rect();
-    r.moveTopLeft(QPoint(x(), y()));
-    QPainterPath path1;
-    path1.addRoundedRect(r,5,5);
-
-    QPolygonF poly2;
-    poly2 << pt << (r.topLeft() + QPointF(10,0)) << (r.topLeft() + QPointF(0,10)) << pt;
-    QPainterPath path2;
-    path2.addPolygon(poly2);
-
-    path1 = path1.united(path2);
-
-    p.setPen(CCanvas::penBorderGray);
-    p.setBrush(CCanvas::brushBackWhite);
-    p.drawPolygon(path1.toFillPolygon());
-}
-
-void IScrOpt::drawBubble2(const QPointF &pt, QPainter& p)
-{
-    QRectF r = rect();
-    r.moveTopLeft(QPoint(x(), y()));
-    QPainterPath path1;
-    path1.addRoundedRect(r,5,5);
-
-    QPolygonF poly2;
-    poly2 << pt << QPointF(pt.x() - 10, r.top() + 1) << QPointF(pt.x() + 10, r.top() + 1) << pt;
-    QPainterPath path2;
-    path2.addPolygon(poly2);
-
-    path1 = path1.united(path2);
-
-    p.setPen(CCanvas::penBorderGray);
-    p.setBrush(CCanvas::brushBackWhite);
-    p.drawPolygon(path1.toFillPolygon());
-}
