@@ -39,9 +39,11 @@ public:
 
     void append();
 
+    bool abortStep();
+
 private:
-    bool addPoint;
-    bool isPoint;
+    bool addPoint = false;
+    bool isPoint = false;
 };
 
 #endif //CLINEOPADDPOINT_H
