@@ -37,8 +37,10 @@ public:
 
     void canvasPanned(QPointF pos);
 
+    bool abortStep();
+
 private:
-    bool movePoint;
+    bool movePoint = false;
 };
 
 #endif //CLINEOPMOVEPOINT_H
