@@ -27,21 +27,6 @@ inline qreal qLog10(qreal x)
 
 CPlotAxis::CPlotAxis( QObject * parent )
     : QObject( parent )
-    , initialized( false )
-    , autoscale( false )
-    , valid(false)
-    , scale( 1.0 )
-    , usedMin( 0.0 )
-    , usedMax( 0.0 )
-    , limitMin( 0.0 )
-    , limitMax( 0.0 )
-    , interval( 0.0 )
-    , ticStart( 0 )
-    , scaleWidth( 0 )
-    , ticType( eTicNorm )
-    , firstTic( false )
-    , lastTic( false )
-    , points(0)
 {
 }
 
@@ -135,11 +120,6 @@ void CPlotAxis::calc()
         usedMin = qFloor( usedMin / interval ) * interval;
         usedMax = qCeil( usedMax / interval ) * interval;
     }
-    else
-    {
-        usedMin = usedMin;
-        usedMax = usedMax;
-    }
 
     int t1 = ( int )( usedMin / interval + 0.5);
     ticStart = interval * t1;
@@ -406,7 +386,7 @@ void CPlotAxis::resetZoom()
 
 void CPlotAxis::zoom(bool in, int point)
 {
-    qreal min, p, d, factor;
+    qreal min, max, p, d, factor;
     if (in)
     {
         factor = 1/1.1;
@@ -419,9 +399,14 @@ void CPlotAxis::zoom(bool in, int point)
     p = pt2val(point);
     min = (p - usedMin) * (1 - factor) + usedMin;
     d = min - usedMin * factor;
+    max = usedMax * factor + d;
 
-    setMinMax(min, usedMax * factor + d);
-    move(0);
+
+    if(qRound(max - min) <= qRound(limitMax - limitMin))
+    {
+        setMinMax(min, max);
+        move(0);
+    }
 }
 
 
