@@ -23,14 +23,21 @@
 
 CPlotData::CPlotData(axistype_e type, QObject * parent)
     : QObject(parent)
-    , grid(true)
-    , badData(true)
     , axisType(type)
-    , xmin(0)
-    , xmax(0)
-    , ymin(0)
-    , ymax(0)
 {
+    setXAxisType(type);
+    yaxis = new CPlotAxis(this);
+}
+
+
+CPlotData::~CPlotData()
+{
+}
+
+void CPlotData::setXAxisType(axistype_e type)
+{
+    delete xaxis;
+
     if(type == eAxisLinear)
     {
         xaxis = new CPlotAxis(this);
@@ -40,15 +47,10 @@ CPlotData::CPlotData(axistype_e type, QObject * parent)
         xaxis = new CPlotAxisTime(this);
     }
     xaxis->setAutoscale(false);
-    yaxis = new CPlotAxis(this);
+
+    axisType = type;
 }
 
-
-CPlotData::~CPlotData()
-{
-}
-
-
 void CPlotData::setLimits()
 {
     if(lines.size() == 0 || badData)
