@@ -46,6 +46,9 @@ public:
         return *yaxis;
     }
 
+    /// create a new x axis
+    void setXAxisType(axistype_e type);
+
     /// setup all internal data to fit the dynamic range of all data points
     void setLimits();
 
@@ -61,7 +64,7 @@ public:
     /// text shown left of the y axis
     QString ylabel;
     /// set true for grid
-    bool grid;
+    bool grid = true;
 
     /// list of plot lines
     QList<line_t> lines;
@@ -79,18 +82,18 @@ public:
     /// vector of plot tags such as waypoints
     QVector<point_t> tags;
 
-    bool badData;
+    bool badData = true;
 
-    axistype_e axisType;
+    axistype_e axisType = eAxisLinear;
 
-    qreal xmin;
-    qreal xmax;
-    qreal ymin;
-    qreal ymax;
+    qreal xmin = 0;
+    qreal xmax = 0;
+    qreal ymin = 0;
+    qreal ymax = 0;
 
 protected:
-    CPlotAxis * xaxis;
-    CPlotAxis * yaxis;
+    CPlotAxis * xaxis = nullptr;
+    CPlotAxis * yaxis = nullptr;
 };
 
 #endif //CPLOTDATA_H
