@@ -20,12 +20,14 @@
 #include "plot/IPlot.h"
 
 #include "CMainWindow.h"
-#include "canvas/CCanvas.h"
 #include "gis/CGisWidget.h"
-#include "helpers/CFadingIcon.h"
+#include "gis/trk/CActivityTrk.h"
+#include "helpers/CDraw.h"
 #include "helpers/CSettings.h"
 #include "mouse/CScrOptRangeTrk.h"
+#include "widgets/CFadingIcon.h"
 
+#include <QKeyEvent>
 #include <QtWidgets>
 
 QPen IPlot::pens[] =
@@ -57,27 +59,8 @@ int IPlot::cnt = 0;
 IPlot::IPlot(CGisItemTrk *trk, CPlotData::axistype_e type, mode_e mode, QWidget *parent)
     : QWidget(parent)
     , mode(mode)
-    , needsRedraw(true)
-    , showScale(true)
-    , thinLine(false)
-    , solid(false)
-    , posMouse(NOPOINT)
     , trk(trk)
     , fm(font())
-    , left(0)
-    , right(0)
-    , top(0)
-    , bottom(0)
-    , deadAreaX(0)
-    , deadAreaY(0)
-    , fontWidth(0)
-    , fontHeight(0)
-    , scaleWidthX1(0)
-    , scaleWidthY1(0)
-    , idxSel1(NOIDX)
-    , idxSel2(NOIDX)
-    , mouseClickState(eMouseClickIdle)
-
 {
     cnt++;
     setObjectName(QString("IPlot%1").arg(cnt));
@@ -105,6 +88,7 @@ IPlot::IPlot(CGisItemTrk *trk, CPlotData::axistype_e type, mode_e mode, QWidget
     }
 
     menu = new QMenu(this);
+    actionResetZoom = menu->addAction(QIcon("://icons/32x32/Zoom.png"), tr("Reset Zoom"), this, SLOT(slotResetZoom()));
     actionStopRange = menu->addAction(QIcon("://icons/32x32/SelectRange.png"), tr("Stop Range"), this, SLOT(slotStopRange()));
     actionPrint     = menu->addAction(QIcon("://icons/32x32/Save.png"), tr("Save..."), this, SLOT(slotSave()));
 
@@ -249,7 +233,7 @@ void IPlot::leaveEvent(QEvent * e)
     needsRedraw = true;
     posMouse    = NOPOINT;
 
-    QApplication::restoreOverrideCursor();
+    CCanvas::restoreOverrideCursor("IPlot::leaveEvent");
     update();
 }
 
@@ -257,7 +241,7 @@ void IPlot::leaveEvent(QEvent * e)
 void IPlot::enterEvent(QEvent * e)
 {
     needsRedraw = true;
-    QApplication::setOverrideCursor(Qt::PointingHandCursor);
+    CCanvas::setOverrideCursor(Qt::PointingHandCursor,"IPlot::enterEvent");
     update();
 }
 
@@ -274,6 +258,20 @@ void IPlot::draw(QPainter& p)
     drawDecoration(p);
 }
 
+void IPlot::keyPressEvent(QKeyEvent *e)
+{
+    // close the current window if `Esc` was pressed
+    if(Qt::Key_Escape == e->key())
+    {
+        e->accept();
+        deleteLater();
+    }
+    else
+    {
+        QWidget::keyPressEvent(e);
+    }
+}
+
 void IPlot::mouseMoveEvent(QMouseEvent * e)
 {
     if(data->lines.isEmpty() || data->badData || !data->x().isValid() || !data->y().isValid())
@@ -387,9 +385,10 @@ void IPlot::mousePressEvent(QMouseEvent * e)
                 scrOptRange = new CScrOptRangeTrk(e->pos(), trk, &dummyMouse, this);
                 connect(scrOptRange->toolHidePoints, SIGNAL(clicked()), this, SLOT(slotHidePoints()));
                 connect(scrOptRange->toolShowPoints, SIGNAL(clicked()), this, SLOT(slotShowPoints()));
+                connect(scrOptRange->toolActivity, SIGNAL(clicked()), this, SLOT(slotActivity()));
                 connect(scrOptRange->toolCopy, SIGNAL(clicked()), this, SLOT(slotCopy()));
 
-                /* Adjust posiion of screen option widget if the widget is out of the visible area*/
+                /* Adjust position of screen option widget if the widget is out of the visible area*/
                 QRect r1 = scrOptRange->geometry();
                 QRect r2 = geometry();
                 r1.moveTopLeft(mapToParent(r1.topLeft()));
@@ -431,7 +430,7 @@ void IPlot::mousePressEvent(QMouseEvent * e)
             }
 
 
-            // Update canvas only if the object ist the owener of the range selection
+            // Update canvas only if the object is the owner of the range selection
             if(wasProcessed)
             {
                 emit sigMouseClickState(mouseClickState);
@@ -449,6 +448,18 @@ void IPlot::mousePressEvent(QMouseEvent * e)
     update();
 }
 
+void IPlot::wheelEvent( QWheelEvent * e)
+{
+    bool in = CMainWindow::self().flipMouseWheel() ? (e->delta() < 0) : (e->delta() > 0);
+
+    data->x().zoom(in, e->pos().x() - left);
+    setSizes();
+    data->x().setScale(rectGraphArea.width());
+
+    needsRedraw = true;
+    update();
+}
+
 void IPlot::setSizes()
 {
     fm = QFontMetrics(CMainWindow::self().getMapFont());
@@ -584,12 +595,12 @@ void IPlot::draw()
         r.adjust(2,2,-2,-2);
         if(underMouse() || posMouse != NOPOINT || solid)
         {
-            p.setPen(solid ? CCanvas::penBorderBlack : CCanvas::penBorderBlue);
+            p.setPen(solid ? CDraw::penBorderBlack : CDraw::penBorderBlue);
             p.setOpacity(1.0);
         }
         else
         {
-            p.setPen(CCanvas::penBorderBlack);
+            p.setPen(CDraw::penBorderBlack);
             p.setOpacity(0.6);
         }
         p.setBrush(QColor(255,255,255,255));
@@ -617,6 +628,7 @@ void IPlot::draw()
     }
     drawGridX(p);
     drawGridY(p);
+    drawActivities(p);
     drawXTic(p);
     drawYTic(p);
     p.setPen(QPen(Qt::black,2));
@@ -635,6 +647,8 @@ void IPlot::drawData(QPainter& p)
     CPlotAxis& xaxis = data->x();
     CPlotAxis& yaxis = data->y();
 
+    int zero = bottom - yaxis.val2pt(0);
+
     while(line != lines.end())
     {
         QPolygonF background;
@@ -647,7 +661,7 @@ void IPlot::drawData(QPainter& p)
         pty = bottom - yaxis.val2pt( point->y() );
         oldPtx = ptx;
 
-        background << QPointF(left,bottom);
+        background << QPointF(left,zero);
         background << QPointF(left,pty);
         background << QPointF(ptx,pty);
         foreground << QPointF(ptx,pty);
@@ -673,7 +687,7 @@ void IPlot::drawData(QPainter& p)
         }
 
         background << QPointF(right,pty);
-        background << QPointF(right,bottom);
+        background << QPointF(right,zero);
 
         p.setPen(Qt::NoPen);
         p.setBrush(colors[penIdx]);
@@ -744,7 +758,7 @@ void IPlot::drawXScale( QPainter &p )
     qreal limMin, limMax, useMin, useMax;
     data->x().getLimits(limMin, limMax, useMin, useMax);
 
-    if((limMax - limMin) <= (useMax - useMin))
+    if(!isZoomed())
     {
         return;
     }
@@ -781,7 +795,7 @@ void IPlot::drawYScale( QPainter &p )
     qreal limMin, limMax, useMin, useMax;
     data->y().getLimits(limMin, limMax, useMin, useMax);
 
-    // draw min/max lables 1st;
+    // draw min/max labels 1st;
     QRect recTextMin;
     QRect recTextMax;
 
@@ -818,7 +832,7 @@ void IPlot::drawYScale( QPainter &p )
         t = data->y().ticmark( t );
     }
 
-    if((limMax - limMin) <= (useMax - useMin))
+    if(!isZoomed())
     {
         return;
     }
@@ -1102,6 +1116,63 @@ void IPlot::drawTags(QPainter& p)
     }
 }
 
+void IPlot::drawActivities(QPainter& p)
+{
+    if((mode == eModeIcon) || (trk->getActivities().getAllFlags() == 0))
+    {
+        return;
+    }
+
+    const QList<CActivityTrk::activity_range_t>& ranges = trk->getActivities().getActivityRanges();
+
+
+    QRect rectClipping = QRect(0,0,right - left,22);
+    p.save();
+    p.translate(left, bottom - 22);
+    p.setClipRect(rectClipping);
+    p.setBrush(QColor(0,170,0,100));
+    p.setPen(Qt::NoPen);
+    p.drawRect(rectClipping);
+
+    QRect rectIconFrame(0,0,20,20);
+    QRect rectIcon(2,2,16,16);
+    foreach(const CActivityTrk::activity_range_t& range, ranges)
+    {
+        int x1, x2;
+        if(data->axisType == CPlotData::eAxisTime)
+        {
+            x1 = data->x().val2pt(range.t1);
+            x2 = data->x().val2pt(range.t2);
+        }
+        else
+        {
+            x1 = data->x().val2pt(range.d1);
+            x2 = data->x().val2pt(range.d2);
+        }
+
+        p.setPen(QPen(Qt::darkGreen,2));
+        p.drawLine(x1,0,x1,20);
+        p.drawLine(x2,0,x2,20);
+
+        int d = (x2 - x1);
+        if(d < 20)
+        {
+            continue;
+        }
+
+        int c = x1 + d/2;
+
+        rectIconFrame.moveCenter(QPoint(c,10));
+        p.setBrush(QColor(255,255,255,100));
+        p.drawRoundedRect(rectIconFrame,3,3);
+
+        rectIcon.moveCenter(QPoint(c,10));
+        p.drawPixmap(rectIcon, QPixmap(range.icon));
+    }
+
+    p.restore();
+}
+
 void IPlot::save(QImage& image)
 {
     resize(image.size());
@@ -1115,6 +1186,7 @@ void IPlot::slotContextMenu(const QPoint & point)
 {
     QPoint p = mapToGlobal(point);
 
+    actionResetZoom->setEnabled(isZoomed());
     actionStopRange->setEnabled((mouseClickState != eMouseClickIdle) && !(idxSel1 == NOIDX || idxSel2 == NOIDX));
     actionPrint->setEnabled(mouseClickState != eMouseClick2nd);
 
@@ -1125,7 +1197,7 @@ void IPlot::slotSave()
 {
     SETTINGS;
     QString path = cfg.value("Paths/lastGraphPath", QDir::homePath()).toString();
-    QString filename = QFileDialog::getSaveFileName( this, tr("Select output file"), path,"Bitmap (*.png)");
+    QString filename = QFileDialog::getSaveFileName( this, tr("Select output file"), path, "PNG Image (*.png)");
 
     if(filename.isEmpty())
     {
@@ -1155,51 +1227,30 @@ void IPlot::slotSave()
 void IPlot::slotHidePoints()
 {
     trk->hideSelectedPoints();
-    scrOptRange->deleteLater();
-
-    CCanvas * canvas = CMainWindow::self().getVisibleCanvas();
-    if(canvas)
-    {
-        canvas->slotTriggerCompleteUpdate(CCanvas::eRedrawGis);
-    }
-
-    trk->setMode(CGisItemTrk::eModeNormal, objectName());
-    mouseClickState = eMouseClickIdle;
+    slotStopRange();
 }
 
 void IPlot::slotShowPoints()
 {
     trk->showSelectedPoints();
-    scrOptRange->deleteLater();
+    slotStopRange();
+}
 
-    CCanvas * canvas = CMainWindow::self().getVisibleCanvas();
-    if(canvas)
-    {
-        canvas->slotTriggerCompleteUpdate(CCanvas::eRedrawGis);
-    }
-
-    trk->setMode(CGisItemTrk::eModeNormal, objectName());
-    mouseClickState = eMouseClickIdle;
+void IPlot::slotActivity()
+{
+    trk->setActivity();
+    slotStopRange();
 }
 
 void IPlot::slotCopy()
 {
     trk->copySelectedPoints();
-    scrOptRange->deleteLater();
-
-    CCanvas * canvas = CMainWindow::self().getVisibleCanvas();
-    if(canvas)
-    {
-        canvas->slotTriggerCompleteUpdate(CCanvas::eRedrawGis);
-    }
-
-    trk->setMode(CGisItemTrk::eModeNormal, objectName());
-    mouseClickState = eMouseClickIdle;
+    slotStopRange();
 }
 
 void IPlot::slotStopRange()
 {
-    delete scrOptRange;
+    scrOptRange->deleteLater();
     trk->setMode(CGisItemTrk::eModeNormal, objectName());
     idxSel1 = idxSel2 = NOIDX;
     mouseClickState = eMouseClickIdle;
@@ -1214,6 +1265,16 @@ void IPlot::slotStopRange()
     }
 }
 
+void IPlot::slotResetZoom()
+{
+    data->x().resetZoom();
+    setSizes();
+
+    needsRedraw = true;
+    update();
+}
+
+
 void IPlot::setMouseRangeFocus(const CGisItemTrk::trkpt_t * ptRange1, const CGisItemTrk::trkpt_t *ptRange2)
 {
     if(ptRange1 == 0 || ptRange2 == 0)
@@ -1251,3 +1312,11 @@ void IPlot::setMouseRangeFocus(const CGisItemTrk::trkpt_t * ptRange1, const CGis
     }
     update();
 }
+
+bool IPlot::isZoomed()
+{
+    qreal limMin, limMax, useMin, useMax;
+    data->x().getLimits(limMin, limMax, useMin, useMax);
+
+    return !((limMax - limMin) <= (useMax - useMin));
+}
