@@ -32,6 +32,7 @@
 #include "gis/rte/CGisItemRte.h"
 #include "gis/trk/CGisItemTrk.h"
 #include "gis/wpt/CGisItemWpt.h"
+#include "helpers/CProgressDialog.h"
 
 #include "CMainWindow.h"
 
@@ -118,7 +119,7 @@ void CQlgtDb::initDB()
     {
         query.prepare( "INSERT INTO versioninfo (version) VALUES(:version)");
         query.bindValue(":version", DB_QLGT_VERSION);
-        QUERY_EXEC(; );
+        QUERY_EXEC();
     }
 
     if(!query.exec( "CREATE TABLE folders ("
@@ -304,7 +305,7 @@ void CQlgtDb::migrateDB(int version)
 
             const int total = query.size();
             quint32 progCnt = 0;
-            PROGRESS_SETUP(tr("Migrating database from version 4 to 5."), &CMainWindow::self());
+            PROGRESS_SETUP(tr("Migrating database from version 4 to 5."), 0, total, CMainWindow::getBestWidgetForParent());
 
             while(query.next())
             {
@@ -340,7 +341,7 @@ void CQlgtDb::migrateDB(int version)
                     return;
                 }
 
-                PROGRESS(progCnt++, total, continue);
+                PROGRESS(progCnt++, continue);
             }
             break;
         }
@@ -358,7 +359,7 @@ void CQlgtDb::migrateDB(int version)
 
             const int total = query.size();
             quint32 progCnt = 0;
-            PROGRESS_SETUP(tr("Migrating database from version 5 to 6."), &CMainWindow::self());
+            PROGRESS_SETUP(tr("Migrating database from version 5 to 6."), 0, total, CMainWindow::getBestWidgetForParent());
 
             while(query.next())
             {
@@ -397,7 +398,7 @@ void CQlgtDb::migrateDB(int version)
                     return;
                 }
 
-                PROGRESS(progCnt++, total, continue);
+                PROGRESS(progCnt++, continue);
             }
 
             break;
@@ -416,7 +417,7 @@ void CQlgtDb::migrateDB(int version)
 
             const int total = query.size();
             quint32 progCnt = 0;
-            PROGRESS_SETUP(tr("Migrating database from version 6 to 7."), &CMainWindow::self());
+            PROGRESS_SETUP(tr("Migrating database from version 6 to 7."), 0, total, CMainWindow::getBestWidgetForParent());
 
             while(query.next())
             {
@@ -474,7 +475,7 @@ void CQlgtDb::migrateDB(int version)
                     return;
                 }
 
-                PROGRESS(progCnt++, total, continue);
+                PROGRESS(progCnt++, continue);
             }
 
             break;
@@ -482,7 +483,7 @@ void CQlgtDb::migrateDB(int version)
 
         case 8:
         {
-            PROGRESS_SETUP(tr("Migrating database from version 7 to 8."), &CMainWindow::self());
+            PROGRESS_SETUP(tr("Migrating database from version 7 to 8."), 0, 1, CMainWindow::getBestWidgetForParent());
 
             if(!query.exec( "CREATE TABLE diarys ("
                             "id             INTEGER PRIMARY KEY AUTOINCREMENT,"
@@ -498,7 +499,7 @@ void CQlgtDb::migrateDB(int version)
                 return;
             }
 
-            PROGRESS(1, 1, return );
+            PROGRESS(1, return );
             break;
         }
 
@@ -511,7 +512,7 @@ void CQlgtDb::migrateDB(int version)
             QFile f(path.absoluteFilePath(name));
             f.copy(path.absoluteFilePath("qlgt_save_v4.db"));
 
-            PROGRESS_SETUP(tr("Migrating database from version 8 to 9."), &CMainWindow::self());
+            PROGRESS_SETUP(tr("Migrating database from version 8 to 9."), 0, 1, CMainWindow::getBestWidgetForParent());
 
             if(!query.exec("ALTER TABLE folders ADD COLUMN locked BOOLEAN DEFAULT FALSE"))
             {
@@ -520,14 +521,14 @@ void CQlgtDb::migrateDB(int version)
                 return;
             }
 
-            PROGRESS(1, 1, return );
+            PROGRESS(1, return );
             break;
         }
         }
     }
     query.prepare( "UPDATE versioninfo set version=:version");
     query.bindValue(":version", version - 1);
-    QUERY_EXEC(; );
+    QUERY_EXEC();
 }
 
 void CQlgtDb::printStatistic()
@@ -539,7 +540,7 @@ void CQlgtDb::printStatistic()
     nItems = 0;
 
     query.prepare("SELECT COUNT() FROM folders");
-    QUERY_EXEC(; );
+    QUERY_EXEC();
     if(query.next())
     {
         nFolders = query.value(0).toInt();
@@ -548,7 +549,7 @@ void CQlgtDb::printStatistic()
 
     query.prepare("SELECT COUNT() FROM items WHERE type=:type");
     query.bindValue(":type", eTrk);
-    QUERY_EXEC(; );
+    QUERY_EXEC();
     if(query.next())
     {
         nItems += query.value(0).toInt();
@@ -556,7 +557,7 @@ void CQlgtDb::printStatistic()
     }
     query.prepare("SELECT COUNT() FROM items WHERE type=:type");
     query.bindValue(":type", eRte);
-    QUERY_EXEC(; );
+    QUERY_EXEC();
     if(query.next())
     {
         nItems += query.value(0).toInt();
@@ -564,7 +565,7 @@ void CQlgtDb::printStatistic()
     }
     query.prepare("SELECT COUNT() FROM items WHERE type=:type");
     query.bindValue(":type", eWpt);
-    QUERY_EXEC(; );
+    QUERY_EXEC();
     if(query.next())
     {
         nItems += query.value(0).toInt();
@@ -572,7 +573,7 @@ void CQlgtDb::printStatistic()
     }
     query.prepare("SELECT COUNT() FROM items WHERE type=:type");
     query.bindValue(":type", eOvl);
-    QUERY_EXEC(; );
+    QUERY_EXEC();
     if(query.next())
     {
         nItems += query.value(0).toInt();
@@ -580,14 +581,14 @@ void CQlgtDb::printStatistic()
     }
     query.prepare("SELECT COUNT() FROM diarys");
     query.bindValue(":type", eDry);
-    QUERY_EXEC(; );
+    QUERY_EXEC();
     if(query.next())
     {
         gui->stdOut(tr("Diaries:          %1").arg(query.value(0).toInt()));
     }
     query.prepare("SELECT COUNT() FROM items WHERE type=:type");
     query.bindValue(":type", eMap);
-    QUERY_EXEC(; );
+    QUERY_EXEC();
     if(query.next())
     {
         gui->stdErr(tr("Map selections:   %1 (can't be converted to QMapShack)").arg(query.value(0).toInt()));
@@ -611,7 +612,7 @@ void CQlgtDb::start(const QString& filename)
 
     QSqlQuery query(db);
     query.prepare("Select parent, child FROM folder2folder");
-    QUERY_EXEC(return; );
+    QUERY_EXEC(return );
     while(query.next())
     {
         quint64 idParent    = query.value(0).toULongLong();
@@ -620,7 +621,7 @@ void CQlgtDb::start(const QString& filename)
     }
 
     query.prepare("Select parent, child FROM folder2item");
-    QUERY_EXEC(return; );
+    QUERY_EXEC(return );
     while(query.next())
     {
         quint64 idParent    = query.value(0).toULongLong();
@@ -637,19 +638,14 @@ void CQlgtDb::xferFolders()
     nDiary = 0;
 
     quint32 cnt = 1;
-    QProgressDialog progress(tr("Restore folders..."),tr("Abort"), 0, 100, gui);
-    progress.setWindowModality(Qt::WindowModal);
+    PROGRESS_SETUP(tr("Restore folders..."), 0, nFolders, gui);
 
     QSqlQuery query(db);
     query.prepare("SELECT id FROM folders");
-    QUERY_EXEC(return; );
+    QUERY_EXEC(return );
     while(query.next())
     {
-        progress.setValue(cnt++ *100 / nFolders);
-        if (progress.wasCanceled())
-        {
-            break;
-        }
+        PROGRESS(cnt++, break);
 
         quint64 idFolder = query.value(0).toULongLong();
 
@@ -660,8 +656,6 @@ void CQlgtDb::xferFolders()
         }
 
         dbQms->addFolder(folder1);
-
-        qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
     }
     progress.setValue(100);
     gui->stdOut(tr("Imported %1 folders and %2 diaries").arg(nFolders).arg(nDiary));
@@ -670,8 +664,7 @@ void CQlgtDb::xferFolders()
 void CQlgtDb::xferItems()
 {
     quint32 cnt = 1;
-    QProgressDialog progress(tr("Copy items..."),tr("Abort"), 0, 100, gui);
-    progress.setWindowModality(Qt::WindowModal);
+    PROGRESS_SETUP(tr("Copy items..."), 0, nItems, gui);
 
     nWpt = 0;
     nTrk = 0;
@@ -681,15 +674,10 @@ void CQlgtDb::xferItems()
 
     QSqlQuery query(db);
     query.prepare("SELECT id FROM items");
-    QUERY_EXEC(return; );
+    QUERY_EXEC(return );
     while(query.next())
     {
-        progress.setValue(cnt++ *100 / nItems);
-        if (progress.wasCanceled())
-        {
-            break;
-        }
-        qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
+        PROGRESS(cnt++, break);
         xferItem(query.value(0).toULongLong());
     }
     progress.setValue(100);
@@ -698,7 +686,7 @@ void CQlgtDb::xferItems()
     gui->stdOut(tr("Import folders..."));
 
     query.prepare("SELECT id FROM folders");
-    QUERY_EXEC(return; );
+    QUERY_EXEC(return );
 }
 
 void CQlgtDb::xferItem(quint64 id)
@@ -706,7 +694,7 @@ void CQlgtDb::xferItem(quint64 id)
     QSqlQuery query(db);
     query.prepare("SELECT type, data FROM items WHERE id=:id");
     query.bindValue(":id", id);
-    QUERY_EXEC(return; );
+    QUERY_EXEC(return );
 
     if(query.next())
     {
